@@ -84,7 +84,7 @@ Array::update_length(int)
 
 /** Build an array with a name and an element type. The name may be omitted,
     which will create a nameless variable. The template (element type) pointer
-    may also be omitted, but if it is omitted when the Array is created, it 
+    may also be omitted, but if it is omitted when the Array is created, it
     \e must be added (with \c add_var()) before \c read() or \c deserialize()
     is called.
 
@@ -102,6 +102,25 @@ Array::Array(const string &n, BaseType *v) : Vector(n, 0, dods_array_c)
     add_var(v); // Vector::add_var() stores null is v is null
 }
 
+/** Build an array on the server-side with a name, a dataset name from which
+    this Array is being created, and an element type.
+
+    @todo Force the Array::add_var() method to be used to add \e v.
+    This version of add_var() calls Vector::add_var().
+
+    @param n A string containing the name of the variable to be created.
+    @param d A string containing the name of the dataset from which this
+    variable is being created.
+    @param v A pointer to a variable of the type to be included
+    in the Array.
+    @brief Array constructor
+*/
+Array::Array(const string &n, const string &d, BaseType *v)
+    : Vector(n, d, 0, dods_array_c)
+{
+    add_var(v); // Vector::add_var() stores null is v is null
+}
+
 /** @brief The Array copy constructor. */
 Array::Array(const Array &rhs) : Vector(rhs)
 {
@@ -196,9 +215,7 @@ Array::append_dim(int size, string name)
     d.stop = size - 1;
     d.stride = 1;
     d.c_size = size;
-#if 0
-    d.selected = true;  // assume all dims selected.
-#endif
+
     _shape.push_back(d);
 
     update_length(size);
@@ -220,20 +237,18 @@ Array::reset_constraint()
         (*i).stop = (*i).size - 1;
         (*i).stride = 1;
         (*i).c_size = (*i).size;
-#if 0
-        (*i).selected = true;
-#endif
+
         update_length((*i).size);
     }
 }
 
 
 /** Tell the Array object to clear the constraint information about
-    dimensions. Do this <i>once</i> before calling <tt>add_constraint()</tt> 
-    for each new constraint expression. Only the dimensions explicitly 
+    dimensions. Do this <i>once</i> before calling <tt>add_constraint()</tt>
+    for each new constraint expression. Only the dimensions explicitly
     selected using <tt>add_constraint()</tt> will be sent.
 
-    @deprecated This should never be used. 
+    @deprecated This should never be used.
     @brief Clears the projection; add each projected dimension explicitly using
     <tt>add_constraint</tt>.
 */
@@ -241,17 +256,6 @@ void
 Array::clear_constraint()
 {
     reset_constraint();
-#if 0
-    for (Dim_iter i = _shape.begin(); i != _shape.end(); i++) {
-        (*i).start = 0;
-        (*i).stop = 0;
-        (*i).stride = 0;
-        (*i).c_size = 0;
-        (*i).selected = false;
-    }
-
-    set_length(-1);
-#endif
 }
 
 // Note: MS VC++ won't tolerate embedded newlines in strings, hence the \n
@@ -301,9 +305,7 @@ Array::add_constraint(Dim_iter i, int start, int stride, int stop)
     d.c_size = (stop - start) / stride + 1;
 
     DBG(cerr << "add_constraint: c_size = " << d.c_size << endl);
-#if 0
-    d.selected = true;
-#endif
+
     update_length(d.c_size);
 }
 
@@ -327,7 +329,7 @@ Array::dim_end()
 
     @brief Return the total number of dimensions in the array.
     @param constrained A boolean flag to indicate whether the array is
-    constrained or not.  By default, constrained is FALSE.
+    constrained or not.  Ignored.
 */
 
 unsigned int
@@ -336,15 +338,6 @@ Array::dimensions(bool /*constrained*/)
     unsigned int dim = 0;
     for (Dim_citer i = _shape.begin(); i != _shape.end(); i++) {
         dim++;
-#if 0
-        if (constrained) {
-            if ((*i).selected)
-                dim++;
-        }
-        else {
-            dim++;
-        }
-#endif
     }
 
     return dim;
@@ -378,17 +371,6 @@ Array::dimension_size(Dim_iter i, bool constrained)
         else
             size = (*i).size;
     }
-    
-#if 0    
-        if (constrained) {
-            if ((*i).selected)
-                size = (*i).c_size;
-            else
-                size = 0;
-        }
-        else
-            size = (*i).size;
-#endif
 
     return size;
 }
@@ -415,26 +397,6 @@ int
 Array::dimension_start(Dim_iter i, bool /*constrained*/)
 {
     return (!_shape.empty()) ? (*i).start : 0;
-    
-#if 0
-    int start = 0;
-
-    if (!_shape.empty())
-        start = (*i).start;
-        
-#if array_selected
-        if (constrained) {
-            if ((*i).selected)
-                start = (*i).start;
-            else
-                start = 0;
-        }
-        else
-            start = (*i).start;
-#endif
-
-    return start;
-#endif
 }
 
 /** Use this function to return the stop index of an array
@@ -459,26 +421,6 @@ int
 Array::dimension_stop(Dim_iter i, bool /*constrained*/)
 {
     return (!_shape.empty()) ? (*i).stop : 0;
-    
-#if 0
-    int stop = 0;
-
-    if (!_shape.empty())
-        stop = (*i).stop;
-    
-#if array_selected
-        if (constrained) {
-            if ((*i).selected)
-                stop = (*i).stop;
-            else
-                stop = 0;
-        }
-        else
-            stop = (*i).stop;
-#endif
-
-    return stop;
-#endif
 }
 
 /** Use this function to return the stride value of an array
@@ -504,26 +446,6 @@ int
 Array::dimension_stride(Dim_iter i, bool /*constrained*/)
 {
     return (!_shape.empty()) ? (*i).stride : 0;
-    
-#if 0
-    int stride = 0;
-
-    if (!_shape.empty())
-        stride = (*i).stride;
-    
-#if array_selected
-        if (constrained) {
-            if ((*i).selected)
-                stride = (*i).stride;
-            else
-                stride = 0;
-        }
-        else
-            stride = (*i).stride;
-#endif
-
-    return stride;
-#endif
 }
 
 /** This function returns the name of the dimension indicated with
@@ -549,7 +471,7 @@ Array::dimension_name(Dim_iter i)
                            "*This* array has no dimensions.");
     return (*i).name;
 }
-
+//#if FILE_METHODS
 /** Prints a declaration for the Array.  This is what appears in a
     DDS.  If the Array is constrained, the declaration will reflect
     the size of the Array once the constraint is applied.
@@ -578,10 +500,6 @@ Array::print_decl(FILE *out, string space, bool print_semi,
     var()->print_decl(out, space, false, constraint_info, constrained);
 
     for (Dim_citer i = _shape.begin(); i != _shape.end(); i++) {
-#if 0
-        if (constrained && !((*i).selected))
-            continue;
-#endif
         fprintf(out, "[") ;
         if ((*i).name != "") {
             fprintf(out, "%s = ", id2www((*i).name).c_str()) ;
@@ -598,7 +516,7 @@ Array::print_decl(FILE *out, string space, bool print_semi,
         fprintf(out, ";\n") ;
     }
 }
-
+//#endif
 /** Prints a declaration for the Array.  This is what appears in a
     DDS.  If the Array is constrained, the declaration will reflect
     the size of the Array once the constraint is applied.
@@ -627,10 +545,6 @@ Array::print_decl(ostream &out, string space, bool print_semi,
     var()->print_decl(out, space, false, constraint_info, constrained);
 
     for (Dim_citer i = _shape.begin(); i != _shape.end(); i++) {
-#if 0
-        if (constrained && !((*i).selected))
-            continue;
-#endif
 	out << "[" ;
         if ((*i).name != "") {
 	    out << id2www((*i).name) << " = " ;
@@ -647,31 +561,31 @@ Array::print_decl(ostream &out, string space, bool print_semi,
 	out << ";\n" ;
     }
 }
-
+//#if FILE_METHODS
 void
 Array::print_xml(FILE *out, string space, bool constrained)
 {
     print_xml_core(out, space, constrained, "Array");
 }
-
+//#endif
 void
 Array::print_xml(ostream &out, string space, bool constrained)
 {
     print_xml_core(out, space, constrained, "Array");
 }
-
+//#if FILE_METHODS
 void
 Array::print_as_map_xml(FILE *out, string space, bool constrained)
 {
     print_xml_core(out, space, constrained, "Map");
 }
-
+//#endif
 void
 Array::print_as_map_xml(ostream &out, string space, bool constrained)
 {
     print_xml_core(out, space, constrained, "Map");
 }
-
+//#if FILE_METHODS
 class PrintArrayDim : public unary_function<Array::dimension&, void>
 {
     FILE *d_out;
@@ -718,7 +632,7 @@ Array::print_xml_core(FILE *out, string space, bool constrained, string tag)
 
     fprintf(out, "%s</%s>\n", space.c_str(), tag.c_str());
 }
-
+//#endif
 class PrintArrayDimStrm : public unary_function<Array::dimension&, void>
 {
     ostream &d_out;
@@ -764,7 +678,7 @@ Array::print_xml_core(ostream &out, string space, bool constrained, string tag)
 
     out << space << "</" << tag << ">\n" ;
 }
-
+//#if FILE_METHODS
 /** Prints the values in ASCII of the entire (constrained) array. This method
     Attempts to make an aesthetically pleasing display. However, it is
     primarily intended for debugging purposes.
@@ -808,9 +722,9 @@ Array::print_array(FILE *out, unsigned int index, unsigned int dims,
         return index;
     }
 }
-
+//#endif
 /** Prints the values in ASCII of the entire (constrained) array. This method
-    Attempts to make an aesthetically pleasing display. However, it is
+    Attempts to make an anesthetically pleasing display. However, it is
     primarily intended for debugging purposes.
 
     @param out Write the output to this ostream
@@ -852,7 +766,7 @@ Array::print_array(ostream &out, unsigned int index, unsigned int dims,
         return index;
     }
 }
-
+//#if FILE_METHODS
 void
 Array::print_val(FILE *out, string space, bool print_decl_p)
 {
@@ -873,14 +787,14 @@ Array::print_val(FILE *out, string space, bool print_decl_p)
         shape[index++] = dimension_size(i, true);
 
     print_array(out, 0, _shape.size(), shape);
-    
+
     delete [] shape; shape = 0;
 
     if (print_decl_p) {
         fprintf(out, ";\n") ;
     }
 }
-
+//#endif
 void
 Array::print_val(ostream &out, string space, bool print_decl_p)
 {
@@ -901,7 +815,7 @@ Array::print_val(ostream &out, string space, bool print_decl_p)
         shape[index++] = dimension_size(i, true);
 
     print_array(out, 0, dimensions(true), shape);
-    
+
     delete [] shape; shape = 0;
 
     if (print_decl_p) {
@@ -960,9 +874,6 @@ Array::dump(ostream &strm) const
         strm << DapIndent::LMarg << "stride: " << (*i).stride << endl ;
         strm << DapIndent::LMarg << "constrained size: " << (*i).c_size
              << endl ;
-#if 0
-        strm << DapIndent::LMarg << "selected: " << (*i).selected << endl ;
-#endif
         DapIndent::UnIndent() ;
     }
     DapIndent::UnIndent() ;
