@@ -117,28 +117,26 @@ public:
         int stop;  ///< The constraint end index
         int stride;  ///< The constraint stride
         int c_size;  ///< Size of dimension once constrained
-#if array_selected
-        bool selected; ///< \c True if a constraint has been applied to this dimension.
-#endif
     };
 
 private:
     std::vector<dimension> _shape; // list of dimensions (i.e., the shape)
-    unsigned int print_array(FILE *out, unsigned int index,
-                             unsigned int dims, unsigned int shape[]);
-    unsigned int print_array(ostream &out, unsigned int index,
-                             unsigned int dims, unsigned int shape[]);
 
     friend class ArrayTest;
 
 protected:
     void _duplicate(const Array &a);
-    void print_xml_core(FILE *out, string space, bool constrained, string tag);
-    void print_xml_core(ostream &out, string space, bool constrained, string tag);
+
+    //#if FILE_METHODS
+    unsigned int print_array(FILE *out, unsigned int index,
+                             unsigned int dims, unsigned int shape[]);
+    //#endif
+    unsigned int print_array(ostream &out, unsigned int index,
+                             unsigned int dims, unsigned int shape[]);
 
 public:
     /** A constant iterator used to access the various dimensions of an
-        Array. 
+        Array.
 
         @see dim_begin()
         @see dim_end() */
@@ -151,7 +149,8 @@ public:
         @see dim_end() */
     typedef std::vector<dimension>::iterator Dim_iter ;
 
-    Array(const string &n = "", BaseType *v = 0);
+    Array(const string &n, BaseType *v);
+    Array(const string &n, const string &d, BaseType *v);
     Array(const Array &rhs);
     virtual ~Array();
 
@@ -180,30 +179,39 @@ public:
 
     unsigned int dimensions(bool constrained = false);
 
-    virtual void print_decl(FILE *out, string space = "    ",
-                            bool print_semi = true,
-                            bool constraint_info = false,
-                            bool constrained = false);
     virtual void print_decl(ostream &out, string space = "    ",
                             bool print_semi = true,
                             bool constraint_info = false,
                             bool constrained = false);
 
-    virtual void print_xml(FILE *out, string space = "    ",
-                           bool constrained = false);
     virtual void print_xml(ostream &out, string space = "    ",
                            bool constrained = false);
 
-    virtual void print_as_map_xml(FILE *out, string space = "    ",
-                                  bool constrained = false);
+    //#if FILE_METHODS
+    virtual void print_xml_core(FILE *out, string space, bool constrained, string tag);
+    //#endif
+    virtual void print_xml_core(ostream &out, string space, bool constrained, string tag);
+
+    // not used (?)
     virtual void print_as_map_xml(ostream &out, string space = "    ",
                                   bool constrained = false);
 
-    virtual void print_val(FILE *out, string space = "",
-                           bool print_decl_p = true);
     virtual void print_val(ostream &out, string space = "",
                            bool print_decl_p = true);
 
+    //#if FILE_METHODS
+    virtual void print_xml(FILE *out, string space = "    ",
+                           bool constrained = false);
+    virtual void print_as_map_xml(FILE *out, string space = "    ",
+                                  bool constrained = false);
+    virtual void print_val(FILE *out, string space = "",
+                           bool print_decl_p = true);
+    virtual void print_decl(FILE *out, string space = "    ",
+                            bool print_semi = true,
+                            bool constraint_info = false,
+                            bool constrained = false);
+    //#endif
+
     virtual bool check_semantics(string &msg, bool all = false);
 
     virtual void dump(ostream &strm) const ;
