@@ -40,7 +40,7 @@
 #include <sstream>
 #include <string>
 
-// #define DODS_DEBUG
+//#define DODS_DEBUG
 
 #include "BaseType.h"
 #include "InternalErr.h"
@@ -65,8 +65,11 @@ namespace libdap {
 void
 BaseType::_duplicate(const BaseType &bt)
 {
+    DBG(cerr << "BaseType::_duplicate: " << bt._name << " send_p: "
+            << bt._send_p << endl);
     _name = bt._name;
     _type = bt._type;
+    _dataset = bt._dataset;
     _read_p = bt._read_p; // added, reza
     _send_p = bt._send_p; // added, reza
     d_in_selection = bt.d_in_selection;
@@ -91,7 +94,25 @@ BaseType::_duplicate(const BaseType &bt)
     data in this variable to a client DODS process.
     @see Type */
 BaseType::BaseType(const string &n, const Type &t)
-        : _name(n), _type(t), _read_p(false), _send_p(false),
+        : _name(n), _type(t), _dataset(""), _read_p(false), _send_p(false),
+        d_in_selection(false), _synthesized_p(false), d_parent(0)
+{}
+
+/** The BaseType constructor needs a name, a dataset, and a type.
+    The BaseType class exists to provide data to
+    type classes that inherit from it.  The constructors of those
+    classes call the BaseType constructor; it is never called
+    directly.
+
+    @brief The BaseType constructor.
+    @param n A string containing the name of the new variable.
+    @param d A string containing the dataset name from which this variable
+    is created
+    @param t The type of the variable.
+    data in this variable to a client DODS process.
+    @see Type */
+BaseType::BaseType(const string &n, const string &d, const Type &t)
+        : _name(n), _type(t), _dataset(d), _read_p(false), _send_p(false),
         d_in_selection(false), _synthesized_p(false), d_parent(0)
 {}
 
@@ -129,6 +150,7 @@ BaseType::toString()
     oss << "BaseType (" << this << "):" << endl
     << "          _name: " << _name << endl
     << "          _type: " << type_name() << endl
+    << "          _dataset: " << _dataset << endl
     << "          _read_p: " << _read_p << endl
     << "          _send_p: " << _send_p << endl
     << "          _synthesized_p: " << _synthesized_p << endl
@@ -155,6 +177,7 @@ BaseType::dump(ostream &strm) const
 
     strm << DapIndent::LMarg << "name: " << _name << endl ;
     strm << DapIndent::LMarg << "type: " << type_name() << endl ;
+    strm << DapIndent::LMarg << "dataset: " << _dataset << endl ;
     strm << DapIndent::LMarg << "read_p: " << _read_p << endl ;
     strm << DapIndent::LMarg << "send_p: " << _send_p << endl ;
     strm << DapIndent::LMarg << "synthesized_p: " << _synthesized_p << endl ;
@@ -183,6 +206,19 @@ BaseType::set_name(const string &n)
     _name = www2id(name); // www2id writes into its param.
 }
 
+/** @brief Returns the name of the dataset used to create this instance
+
+    A dataset from which the data is to be read. The meaning of this string
+    will vary among different types of data sources. It \e may be the name
+    of a data file or an identifier used to read data from a relational
+    database.
+ */
+string
+BaseType::dataset() const
+{
+    return _dataset;
+}
+
 /** @brief Returns the type of the class instance. */
 Type
 BaseType::type() const
@@ -237,7 +273,7 @@ BaseType::type_name() const
 }
 
 /** @brief Returns true if the instance is a numeric, string or URL
-    type variable. 
+    type variable.
     @return True if the instance is a scalar numeric, String or URL variable,
     False otherwise. Arrays (even of simple types) return False.
     @see is_vector_type() */
@@ -267,8 +303,8 @@ BaseType::is_simple_type()
     return false;
 }
 
-/** @brief Returns true if the instance is a vector (i.e., array) type 
-    variable. 
+/** @brief Returns true if the instance is a vector (i.e., array) type
+    variable.
     @return True if the instance is an Array, False otherwise. */
 bool
 BaseType::is_vector_type()
@@ -299,7 +335,7 @@ BaseType::is_vector_type()
 }
 
 /** @brief Returns true if the instance is a constructor (i.e., Structure,
-    Sequence or Grid) type variable. 
+    Sequence or Grid) type variable.
     @return True if the instance is a Structure, Sequence or Grid, False
     otherwise. */
 bool
@@ -433,7 +469,8 @@ void
 BaseType::set_read_p(bool state)
 {
     if (! _synthesized_p) {
-        DBG(cerr << "Changing read_p state of " << name() << endl);
+        DBG(cerr << "Changing read_p state of " << name() << " to "
+	         << state << endl);
         _read_p = state;
     }
 }
@@ -456,7 +493,7 @@ BaseType::send_p()
 
 /** Sets the value of the <tt>send_p</tt> flag.  This
     function is meant to be called from within the constraint evaluator of
-    other code which determines that this variable should be returned to the 
+    other code which determines that this variable should be returned to the
     client.  Data are ready to be sent when <i>both</i> the <tt>_send_p</tt>
     and <tt>_read_p</tt> flags are set to TRUE.
 
@@ -679,15 +716,10 @@ BaseType::add_var(BaseType *, Part)
     values remain in the Sequence, false to indicate no more values remain.
     (see Sequence::serialize() and Sequence::read_row()).
 
-    @param dataset A string naming the dataset from which the data is to
-    be read. The meaning of this string will vary among different types of
-    data sources. It \e may be the name of a data file or an identifier
-    used to read data from a relational database.
-
     @see BaseType
     @see Sequence  */
 bool
-BaseType::read(const string &)
+BaseType::read()
 {
     if (_read_p)
         return false;
@@ -696,16 +728,16 @@ BaseType::read(const string &)
 }
 
 void
-BaseType::intern_data(const string &dataset, ConstraintEvaluator &, DDS &dds)
+BaseType::intern_data(ConstraintEvaluator &, DDS &dds)
 {
     dds.timeout_on();
-
+    DBG(cerr << "BaseType::intern_data: " << name() << endl);
     if (!read_p())
-        read(dataset);          // read() throws Error and InternalErr
+        read();          // read() throws Error and InternalErr
 
     dds.timeout_off();
 }
-
+//#if FILE_METHODS
 /** Write the variable's declaration in a C-style syntax. This
     function is used to create textual representation of the Data
     Descriptor Structure (DDS).  See <i>The DODS User Manual</i> for
@@ -770,7 +802,7 @@ BaseType::print_decl(FILE *out, string space, bool print_semi,
     if (print_semi)
         fprintf(out, ";\n") ;
 }
-
+//#endif
 /** Write the variable's declaration in a C-style syntax. This
     function is used to create textual representation of the Data
     Descriptor Structure (DDS).  See <i>The DODS User Manual</i> for
@@ -834,7 +866,7 @@ BaseType::print_decl(ostream &out, string space, bool print_semi,
     if (print_semi)
 	out << ";\n" ;
 }
-
+//#if FILE_METHODS
 /** Write the XML representation of this variable. This method is used to
     build the DDX XML response.
     @param out Destination.
@@ -861,7 +893,7 @@ BaseType::print_xml(FILE *out, string space, bool constrained)
         fprintf(out, "/>\n"); // no attributes; just close tag.
     }
 }
-
+//#endif
 /** Write the XML representation of this variable. This method is used to
     build the DDX XML response.
     @param out Destination output stream
@@ -972,11 +1004,9 @@ BaseType::check_semantics(string &msg, bool)
     is implied. Choose one from the following: <tt>EQUAL</tt>,
     <tt>NOT_EQUAL</tt>, <tt>GREATER</tt>, <tt>GREATER_EQL</tt>,
     <tt>LESS</tt>, <tt>LESS_EQL</tt>, and <tt>REGEXP</tt>.
-    @param dataset The name of the dataset from which the instance's
-    data has come (or is to come).
     @return The boolean value of the comparison. */
 bool
-BaseType::ops(BaseType *, int, const string &)
+BaseType::ops(BaseType *, int)
 {
     // Even though ops is a public method, it can never be called because
     // they will never have a BaseType object since this class is abstract,
