@@ -190,6 +190,7 @@ class BaseType : public DapObj
 private:
     string _name;  // name of the instance
     Type _type;   // instance's type
+    string _dataset; // name of the dataset used to create this BaseType
 
     bool _read_p;  // true if the value has been read
     bool _send_p;  // Is the variable in the projection?
@@ -210,7 +211,8 @@ protected:
 public:
     typedef stack<BaseType *> btp_stack;
 
-    BaseType(const string &n = "", const Type &t = dods_null_c);
+    BaseType(const string &n, const Type &t);
+    BaseType(const string &n, const string &d, const Type &t);
 
     BaseType(const BaseType &copy_from);
     virtual ~BaseType();
@@ -236,6 +238,8 @@ public:
     void set_type(const Type &t);
     string type_name() const;
 
+    string dataset() const ;
+
     virtual bool is_simple_type();
     virtual bool is_vector_type();
     virtual bool is_constructor_type();
@@ -300,25 +304,26 @@ public:
 
     virtual void add_var(BaseType *bt, Part part = nil);
 
-    virtual bool read(const string &dataset);
+    virtual bool read();
 
     virtual bool check_semantics(string &msg, bool all = false);
 
-    virtual bool ops(BaseType *b, int op, const string &dataset);
-
+    virtual bool ops(BaseType *b, int op);
+    //#if FILE_METHODS
     virtual void print_decl(FILE *out, string space = "    ",
                             bool print_semi = true,
                             bool constraint_info = false,
                             bool constrained = false);
-
+    //#endif
     virtual void print_decl(ostream &out, string space = "    ",
                             bool print_semi = true,
                             bool constraint_info = false,
                             bool constrained = false);
 
+    //#if FILE_METHODS
     virtual void print_xml(FILE *out, string space = "    ",
                            bool constrained = false);
-
+    //#endif
     virtual void print_xml(ostream &out, string space = "    ",
                            bool constrained = false);
 
@@ -346,9 +351,9 @@ public:
 	caller is responsible for deallocating that memory. Array and
 	values for simple types are stored as C would store an array.
 
-        @deprecated Use value() in the leaf classes.
-         
-	@brief Reads the class data. 
+    @deprecated Use value() in the leaf classes.
+
+	@brief Reads the class data.
 
 	@param val A pointer to a pointer to the memory into which the
 	class data will be copied. If the value pointed to is NULL,
@@ -356,7 +361,7 @@ public:
 	value modified accordingly. The calling program is responsible
 	for deallocating the memory references by this pointer.
 
-	@return The size (in bytes) of the information copied to <i>val</i>. 
+	@return The size (in bytes) of the information copied to <i>val</i>.
     */
     virtual unsigned int buf2val(void **val) = 0;
 
@@ -364,14 +369,14 @@ public:
 	internal buffer. This function does not perform any checks, so
 	users must be sure that the thing pointed to can actually be
 	stored in the object's buffer.
-	
+
 	Only simple objects (Int, Float, Byte, and so on) and arrays
 	of these simple objects may be stored using this function. To
 	put data into more complex constructor types, use the
 	functions provided by that class.
 
-        @deprecated Use set_value() in the leaf classes.
-         
+    @deprecated Use set_value() in the leaf classes.
+
 	@brief Loads class data.
 
 	@param val A pointer to the data to be inserted into the class
@@ -391,21 +396,19 @@ public:
 	@see Vector::val2buf */
     virtual unsigned int val2buf(void *val, bool reuse = false) = 0;
 
-    /** Similar to using serialize() and deserialize() together in one object. 
-        Data are read as for serialize and those values are stored in the 
+    /** Similar to using serialize() and deserialize() together in one object.
+        Data are read as for serialize and those values are stored in the
         objects as deserialize() does but does not write and then read data
         to/from a stream.
-        
-        This method is defined by the various data type classes. It calls the 
+
+        This method is defined by the various data type classes. It calls the
         read() abstract method.
-        
-        @param dataset The (local) name of dataset to be read.
+
         @param eval Use this as the constraint expression evaluator.
         @param dds The Data Descriptor Structure object corresponding
         to this dataset. See <i>The DODS User Manual</i> for
         information about this structure. */
-    virtual void intern_data(const string &dataset, ConstraintEvaluator &eval,
-                             DDS &dds);
+    virtual void intern_data(ConstraintEvaluator &eval, DDS &dds);
 
     /** Sends the data from the indicated (local) dataset through the
 	connection identified by the <i>sink</i> parameter. If the
@@ -420,7 +423,6 @@ public:
 
 	@brief Move data to the net.
 
-	@param dataset The (local) name of dataset to be read.
         @param eval Use this as the constraint expression evaluator.
 	@param dds The Data Descriptor Structure object corresponding
 	to this dataset. See <i>The DODS User Manual</i> for
@@ -435,8 +437,8 @@ public:
 	@exception InternalErr.
 	@exception Error.
 	@see DDS */
-    virtual bool serialize(const string &dataset, ConstraintEvaluator &eval,
-                           DDS &dds, Marshaller &m, bool ce_eval = true) = 0;
+    virtual bool serialize(ConstraintEvaluator &eval, DDS &dds,
+			   Marshaller &m, bool ce_eval = true) = 0;
 
     /** Receives data from the network connection identified by the
 	<tt>source</tt> parameter. The data is put into the class data
@@ -464,6 +466,7 @@ public:
 	@see DDS */
     virtual bool deserialize(UnMarshaller &um, DDS *dds, bool reuse = false) = 0;
 
+    //#if FILE_METHODS
     /** Prints the value of the variable, with its declaration. This
 	function is primarily intended for debugging DODS
 	applications. However, it can be overloaded and used to do
@@ -473,13 +476,15 @@ public:
 
 	@brief Prints the value of the variable.
 
-	@param out The output FILE on which to print the value.
+	@param out The output stream on which to print the value.
 	@param space This value is passed to the print_decl()
 	function, and controls the leading spaces of the output.
 	@param print_decl_p A boolean value controlling whether the
 	variable declaration is printed as well as the value. */
+
     virtual void print_val(FILE *out, string space = "",
                            bool print_decl_p = true) = 0;
+    //#endif
 
     /** Prints the value of the variable, with its declaration. This
 	function is primarily intended for debugging DODS
