@@ -37,7 +37,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    { "$Id: Byte.cc 18315 2008-03-03 20:14:44Z jimg $"
+    { "$Id: Byte.cc 20518 2009-03-05 23:39:46Z jimg $"
     };
 
 #include "Byte.h"
@@ -53,6 +53,8 @@ static char rcsid[] not_used =
 using std::cerr;
 using std::endl;
 
+namespace libdap {
+
 /** The Byte constructor requires only the name of the variable
     to be created.  The name may be omitted, which will create a
     nameless variable.  This may be adequate for some applications.
@@ -62,12 +64,22 @@ using std::endl;
     created.
 
 */
-
-namespace libdap {
-
 Byte::Byte(const string & n): BaseType(n, dods_byte_c)
 {}
 
+/** This Byte constructor requires the name of the variable to be created
+    and the name of the dataset from which this variable is being created.
+    This constructor is used in server-side processing, loading structure in
+    from a dataset.
+
+    @brief The Byte server-side constructor.
+    @param n A string containing the name of the variable to be created.
+    @param d A string containing the name of the dataset from which the
+    variable is being created.
+*/
+Byte::Byte(const string &n, const string &d): BaseType(n, d, dods_byte_c)
+{}
+
 Byte::Byte(const Byte & copy_from): BaseType(copy_from)
 {
     _buf = copy_from._buf;
@@ -105,16 +117,16 @@ unsigned int Byte::width()
     @return False if a failure to read, send or flush is detected, true
     otherwise.
 */
-bool Byte::serialize(const string & dataset, ConstraintEvaluator & eval,
-                     DDS & dds, Marshaller &m, bool ce_eval)
+bool Byte::serialize(ConstraintEvaluator & eval, DDS & dds,
+		     Marshaller &m, bool ce_eval)
 {
     dds.timeout_on();
 
     if (!read_p())
-        read(dataset);          // read() throws Error and InternalErr
+        read();          // read() throws Error and InternalErr
 
 #if EVAL
-    if (ce_eval && !eval.eval_selection(dds, dataset))
+    if (ce_eval && !eval.eval_selection(dds, dataset()))
         return true;
 #endif
 
@@ -187,7 +199,7 @@ dods_byte Byte::value() const
 {
     return _buf;
 }
-
+//#if FILE_METHODS
 void Byte::print_val(FILE * out, string space, bool print_decl_p)
 {
     if (print_decl_p) {
@@ -197,7 +209,7 @@ void Byte::print_val(FILE * out, string space, bool print_decl_p)
     else
         fprintf(out, "%d", (int) _buf);
 }
-
+//#endif
 void Byte::print_val(ostream &out, string space, bool print_decl_p)
 {
     if (print_decl_p) {
@@ -208,25 +220,25 @@ void Byte::print_val(ostream &out, string space, bool print_decl_p)
 	out << (int)_buf ;
 }
 
-bool Byte::ops(BaseType * b, int op, const string & dataset)
+bool Byte::ops(BaseType * b, int op)
 {
 
     // Extract the Byte arg's value.
-    if (!read_p() && !read(dataset)) {
+    if (!read_p() && !read()) {
         cerr << "This value not read!" << endl;
         // Jose Garcia
         // Since the read method is virtual and implemented outside
-        // libdap++ if we can not read the data that is the problem
+        // libdap++ if we cannot read the data that is the problem
         // of the user or of whoever wrote the surrogate library
         // implementing read therefore it is an internal error.
         throw InternalErr("This value not read!");
     }
     // Extract the second arg's value.
-    if (!b->read_p() && !b->read(dataset)) {
+    if (!b || !b->read_p() && !b->read()) {
         cerr << "This value not read!" << endl;
         // Jose Garcia
         // Since the read method is virtual and implemented outside
-        // libdap++ if we can not read the data that is the problem
+        // libdap++ if we cannot read the data that is the problem
         // of the user or of whoever wrote the surrogate library
         // implementing read therefore it is an internal error.
         throw InternalErr("This value not read!");
