@@ -61,7 +61,7 @@ namespace libdap
 class Byte: public BaseType
 {
     /** This class allows Int16, ..., Float64 access to <tt>_buf</tt> to
-    simplify and speed up the relational operators. 
+    simplify and speed up the relational operators.
 
     NB: According to Stroustrup it does not matter where (public, private
     or protected) friend classes are declared. */
@@ -76,7 +76,8 @@ protected:
     dods_byte _buf;
 
 public:
-    Byte(const string &n = "");
+    Byte(const string &n);
+    Byte(const string &n, const string &d);
 
     virtual ~Byte()
     {}
@@ -89,8 +90,8 @@ public:
 
     virtual BaseType *ptr_duplicate();
 
-    bool serialize(const string &dataset, ConstraintEvaluator &eval,
-                   DDS &dds, Marshaller &m, bool ce_eval);
+    bool serialize(ConstraintEvaluator &eval, DDS &dds,
+		   Marshaller &m, bool ce_eval);
     bool deserialize(UnMarshaller &um, DDS *, bool);
 
     virtual unsigned int val2buf(void *val, bool reuse = false);
@@ -98,13 +99,14 @@ public:
 
     virtual bool set_value(const dods_byte value);
     virtual dods_byte value() const;
-
+    //#if FILE_METHODS
     virtual void print_val(FILE *out, string space = "",
                            bool print_decl_p = true);
+    //#endif
     virtual void print_val(ostream &out, string space = "",
                            bool print_decl_p = true);
 
-    virtual bool ops(BaseType *b, int op, const string &dataset);
+    virtual bool ops(BaseType *b, int op);
 
     virtual void dump(ostream &strm) const ;
 };
