@@ -25,7 +25,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: ConstraintEvaluator.cc 17856 2008-02-02 21:25:59Z pwest $"
+    {"$Id: ConstraintEvaluator.cc 19914 2008-11-25 17:26:22Z jimg $"
     };
 
 #include "ConstraintEvaluator.h"
@@ -83,14 +83,13 @@ ConstraintEvaluator::clause_end()
 /** Returns the value of the indicated clause of a constraint
     expression. */
 bool
-ConstraintEvaluator::clause_value(Clause_iter &iter, DDS &dds,
-                                  const string &dataset)
+ConstraintEvaluator::clause_value(Clause_iter &iter, DDS &dds/*, const string &***/)
 {
     if (expr.empty())
         throw InternalErr(__FILE__, __LINE__,
                           "There are no CE clauses for *this* DDS object.");
 
-    return (*iter)->value(dataset, dds);
+    return (*iter)->value(dds);
 }
 
 /** @brief Add a clause to a constraint expression.
@@ -193,7 +192,7 @@ public:
     @name External Function Accessors
 */
 //@{
-
+#if 1
 /** @brief Add a boolean function to the list. */
 void
 ConstraintEvaluator::add_function(const string &name, bool_func f)
@@ -202,7 +201,7 @@ ConstraintEvaluator::add_function(const string &name, bool_func f)
     function func(name, f);
     functions.push_back(func);
 }
-
+#endif
 /** @brief Add a BaseType function to the list. */
 void
 ConstraintEvaluator::add_function(const string &name, btp_func f)
@@ -220,7 +219,7 @@ ConstraintEvaluator::add_function(const string &name, proj_func f)
     function func(name, f);
     functions.push_back(func);
 }
-
+#if 1
 /** @brief Find a Boolean function with a given name in the function list. */
 bool
 ConstraintEvaluator::find_function(const string &name, bool_func *f) const
@@ -236,7 +235,7 @@ ConstraintEvaluator::find_function(const string &name, bool_func *f) const
 
     return false;
 }
-
+#endif
 /** @brief Find a BaseType function with a given name in the function list. */
 bool
 ConstraintEvaluator::find_function(const string &name, btp_func *f) const
@@ -283,7 +282,7 @@ ConstraintEvaluator::functional_expression()
 
 /** @brief Evaluate a function-valued constraint expression. */
 BaseType *
-ConstraintEvaluator::eval_function(DDS &dds, const string &dataset)
+ConstraintEvaluator::eval_function(DDS &dds, const string &)
 {
     if (expr.size() != 1)
         throw InternalErr(__FILE__, __LINE__,
@@ -291,7 +290,7 @@ ConstraintEvaluator::eval_function(DDS &dds, const string &dataset)
 
     Clause *cp = expr[0] ;
     BaseType *result;
-    if (cp->value(dataset, dds, &result))
+    if (cp->value(dds, &result))
         return result;
     else
         return NULL;
@@ -321,7 +320,7 @@ ConstraintEvaluator::boolean_expression()
     @param dataset This string is passed to the read() methods.
     @return True if the expression is true, false otherwise. */
 bool
-ConstraintEvaluator::eval_selection(DDS &dds, const string &dataset)
+ConstraintEvaluator::eval_selection(DDS &dds, const string &)
 {
     if (expr.empty()) {
         DBG(cerr << "No selection recorded" << endl);
@@ -340,7 +339,7 @@ ConstraintEvaluator::eval_selection(DDS &dds, const string &dataset)
         if (!((*i)->boolean_clause()))
             throw InternalErr(__FILE__, __LINE__,
                               "A selection expression must contain only boolean clauses.");
-        result = result && (*i)->value(dataset, dds);
+        result = result && (*i)->value(dds);
     }
 
     return result;
