@@ -63,6 +63,20 @@ Constructor::Constructor(const string &n, const Type &t)
         : BaseType(n, t)
 {}
 
+/** Server-side constructor that takes the name of the variable to be
+ * created, the dataset name from which this variable is being created, and
+ * the type of data being stored in the Constructor. This is a protected
+ * constructor, available only to derived classes of Constructor
+ *
+ * @param n string containing the name of the variable to be created
+ * @param d string containing the name of the dataset from which this
+ * variable is being created
+ * @param t type of data being stored
+ */
+Constructor::Constructor(const string &n, const string &d, const Type &t)
+        : BaseType(n, d, t)
+{}
+
 Constructor::Constructor(const Constructor &rhs) : BaseType(rhs)
 {}
 
@@ -272,7 +286,7 @@ Constructor::get_var_index(int i)
     return *(_vars.begin() + i);
 }
 
-
+//#if FILE_METHODS
 void
 Constructor::print_decl(FILE *out, string space, bool print_semi,
                         bool constraint_info, bool constrained)
@@ -297,7 +311,7 @@ Constructor::print_decl(FILE *out, string space, bool print_semi,
     if (print_semi)
         fprintf(out, ";\n") ;
 }
-
+//#endif
 void
 Constructor::print_decl(ostream &out, string space, bool print_semi,
                         bool constraint_info, bool constrained)
@@ -322,7 +336,7 @@ Constructor::print_decl(ostream &out, string space, bool print_semi,
     if (print_semi)
 	out << ";\n" ;
 }
-
+//#if FILE_METHODS
 class PrintField : public unary_function<BaseType *, void>
 {
     FILE *d_out;
@@ -366,7 +380,7 @@ Constructor::print_xml(FILE *out, string space, bool constrained)
         fprintf(out, "/>\n");
     }
 }
-
+//#endif
 class PrintFieldStrm : public unary_function<BaseType *, void>
 {
     ostream &d_out;
