@@ -50,14 +50,15 @@ protected:
     virtual AttrTable *find_matching_container(AttrTable::entry *source,
             BaseType **dest_variable);
 
+    Constructor(const string &n, const Type &t);
+    Constructor(const string &n, const string &d, const Type &t);
+
+    Constructor(const Constructor &copy_from);
 public:
     typedef std::vector<BaseType *>::const_iterator Vars_citer ;
     typedef std::vector<BaseType *>::iterator Vars_iter ;
     typedef std::vector<BaseType *>::reverse_iterator Vars_riter ;
 
-    Constructor(const string &n, const Type &t);
-
-    Constructor(const Constructor &copy_from);
     virtual ~Constructor();
 
     Constructor &operator=(const Constructor &rhs);
@@ -72,20 +73,23 @@ public:
 
     virtual bool is_linear();
 
-    virtual void print_decl(FILE *out, string space = "    ",
-                            bool print_semi = true,
-                            bool constraint_info = false,
-                            bool constrained = false);
     virtual void print_decl(ostream &out, string space = "    ",
                             bool print_semi = true,
                             bool constraint_info = false,
                             bool constrained = false);
 
-    virtual void print_xml(FILE *out, string space = "    ",
-                           bool constrained = false);
     virtual void print_xml(ostream &out, string space = "    ",
                            bool constrained = false);
 
+    //#if FILE_METHODS
+    virtual void print_decl(FILE *out, string space = "    ",
+                            bool print_semi = true,
+                            bool constraint_info = false,
+                            bool constrained = false);
+    virtual void print_xml(FILE *out, string space = "    ",
+                           bool constrained = false);
+    //#endif
+
     virtual void dump(ostream &strm) const ;
 };
 
