@@ -42,8 +42,6 @@
 #include <string>
 #include <vector>
 
-//#include "Pix.h"
-
 #ifndef _basetype_h
 #include "BaseType.h"
 #endif
@@ -176,25 +174,38 @@ class DDS : public DapObj
 private:
     BaseTypeFactory *d_factory;
 
-    string name;  // The dataset name
+    string name;                // The dataset name
+    string _filename;		// File name (or other OS identifier) for
+    string _container_name;	// name of container structure
+    Structure *d_container;	// current container for container name
+				// dataset or part of dataset.
 
-    string _filename;  // File name (or other OS identifier) for
-    // dataset or part of dataset.
-    int d_protocol_major;       // The protocol major version number
-    int d_protocol_minor;       // ... and minor version number
+    // These are used on the client-side and correspond to the version of the
+    // response. The client_dap_major/minor fields hold information sent from
+    // a client describing what it would like.
+
+    int d_dap_major;       // The protocol major version number
+    int d_dap_minor;       // ... and minor version number
+
+    // These hold the major and minor versions of DAP that the client sent in
+    // the XDAP-Accept header. If the header is not sent, these default to 2.0
+    int d_client_dap_major;
+    int d_client_dap_minor;
+
+    string d_request_xml_base;
 
     AttrTable d_attr;           // Global attributes.
 
-    vector<BaseType *> vars; // Variables at the top level
+    vector<BaseType *> vars;    // Variables at the top level
 #if 0
     bool is_global_attr(string name);
     void add_global_attribute(AttrTable::entry *entry);
 #endif
     BaseType *find_hdf4_dimension_attribute_home(AttrTable::entry *source);
 
-    int d_timeout;  // alarm time in seconds. If greater than
-    // zero, raise the alarm signal if more than
-    // d_timeout seconds are spent reading data.
+    int d_timeout;              // alarm time in seconds. If greater than
+                                // zero, raise the alarm signal if more than
+                                // d_timeout seconds are spent reading data.
     friend class DDSTest;
 
 protected:
@@ -230,7 +241,7 @@ public:
     void set_dataset_name(const string &n);
 
     /** Return the factory which makes instances of the Byte, ..., Grid
-        type classes. Specialize BaseTypeFactory so that a DDS will be 
+        type classes. Specialize BaseTypeFactory so that a DDS will be
         populated with your client or server's specialized types.
         @return An instance of BaseTypeFactory. */
     BaseTypeFactory *get_factory() const
@@ -239,9 +250,10 @@ public:
     }
 
     /** Set the factory class used to instantiate variables during the
-        parse of a DDS. 
+        parse of a DDS.
         @param factory The factory this DDS should use. Caller must free
         factory when done with this DDS.
+        @return The old factory.
         @see BaseTypeFactory */
     BaseTypeFactory *set_factory(BaseTypeFactory *factory)
     {
@@ -255,6 +267,40 @@ public:
     string filename();
     void filename(const string &fn);
 
+    /// Get the DAP major version as sent by the client
+    int get_dap_major() const { return d_dap_major; }
+    /// Get the DAP minor version as sent by the client
+    int get_dap_minor() const { return d_dap_minor; }
+
+    /// Set the DAP major version (typically using info from the client)
+    void set_dap_major(int p) { d_dap_major = p; }
+    /// Set the DAP minor version (typically using info from the client)
+    void set_dap_minor(int p) { d_dap_minor = p; }
+
+    void set_dap_version(const string &version_string);
+
+    /// Get the DAP major version as sent by the client
+    int get_client_dap_major() const { return d_client_dap_major; }
+    /// Get the DAP minor version as sent by the client
+    int get_client_dap_minor() const { return d_client_dap_minor; }
+
+    /// Set the DAP major version (typically using info from the client)
+    void set_client_dap_major(int p) { d_client_dap_major = p; }
+    /// Set the DAP minor version (typically using info from the client)
+    void set_client_dap_minor(int p) { d_client_dap_minor = p; }
+
+    void set_client_dap_version(const string &version_string);
+
+    /// Get the URL that will return this DDS/DDX/DataThing
+    string get_request_xml_base() const { return d_request_xml_base; }
+
+    /// @see get_request_xml_base
+    void set_request_xml_base(const string &xb) { d_request_xml_base = xb; }
+
+    string container_name() ;
+    void container_name( const string &cn ) ;
+    Structure *container() ;
+
     void add_var(BaseType *bt);
 
     /// Removes a variable from the DDS.
@@ -264,7 +310,7 @@ public:
     BaseType *var(const string &n, BaseType::btp_stack *s = 0);
     int num_var();
 
-    /// Return an iterator
+    /// Return an iterator to the first variable
     Vars_iter var_begin();
     /// Return a reverse iterator
     Vars_riter var_rbegin();
@@ -289,13 +335,17 @@ public:
     void parse(string fname);
     void parse(int fd);
     void parse(FILE *in = stdin);
-
+    //#if FILE_METHODS
     void print(FILE *out);
+    //#endif
     void print(ostream &out);
+    //#if FILE_METHODS
     void print_constrained(FILE *out);
+    //#endif
     void print_constrained(ostream &out);
-
+    //#if FILE_METHODS
     void print_xml(FILE *out, bool constrained, const string &blob);
+    //#endif
     void print_xml(ostream &out, bool constrained, const string &blob);
 
     void mark_all(bool state);
