@@ -30,6 +30,9 @@
 #include "Error.h"
 #endif
 
+namespace libdap
+{
+
 /** Thrown when the DDX response cannot be parsed.. */
 class DDXParseFailed : public Error
 {
@@ -41,4 +44,6 @@ public:
     {}
 };
 
+} // namespace libdap
+
 #endif // ddx_exceptions_h
