@@ -37,7 +37,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: DODSFilter.cc 18798 2008-05-31 02:26:22Z pwest $"
+    {"$Id: DODSFilter.cc 19948 2008-12-03 23:51:12Z jimg $"
     };
 
 #include <signal.h>
@@ -606,6 +606,7 @@ DODSFilter::get_timeout() const
     return d_timeout;
 }
 
+//#if FILE_METHODS
 /** Use values of this instance to establish a timeout alarm for the server.
     If the timeout value is zero, do nothing.
 
@@ -629,6 +630,7 @@ DODSFilter::establish_timeout(FILE *stream) const
     }
 #endif
 }
+//#endif
 
 // FIXME
 void
@@ -710,6 +712,7 @@ DODSFilter::send_version_info() const
     do_version(d_cgi_ver, get_dataset_version());
 }
 
+//#if FILE_METHODS
 /** This function formats and prints an ASCII representation of a
     DAS on stdout.  This has the effect of sending the DAS object
     back to the client program.
@@ -738,7 +741,7 @@ DODSFilter::send_das(FILE *out, DAS &das, const string &anc_location,
     }
     fflush(out) ;
 }
-
+//#endif
 /** This function formats and prints an ASCII representation of a
     DAS on stdout.  This has the effect of sending the DAS object
     back to the client program.
@@ -772,9 +775,10 @@ void
 DODSFilter::send_das(DAS &das, const string &anc_location,
                      bool with_mime_headers) const
 {
-    send_das(stdout, das, anc_location, with_mime_headers);
+    send_das(cout, das, anc_location, with_mime_headers);
 }
 
+//#if FILE_METHODS
 /** This function formats and prints an ASCII representation of a
     DDS on stdout.  When called by a CGI program, this has the
     effect of sending a DDS object back to the client
@@ -821,7 +825,7 @@ DODSFilter::send_dds(FILE *out, DDS &dds, ConstraintEvaluator &eval,
 
     fflush(out) ;
 }
-
+//#endif
 /** This function formats and prints an ASCII representation of a
     DDS on stdout.  When called by a CGI program, this has the
     effect of sending a DDS object back to the client
@@ -874,9 +878,10 @@ DODSFilter::send_dds(DDS &dds, ConstraintEvaluator &eval,
                      bool constrained, const string &anc_location,
                      bool with_mime_headers) const
 {
-    send_dds(stdout, dds, eval, constrained, anc_location, with_mime_headers);
+    send_dds(cout, dds, eval, constrained, anc_location, with_mime_headers);
 }
 
+//#if FILE_METHODS
 // 'lmt' unused. Should it be used to supply a LMT or removed from the
 // method? jhrg 8/9/05
 void
@@ -895,13 +900,13 @@ DODSFilter::functional_constraint(BaseType &var, DDS &dds,
 
     try {
         // In the following call to serialize, suppress CE evaluation.
-        var.serialize(d_dataset, eval, dds, m, false);
+        var.serialize(eval, dds, m, false);
     }
     catch (Error &e) {
         throw;
     }
 }
-
+//#endif
 // 'lmt' unused. Should it be used to supply a LMT or removed from the
 // method? jhrg 8/9/05
 void
@@ -920,13 +925,13 @@ DODSFilter::functional_constraint(BaseType &var, DDS &dds,
 
     try {
         // In the following call to serialize, suppress CE evaluation.
-        var.serialize(d_dataset, eval, dds, m, false);
+        var.serialize(eval, dds, m, false);
     }
     catch (Error &e) {
         throw;
     }
 }
-
+//#if FILE_METHODS
 void
 DODSFilter::dataset_constraint(DDS & dds, ConstraintEvaluator & eval,
                                FILE * out) const
@@ -944,13 +949,14 @@ DODSFilter::dataset_constraint(DDS & dds, ConstraintEvaluator & eval,
         for (DDS::Vars_iter i = dds.var_begin(); i != dds.var_end(); i++)
             if ((*i)->send_p()) {
                 DBG(cerr << "Sending " << (*i)->name() << endl);
-                (*i)->serialize(d_dataset, eval, dds, m, true);
+                (*i)->serialize(eval, dds, m, true);
             }
     }
     catch (Error & e) {
         throw;
     }
 }
+//#endif
 
 void
 DODSFilter::dataset_constraint(DDS & dds, ConstraintEvaluator & eval,
@@ -969,14 +975,14 @@ DODSFilter::dataset_constraint(DDS & dds, ConstraintEvaluator & eval,
         for (DDS::Vars_iter i = dds.var_begin(); i != dds.var_end(); i++)
             if ((*i)->send_p()) {
                 DBG(cerr << "Sending " << (*i)->name() << endl);
-                (*i)->serialize(d_dataset, eval, dds, m, true);
+                (*i)->serialize(eval, dds, m, true);
             }
     }
     catch (Error & e) {
         throw;
     }
 }
-
+//#if FILE_METHODS
 /** Send the data in the DDS object back to the client program. The data is
     encoded using a Marshaller, and enclosed in a MIME document which is all sent
     to \c data_stream. If this is being called from a CGI, \c data_stream is
@@ -1013,7 +1019,7 @@ DODSFilter::send_data(DDS & dds, ConstraintEvaluator & eval,
     dds.set_timeout(d_timeout);
 
     eval.parse_constraint(d_ce, dds);   // Throws Error if the ce doesn't
-					// parse. 
+					// parse.
 
     dds.tag_nested_sequences(); // Tag Sequences as Parent or Leaf node.
 
@@ -1070,7 +1076,7 @@ DODSFilter::send_data(DDS & dds, ConstraintEvaluator & eval,
 
     fflush(data_stream);
 }
-
+//#endif
 /** Send the data in the DDS object back to the client program. The data is
     encoded using a Marshaller, and enclosed in a MIME document which is all sent
     to \c data_stream. If this is being called from a CGI, \c data_stream is
@@ -1107,7 +1113,7 @@ DODSFilter::send_data(DDS & dds, ConstraintEvaluator & eval,
     dds.set_timeout(d_timeout);
 
     eval.parse_constraint(d_ce, dds);   // Throws Error if the ce doesn't
-					// parse. 
+					// parse.
 
     dds.tag_nested_sequences(); // Tag Sequences as Parent or Leaf node.
 
@@ -1165,6 +1171,7 @@ DODSFilter::send_data(DDS & dds, ConstraintEvaluator & eval,
     data_stream << flush ;
 }
 
+//#if FILE_METHODS
 /** Send the DDX response. The DDX never contains data, instead it holds a
     reference to a Blob response which is used to get the data values. The
     DDS and DAS objects are built using code that already exists in the
@@ -1202,7 +1209,7 @@ DODSFilter::send_ddx(DDS &dds, ConstraintEvaluator &eval, FILE *out,
         dds.print_xml(out, !d_ce.empty(), d_url + ".blob?" + d_ce);
     }
 }
-
+//#endif
 /** Send the DDX response. The DDX never contains data, instead it holds a
     reference to a Blob response which is used to get the data values. The
     DDS and DAS objects are built using code that already exists in the
@@ -1240,7 +1247,7 @@ DODSFilter::send_ddx(DDS &dds, ConstraintEvaluator &eval, ostream &out,
         dds.print_xml(out, !d_ce.empty(), d_url + ".blob?" + d_ce);
     }
 }
-
+//#if FILE_METHODS
 /** Write the BLOB response to the client.
     @param dds Use the variables in this DDS to generate the BLOB response.
     @param out Dump the response to this FILE pointer.
@@ -1303,6 +1310,6 @@ DODSFilter::send_blob(DDS &, FILE *, bool)
     }
 #endif
 }
-
+//#endif
 } // namespace libdap
 
