@@ -35,7 +35,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: DataDDS.cc 17002 2007-08-27 19:16:51Z pwest $"
+    {"$Id: DataDDS.cc 17856 2008-02-02 21:25:59Z pwest $"
     };
 
 
@@ -49,6 +49,8 @@ static char rcsid[] not_used =
 
 using namespace std;
 
+namespace libdap {
+
 // private
 
 /** Parse the version string. A string that does not parse causes the
@@ -166,3 +168,5 @@ DataDDS::DataDDS(BaseTypeFactory *factory, const string &n, const string &v,
     m_protocol_string_to_numbers();
 }
 
+} // namespace libdap
+
