@@ -35,7 +35,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: Error.cc 18315 2008-03-03 20:14:44Z jimg $"
+    {"$Id: Error.cc 18940 2008-06-25 19:22:37Z jimg $"
     };
 
 #include <cstdio>
@@ -224,7 +224,7 @@ Error::print(FILE *out) const
     that can be used to send and receive an Error object over the network in
     a MIME document.
 
-    @param out A reference to the output stream on which the Error object is to
+    @param strm A reference to the output stream on which the Error object is to
     be rendered. */
 void
 Error::print(ostream &strm) const
