@@ -39,7 +39,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: Float32.cc 18315 2008-03-03 20:14:44Z jimg $"
+    {"$Id: Float32.cc 20518 2009-03-05 23:39:46Z jimg $"
     };
 
 #include "Float32.h"
@@ -67,6 +67,17 @@ Float32::Float32(const string &n)
         : BaseType(n, dods_float32_c)
 {}
 
+/** The Float32 server-side constructor accepts the name of the variable and
+    the dataset name from which this instance is created.
+
+    @param n A string containing the name of the variable to be created.
+    @param d A string containing the name of the dataset from which this
+    variable is created
+*/
+Float32::Float32(const string &n, const string &d)
+        : BaseType(n, d, dods_float32_c)
+{}
+
 Float32::Float32(const Float32 &copy_from) : BaseType(copy_from)
 {
     _buf = copy_from._buf;
@@ -98,16 +109,16 @@ Float32::width()
 }
 
 bool
-Float32::serialize(const string &dataset, ConstraintEvaluator &eval, DDS &dds,
+Float32::serialize(ConstraintEvaluator &eval, DDS &dds,
                    Marshaller &m, bool ce_eval)
 {
     dds.timeout_on();
 
     if (!read_p())
-        read(dataset);  // read() throws Error and InternalErr
+        read();  // read() throws Error and InternalErr
 
 #if EVAL
-    if (ce_eval && !eval.eval_selection(dds, dataset))
+    if (ce_eval && !eval.eval_selection(dds, dataset()))
         return true;
 #endif
 
@@ -178,7 +189,7 @@ Float32::value() const
 {
     return _buf;
 }
-
+//#if FILE_METHODS
 void
 Float32::print_val(FILE *out, string space, bool print_decl_p)
 {
@@ -192,7 +203,7 @@ Float32::print_val(FILE *out, string space, bool print_decl_p)
     else
         fprintf(out, "%.6g", _buf) ;
 }
-
+//#endif
 void
 Float32::print_val(ostream &out, string space, bool print_decl_p)
 {
@@ -208,19 +219,19 @@ Float32::print_val(ostream &out, string space, bool print_decl_p)
 }
 
 bool
-Float32::ops(BaseType *b, int op, const string &dataset)
+Float32::ops(BaseType *b, int op)
 {
     // Get this instance's value
-    if (!read_p() && !read(dataset)) {
+    if (!read_p() && !read()) {
         // Jose Garcia Since the read method is virtual and
-        // implemented outside libdap++ if we can not read the data
+        // implemented outside libdap++ if we cannot read the data
         // that is the problem of whomever wrote the implementation of
         // read and therefore it is an internal error.
         throw InternalErr(__FILE__, __LINE__, "This value not read!");
     }
 
     // Extract the second arg's value.
-    if (!b->read_p() && !b->read(dataset)) {
+    if (!b || !b->read_p() && !b->read()) {
         throw InternalErr(__FILE__, __LINE__, "This value not read!");
     }
 
