@@ -38,7 +38,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: Float64.cc 18315 2008-03-03 20:14:44Z jimg $"
+    {"$Id: Float64.cc 19948 2008-12-03 23:51:12Z jimg $"
     };
 
 #include <iomanip>
@@ -69,6 +69,17 @@ Float64::Float64(const string &n)
         : BaseType(n, dods_float64_c)
 {}
 
+/** The Float64 server-side constructor accepts the name of the variable and
+    the dataset name from which this instance is created.
+
+    @param n A string containing the name of the variable to be created.
+    @param d A string containing the name of the dataset from which this
+    variable is created
+*/
+Float64::Float64(const string &n, const string &d)
+        : BaseType(n, d, dods_float64_c)
+{}
+
 Float64::Float64(const Float64 &copy_from) : BaseType(copy_from)
 {
     _buf = copy_from._buf;
@@ -100,16 +111,16 @@ Float64::width()
 }
 
 bool
-Float64::serialize(const string &dataset, ConstraintEvaluator &eval, DDS &dds,
+Float64::serialize(ConstraintEvaluator &eval, DDS &dds,
                    Marshaller &m, bool ce_eval)
 {
     dds.timeout_on();
 
     if (!read_p())
-        read(dataset);  // read() throws Error and InternalErr
+        read();  // read() throws Error and InternalErr
 
 #if EVAL
-    if (ce_eval && !eval.eval_selection(dds, dataset))
+    if (ce_eval && !eval.eval_selection(dds, dataset()))
         return true;
 #endif
 
@@ -179,7 +190,7 @@ Float64::set_value(dods_float64 val)
 
     return true;
 }
-
+//#if FILE_METHODS
 void
 Float64::print_val(FILE *out, string space, bool print_decl_p)
 {
@@ -193,7 +204,7 @@ Float64::print_val(FILE *out, string space, bool print_decl_p)
     else
         fprintf(out, "%.15g", _buf) ;
 }
-
+//#endif
 void
 Float64::print_val(ostream &out, string space, bool print_decl_p)
 {
@@ -209,23 +220,23 @@ Float64::print_val(ostream &out, string space, bool print_decl_p)
 }
 
 bool
-Float64::ops(BaseType *b, int op, const string &dataset)
+Float64::ops(BaseType *b, int op)
 {
     // Extract the Byte arg's value.
-    if (!read_p() && !read(dataset)) {
+    if (!read_p() && !read()) {
         // Jose Garcia
         // Since the read method is virtual and implemented outside
-        // libdap++ if we can not read the data that is the problem
+        // libdap++ if we cannot read the data that is the problem
         // of the user or of whoever wrote the surrogate library
         // implemeting read therefore it is an internal error.
         throw InternalErr(__FILE__, __LINE__, "This value not read!");
     }
 
     // Extract the second arg's value.
-    if (!b->read_p() && !b->read(dataset)) {
+    if (!b->read_p() && !b->read()) {
         // Jose Garcia
         // Since the read method is virtual and implemented outside
-        // libdap++ if we can not read the data that is the problem
+        // libdap++ if we cannot read the data that is the problem
         // of the user or of whoever wrote the surrogate library
         // implemeting read therefore it is an internal error.
         throw InternalErr(__FILE__, __LINE__, "This value not read!");
