@@ -50,6 +50,9 @@
 #include "Grid.h"
 #endif
 
+namespace libdap
+{
+
 enum relop {
     dods_nop_op,
     dods_greater_op,
@@ -103,6 +106,10 @@ public:
               const relop op1, const double value2, const relop op2);
     //@}
 
+    virtual ~GSEClause() {
+    	delete d_map; d_map = 0;
+    }
+    
     bool OK() const;
 
     /** @name Accessors */
@@ -130,5 +137,7 @@ public:
     //@}
 };
 
+} // namespace libdap
+
 #endif // _gseclause_h
 
