@@ -78,6 +78,21 @@ Grid::_duplicate(const Grid &s)
 Grid::Grid(const string &n) : Constructor(n, dods_grid_c), _array_var(0)
 {}
 
+/** The Grid server-side constructor requires the name of the variable
+    to be created and the dataset name from which this variable is created.
+    Used when creating variables on the server side.
+
+    @param n A string containing the name of the variable to be
+    created.
+    @param d A string containing the name of the dataset from which this
+    variable is being created.
+
+    @brief The Grid constructor.
+*/
+Grid::Grid(const string &n, const string &d)
+    : Constructor(n, d, dods_grid_c), _array_var(0)
+{}
+
 /** @brief The Grid copy constructor. */
 Grid::Grid(const Grid &rhs) : Constructor(rhs)
 {
@@ -131,6 +146,9 @@ Grid::element_count(bool leaves)
             j += (*j)->element_count(leaves);
         }
 
+		if (!get_array())
+			throw InternalErr(__FILE__, __LINE__, "No Grid arry!");
+
         i += get_array()->element_count(leaves);
         return i;
     }
@@ -185,27 +203,27 @@ Grid::width()
 }
 
 void
-Grid::intern_data(const string &dataset, ConstraintEvaluator &eval, DDS &dds)
+Grid::intern_data(ConstraintEvaluator &eval, DDS &dds)
 {
     dds.timeout_on();
 
     if (!read_p())
-        read(dataset);  // read() throws Error and InternalErr
+        read();  // read() throws Error and InternalErr
 
     dds.timeout_off();
 
     if (_array_var->send_p())
-        _array_var->intern_data(dataset, eval, dds);
+        _array_var->intern_data(eval, dds);
 
     for (Map_iter i = _map_vars.begin(); i != _map_vars.end(); i++) {
         if ((*i)->send_p()) {
-            (*i)->intern_data(dataset, eval, dds);
+            (*i)->intern_data(eval, dds);
         }
     }
 }
 
 bool
-Grid::serialize(const string &dataset, ConstraintEvaluator &eval, DDS &dds,
+Grid::serialize(ConstraintEvaluator &eval, DDS &dds,
                 Marshaller &m, bool ce_eval)
 {
     dds.timeout_on();
@@ -215,21 +233,21 @@ Grid::serialize(const string &dataset, ConstraintEvaluator &eval, DDS &dds,
     // implement this as a selection function.
 
     if (!read_p())
-        read(dataset);  // read() throws Error and InternalErr
+        read();  // read() throws Error and InternalErr
 
 #if EVAL
-    if (ce_eval && !eval.eval_selection(dds, dataset))
+    if (ce_eval && !eval.eval_selection(dds, dataset()))
         return true;
 #endif
 
     dds.timeout_off();
 
     if (_array_var->send_p())
-        _array_var->serialize(dataset, eval, dds, m, false);
+        _array_var->serialize(eval, dds, m, false);
 
     for (Map_iter i = _map_vars.begin(); i != _map_vars.end(); i++) {
         if ((*i)->send_p()) {
-            (*i)->serialize(dataset, eval, dds, m, false);
+            (*i)->serialize(eval, dds, m, false);
         }
     }
 
@@ -365,7 +383,11 @@ Grid::array_var()
 Array *
 Grid::get_array()
 {
-    return dynamic_cast<Array*>(_array_var);
+    Array *a = dynamic_cast<Array*>(_array_var);
+    if (a)
+        return a;
+    else
+        throw InternalErr(__FILE__, __LINE__, "bad Cast");
 }
 
 /** @brief Returns an iterator referencing the first Map vector. */
@@ -509,7 +531,7 @@ Grid::clear_constraint()
     for (Map_iter m = map_begin(); m != map_end(); ++m)
         dynamic_cast<Array&>(*(*m)).clear_constraint();
 }
-
+//#if FILE_METHODS
 void
 Grid::print_decl(FILE *out, string space, bool print_semi,
                  bool constraint_info, bool constrained)
@@ -579,7 +601,7 @@ Grid::print_decl(FILE *out, string space, bool print_semi,
 exit:
     return;
 }
-
+//#endif
 void
 Grid::print_decl(ostream &out, string space, bool print_semi,
                  bool constraint_info, bool constrained)
@@ -591,7 +613,7 @@ Grid::print_decl(ostream &out, string space, bool print_semi,
     // the case where the projection removes all but one component; the
     // resulting object is a simple array.
     //
-    // I replaced the 'true' with the value of 'print_semi' passed in by the 
+    // I replaced the 'true' with the value of 'print_semi' passed in by the
     // caller. This fixes an issue with the intern_data tests and does not
     // seem to break anything else. jhrg 11/9/07
     int projection = components(true);
@@ -604,8 +626,8 @@ Grid::print_decl(ostream &out, string space, bool print_semi,
 
         goto exit;  // Skip end material.
     }
-    // If there are M (< N) componets (Array and Maps combined) in a N
-    // component Grid, send the M components as elements of a Struture.
+    // If there are M (< N) components (Array and Maps combined) in a N
+    // component Grid, send the M components as elements of a Structure.
     // This will preserve the grouping without violating the rules for a
     // Grid.
     else if (constrained && !projection_yields_grid()) {
@@ -654,14 +676,16 @@ exit:
     return;
 }
 
+//#if FILE_METHODS
 class PrintMapField : public unary_function<BaseType *, void>
 {
     FILE *d_out;
     string d_space;
     bool d_constrained;
+    string d_tag;
 public:
-    PrintMapField(FILE *o, string s, bool c)
-            : d_out(o), d_space(s), d_constrained(c)
+    PrintMapField(FILE *o, string s, bool c, const string &t = "Map")
+            : d_out(o), d_space(s), d_constrained(c), d_tag(t)
     {}
 
     void operator()(BaseType *btp)
@@ -669,7 +693,7 @@ public:
         Array *a = dynamic_cast<Array*>(btp);
         if (!a)
             throw InternalErr(__FILE__, __LINE__, "Expected an Array.");
-        a->print_as_map_xml(d_out, d_space, d_constrained);
+        a->print_xml_core(d_out, d_space, d_constrained, d_tag);
     }
 };
 
@@ -677,32 +701,74 @@ void
 Grid::print_xml(FILE *out, string space, bool constrained)
 {
     if (constrained && !send_p())
-        return;
+         return;
 
-    fprintf(out, "%s<Grid", space.c_str());
-    if (!name().empty())
-        fprintf(out, " name=\"%s\"", id2xml(name()).c_str());
+     // If we are printing the declaration of a constrained Grid then check for
+     // the case where the projection removes all but one component; the
+     // resulting object is a simple array.
+     //
+     // I replaced the 'true' with the value of 'print_semi' passed in by the
+     // caller. This fixes an issue with the intern_data tests and does not
+     // seem to break anything else. jhrg 11/9/07
+     int projection = components(true);
+     if (constrained && projection == 1) {
+         get_attr_table().print_xml(out, space + "    ", constrained);
 
-    fprintf(out, ">\n");
+         get_array()->print_xml(out, space + "    ", constrained);
 
-    get_attr_table().print_xml(out, space + "    ", constrained);
+         for_each(map_begin(), map_end(),
+                  PrintMapField(out, space + "    ", constrained, "Array"));
+     }
+     // If there are M (< N) components (Array and Maps combined) in a N
+     // component Grid, send the M components as elements of a Structure.
+     // This will preserve the grouping without violating the rules for a
+     // Grid.
+     else if (constrained && !projection_yields_grid()) {
+         fprintf(out, "%s<Structure", space.c_str());
+         if (!name().empty())
+             fprintf(out, " name=\"%s\"", id2xml(name()).c_str());
 
-    get_array()->print_xml(out, space + "    ", constrained);
+         fprintf(out, ">\n");
 
-    for_each(map_begin(), map_end(),
-             PrintMapField(out, space + "    ", constrained));
+         get_attr_table().print_xml(out, space + "    ", constrained);
 
-    fprintf(out, "%s</Grid>\n", space.c_str());
+         get_array()->print_xml(out, space + "    ", constrained);
+
+         for_each(map_begin(), map_end(),
+                  PrintMapField(out, space + "    ", constrained, "Array"));
+
+         fprintf(out, "%s</Structure>\n", space.c_str());
+     }
+     else {
+         // The number of elements in the (projected) Grid must be such that
+         // we have a valid Grid object; send it as such.
+         fprintf(out, "%s<Grid", space.c_str());
+         if (!name().empty())
+             fprintf(out, " name=\"%s\"", id2xml(name()).c_str());
+
+         fprintf(out, ">\n");
+
+         get_attr_table().print_xml(out, space + "    ", constrained);
+
+         get_array()->print_xml(out, space + "    ", constrained);
+
+         for_each(map_begin(), map_end(),
+                  PrintMapField(out, space + "    ", constrained));
+
+         fprintf(out, "%s</Grid>\n", space.c_str());
+     }
 }
+//#endif
 
 class PrintMapFieldStrm : public unary_function<BaseType *, void>
 {
     ostream &d_out;
     string d_space;
     bool d_constrained;
+    string d_tag;
 public:
-    PrintMapFieldStrm(ostream &o, string s, bool c)
-            : d_out(o), d_space(s), d_constrained(c)
+    PrintMapFieldStrm(ostream &o, string s, bool c, const string &t = "Map")
+            : d_out(o), d_space(s), d_constrained(c), d_tag(t)
     {}
 
     void operator()(BaseType *btp)
@@ -710,7 +776,7 @@ public:
         Array *a = dynamic_cast<Array*>(btp);
         if (!a)
             throw InternalErr(__FILE__, __LINE__, "Expected an Array.");
-        a->print_as_map_xml(d_out, d_space, d_constrained);
+        a->print_xml_core(d_out, d_space, d_constrained, d_tag);
     }
 };
 
@@ -720,22 +786,63 @@ Grid::print_xml(ostream &out, string space, bool constrained)
     if (constrained && !send_p())
         return;
 
-    out << space << "<Grid" ;
-    if (!name().empty())
-	out << " name=\"" << id2xml(name()) << "\"" ;
+    // If we are printing the declaration of a constrained Grid then check for
+    // the case where the projection removes all but one component; the
+    // resulting object is a simple array.
+    //
+    // I replaced the 'true' with the value of 'print_semi' passed in by the
+    // caller. This fixes an issue with the intern_data tests and does not
+    // seem to break anything else. jhrg 11/9/07
+    int projection = components(true);
+    if (constrained && projection == 1) {
+        get_attr_table().print_xml(out, space + "    ", constrained);
 
-    out << ">\n" ;
+        get_array()->print_xml(out, space + "    ", constrained);
 
-    get_attr_table().print_xml(out, space + "    ", constrained);
+        for_each(map_begin(), map_end(),
+                 PrintMapFieldStrm(out, space + "    ", constrained, "Array"));
+    }
+    // If there are M (< N) components (Array and Maps combined) in a N
+    // component Grid, send the M components as elements of a Structure.
+    // This will preserve the grouping without violating the rules for a
+    // Grid.
+    else if (constrained && !projection_yields_grid()) {
+        out << space << "<Structure" ;
+        if (!name().empty())
+            out << " name=\"" << id2xml(name()) << "\"" ;
 
-    get_array()->print_xml(out, space + "    ", constrained);
+        out << ">\n" ;
 
-    for_each(map_begin(), map_end(),
-             PrintMapFieldStrm(out, space + "    ", constrained));
+        get_attr_table().print_xml(out, space + "    ", constrained);
 
-    out << space << "</Grid>\n" ;
+        get_array()->print_xml(out, space + "    ", constrained);
+
+        for_each(map_begin(), map_end(),
+                 PrintMapFieldStrm(out, space + "    ", constrained, "Array"));
+
+        out << space << "</Structure>\n" ;
+    }
+    else {
+        // The number of elements in the (projected) Grid must be such that
+        // we have a valid Grid object; send it as such.
+        out << space << "<Grid" ;
+        if (!name().empty())
+            out << " name=\"" << id2xml(name()) << "\"" ;
+
+        out << ">\n" ;
+
+        get_attr_table().print_xml(out, space + "    ", constrained);
+
+        get_array()->print_xml(out, space + "    ", constrained);
+
+        for_each(map_begin(), map_end(),
+                 PrintMapFieldStrm(out, space + "    ", constrained));
+
+        out << space << "</Grid>\n" ;
+    }
 }
 
+//#if FILE_METHODS
 void
 Grid::print_val(FILE *out, string space, bool print_decl_p)
 {
@@ -765,7 +872,7 @@ Grid::print_val(FILE *out, string space, bool print_decl_p)
     if (print_decl_p)
         fprintf(out, ";\n") ;
 }
-
+//#endif
 void
 Grid::print_val(ostream &out, string space, bool print_decl_p)
 {
@@ -776,7 +883,7 @@ Grid::print_val(ostream &out, string space, bool print_decl_p)
 
     // If we are printing a value on the client-side, projection_yields_grid
     // should not be called since we don't *have* a projection without a
-    // contraint. I think that if we are here and send_p() is not true, then
+    // Constraint. I think that if we are here and send_p() is not true, then
     // the value of this function should be ignored. 4/6/2000 jhrg
     bool pyg = projection_yields_grid(); // hack 12/1/99 jhrg
     if (pyg || !send_p())
