@@ -128,7 +128,8 @@ private:
 
 public:
 
-    Grid(const string &n = "");
+    Grid(const string &n);
+    Grid(const string &n, const string &d);
     Grid(const Grid &rhs);
     virtual ~Grid();
 
@@ -164,35 +165,37 @@ public:
 
     virtual void clear_constraint();
 
-    virtual void intern_data(const string &dataset, ConstraintEvaluator &eval,
-                             DDS &dds);
-    virtual bool serialize(const string &dataset, ConstraintEvaluator &eval,
-                           DDS &dds, Marshaller &m, bool ce_eval = true);
+    virtual void intern_data(ConstraintEvaluator &eval, DDS &dds);
+    virtual bool serialize(ConstraintEvaluator &eval, DDS &dds,
+			   Marshaller &m, bool ce_eval = true);
     virtual bool deserialize(UnMarshaller &um, DDS *dds, bool reuse = false);
 
     virtual unsigned int val2buf(void *buf, bool reuse = false);
 
     virtual unsigned int buf2val(void **val);
 
-    virtual void print_decl(FILE *out, string space = "    ",
-                            bool print_semi = true,
-                            bool constraint_info = false,
-                            bool constrained = false);
     virtual void print_decl(ostream &out, string space = "    ",
                             bool print_semi = true,
                             bool constraint_info = false,
                             bool constrained = false);
 
-    virtual void print_xml(FILE *out, string space = "    ",
-                           bool constrained = false);
     virtual void print_xml(ostream &out, string space = "    ",
                            bool constrained = false);
 
-    virtual void print_val(FILE *out, string space = "",
-                           bool print_decl_p = true);
     virtual void print_val(ostream &out, string space = "",
                            bool print_decl_p = true);
 
+    //#if FILE_METHODS
+    virtual void print_decl(FILE *out, string space = "    ",
+                            bool print_semi = true,
+                            bool constraint_info = false,
+                            bool constrained = false);
+    virtual void print_xml(FILE *out, string space = "    ",
+                           bool constrained = false);
+    virtual void print_val(FILE *out, string space = "",
+                           bool print_decl_p = true);
+    //#endif
+
     virtual bool check_semantics(string &msg, bool all = false);
 
     Map_iter map_begin() ;
