@@ -4,7 +4,7 @@
 // This file is part of libdap, A C++ implementation of the OPeNDAP Data
 // Access Protocol.
 
-// Copyright (c) 2002 OPeNDAP, Inc.
+// Copyright (c) 2002,2008 OPeNDAP, Inc.
 // Author: James Gallagher <jgallagher@opendap.org>
 //
 // This library is free software; you can redistribute it and/or
@@ -36,6 +36,10 @@
 #include <vector>
 #include <map>
 
+#ifndef _http_cache_table_h
+#include "HTTPCacheTable.h"
+#endif
+
 #ifndef _error_h
 #include "Error.h"
 #endif
@@ -44,6 +48,10 @@
 #include "InternalErr.h"
 #endif
 
+#ifndef _debug_h
+#include "debug.h"
+#endif
+
 // The private method HTTPCache::write_body() could, at one time, throw
 // ResponseTooBig to signal that while writing a response body it was found
 // to be bigger than the max_entry_size property. But I bagged that; the
@@ -62,20 +70,27 @@
 #include "SignalHandlerRegisteredErr.h"
 #endif
 
-const int CACHE_TABLE_SIZE = 1499;
+#define LOCK(m) pthread_mutex_lock((m))
+#define TRYLOCK(m) pthread_mutex_trylock((m))
+#define UNLOCK(m) pthread_mutex_unlock((m))
+#define INIT(m) pthread_mutex_init((m), 0)
+#define DESTROY(m) pthread_mutex_destroy((m))
 
 using namespace std;
 
 namespace libdap
 {
 
-/** Implements a single-user MT-safe HTTP 1.1 compliant (mostly) cache.
+// This function is exported so the test code can use it too.
+bool is_hop_by_hop_header(const string &header);
+
+/** Implements a multi-process MT-safe HTTP 1.1 compliant (mostly) cache.
 
     <i>Clients that run as users lacking a writable HOME directory MUST
     disable this cache. Use Connect::set_cache_enable(false).</i>
 
-    The design of this class was taken from the W3C libwww software. That
-    code was originally written by Henrik Frystyk Nielsen, Copyright MIT
+    The original design of this class was taken from the W3C libwww software, 
+    written by Henrik Frystyk Nielsen, Copyright MIT
     1995. See the file MIT_COPYRIGHT. This software is a complete rewrite in
     C++ with additional features useful to the DODS and OPeNDAP projects.
 
@@ -98,7 +113,7 @@ namespace libdap
     accessed, an extra locking mechanism is in place for `entries' which are
     accessed. If a thread accesses a entry, that response must be locked to
     prevent it from being updated until the thread tells the cache that it's
-    no longer using it. The methods get_cache_response() and
+    no longer using it. The method get_cache_response() and
     get_cache_response_body() both lock an entry; use
     release_cache_response() to release the lock. Entries are locked using a
     combination of a counter and a mutex. The following methods block when
@@ -109,94 +124,21 @@ namespace libdap
     get_conditional_request_headers() would only lock when an entry is in use
     for writing. But I haven't done that.)
 
-    @todo Because is_url_in_cache() and is_url_valid() are discrete, an
-    interface that combines the two might be easier to use. Or maybe if
-    is_url_valid() threw a special exception if the entry was missing.
-    Something to help clients deal with URLs that are removed from the cache
-    in between calls to the two methods.
-
-    @todo Change the entry locking scheme to distinguish between entries
-    accessed for reading and for writing.
-
-    @todo Test in MT software. Is the entry locking scheme good enough? The
-    current software throws an exception if there's an attempt to modify an
-    entry that is locked by another thread. Maybe it should block instead?
-    Maybe we should provide a tests to see if an update would block (one that
-    returns right away and one that blocks). Note: Rob Morris added tests for
-    MT-safety. 02/06/03 jhrg
-
-    @author James Gallagher <jgallagher@gso.uri.edu> */
+	@todo Update documentation: get_cache_response() now also serves as 
+	is_url_in_cache() and is_url_valid() should only be called after a locked
+	cached response is accessed using get_cahced_response(). These lock the
+	cache for reading. The methods cache_response() and update_response()
+	lock an entry for writing.
+	
+	@todo Check that the lock-for-write and lock-for-read work together since
+	it's possible that an entry in use might have a stream of readers and never
+	free the 'read-lock' thus blocking a writer.
+	
+    @author James Gallagher <jgallagher@opendap.org> */
 class HTTPCache
 {
-public:
-    /** A struct used to store information about responses in the
-    cache's volatile memory. 
-
-    About entry locking: An entry is locked using both a mutex and a
-    counter. The counter keeps track of how many clients are accessing a
-    given entry while the mutex provides a guarantee that updates to the
-    counter are MT-safe. In addition, the HTTPCache object maintains a
-    map which binds the FILE* returned to a client with a given entry.
-    This way the client can tell the HTTPCache object that it is done
-    with <code>FILE *response</code> and the class can arrange to update
-    the lock counter and mutex. */
-    struct CacheEntry
-    {
-        string url;  // Location
-        int hash;
-        int hits;  // Hit counts
-
-        string cachename;
-
-        string etag;
-        time_t lm;  // Last modified
-        time_t expires;
-        time_t date;  // From the response header.
-        time_t age;
-        time_t max_age;  // From Cache-Control
-
-        unsigned long size; // Size of cached entity body
-        bool range;  // Range is not currently supported. 10/02/02
-        // jhrg
-
-        time_t freshness_lifetime;
-        time_t response_time;
-        time_t corrected_initial_age;
-
-        bool must_revalidate;
-        bool no_cache;  // This field is not saved in the index.
-
-        int locked;
-        pthread_mutex_t lock ;
-
-    CacheEntry() : url(""), hash(-1), hits(0), cachename(""),
-                etag(""), lm(-1),
-                expires(-1), date(-1), age(-1), max_age(-1), size(0),
-                range(false), freshness_lifetime(0), response_time(0),
-                corrected_initial_age(0), must_revalidate(false),
-                no_cache(false), locked(0)
-    {}
-    };
-
-#ifdef WIN32
-    //  Declared private below for gcc.  There appears to be a
-    //  difference in public vs. private under gcc when objects
-    //  share the same source file (??).
-    //
-    // My guess is that this was a bug in older versions of gcc. I've made
-    // the functors classes (they were structs) and made them friends (so
-    // they can access private stuff). We should not need this any longer,
-    // but I'm hesitant to remove it since I cannot easily test with VC++.
-    // 01/23/04 jhrg
-    unsigned long d_max_entry_size; // Max individual entry size.
-
-    void remove_cache_entry(CacheEntry *entry);
-    bool stopGC() const;
-#endif
-
 private:
     string d_cache_root;
-    string d_cache_index;
     FILE *d_locked_open_file; // Lock for single process use.
 
     bool d_cache_enabled;
@@ -208,12 +150,8 @@ private:
     unsigned long d_total_size; // How much can we store?
     unsigned long d_folder_size; // How much of that is meta data?
     unsigned long d_gc_buffer; // How much memory needed as buffer?
-#ifndef WIN32  //  Declared public above for win32
     unsigned long d_max_entry_size; // Max individual entry size.
-#endif
-    unsigned long d_current_size;
     int d_default_expiration;
-    unsigned int d_block_size; // File block size.
 
     vector<string> d_cache_control;
     // these are values read from a request-directive Cache-Control header.
@@ -224,27 +162,12 @@ private:
     time_t d_max_stale;  // -1: not set, 0:any response, >0 max time.
     time_t d_min_fresh;
 
-    int d_new_entries;  // How many entries since index write?
-
     // Lock non-const methods (also ones that use the STL).
     pthread_mutex_t d_cache_mutex;
+    
+    HTTPCacheTable *d_http_cache_table;
 
-    // Typedefs for CacheTable. A CacheTable is a vector of vectors of
-    // CacheEntries. The outer vector is accessed using the hash value.
-    // Entries with matching hashes occupy successive positions in the inner
-    // vector (that's how hash collisions are resolved). Search the inner
-    // vector for a specific match.
-    typedef vector<CacheEntry *> CachePointers;
-    typedef CachePointers::iterator CachePointersIter;
-
-    // CACHE_TABLE_SIZE is used by the static function get_hash defined in
-    // HTTPCache.cc. The table is indexed by the various cache entries' hash
-    // code. 10/01/02 jhrg
-    typedef CachePointers *CacheTable[CACHE_TABLE_SIZE];
-
-    CacheTable d_cache_table;
-
-    map<FILE *, CacheEntry *> d_locked_entries;
+    // d_open_files is used by the interrupt handler to clean up
     vector<string> d_open_files;
 
     static HTTPCache *_instance;
@@ -252,78 +175,42 @@ private:
     friend class HTTPCacheTest; // Unit tests
     friend class HTTPCacheInterruptHandler;
 
-    // Functors used with STL algorithms
-
-    friend class DeleteExpired;
-    friend class DeleteByHits;
-    friend class DeleteCacheEntry;
-    friend class DeleteUnlockedCacheEntry;
-    friend class WriteOneCacheEntry;
-
     // Private methods
-
-    void clone(const HTTPCache &)
-    {}
-
-    HTTPCache(const HTTPCache &cache)
-    {
-        clone(cache);
+    HTTPCache(const HTTPCache &) {
+    	throw InternalErr(__FILE__, __LINE__, "Unimplemented");
+    }
+    HTTPCache() {
+    	throw InternalErr(__FILE__, __LINE__, "Unimplemented");
+    }
+    HTTPCache &operator=(const HTTPCache &) {
+    	throw InternalErr(__FILE__, __LINE__, "Unimplemented");
     }
 
-    HTTPCache()
-    {}
-
-    HTTPCache(string cache_root, bool force) throw(Error);
-
-    HTTPCache &operator=(const HTTPCache &rhs)
-    {
-        if (this != &rhs)
-            clone(rhs);
-        return *this;
-    }
+    HTTPCache(string cache_root, bool force);
 
     static void delete_instance(); // Run by atexit (hence static)
-
-    CacheEntry *cache_index_parse_line(const char *line);
-    bool cache_index_read();
-    bool cache_index_delete();
-
+    
     void set_cache_root(const string &root = "");
-
+    void create_cache_root(const string &cache_root);
+    
+    // These will go away when the cache can be used by multiple processes.
     bool get_single_user_lock(bool force = false);
     void release_single_user_lock();
-
-    void add_entry_to_cache_table(CacheEntry *e);
-    void remove_entry_from_cache_table(const string &url);
-    void parse_headers(CacheEntry *entry, const vector<string> &headers);
-    void calculate_time(CacheEntry *entry, time_t request_time);
-#ifndef WIN32  //  Declared public above for win32
-    void remove_cache_entry(CacheEntry *entry);
-#endif
-    CacheEntry *get_entry_from_cache_table(const string &url) const;
-    CacheEntry *get_entry_from_cache_table(int hash, const string &url) const;
+    
+    bool is_url_in_cache(const string &url);
 
     // I made these four methods so they could be tested by HTTPCacheTest.
-    // Otherwise they would be static functions in HTTPCache.cc. 10/01/02
-    // jhrg
+    // Otherwise they would be static functions. jhrg 10/01/02
     void write_metadata(const string &cachename, const vector<string> &headers);
     void read_metadata(const string &cachename, vector<string> &headers);
     int write_body(const string &cachename, const FILE *src);
     FILE *open_body(const string &cachename);
 
-    void create_cache_root(const string &cache_root);
-
-    string create_hash_directory(int hash);
-    void create_location(CacheEntry *entry);
-
-#ifndef WIN32  //  Declared public above for win32
     bool stopGC() const;
-#endif
     bool startGC() const;
 
-    void cache_index_write();
-
     void perform_garbage_collection();
+    void too_big_gc();
     void expired_gc();
     void hits_gc();
 
@@ -336,9 +223,6 @@ public:
     void set_cache_enabled(bool mode);
     bool is_cache_enabled() const;
 
-    void set_cache_protected(bool mode);
-    bool is_cache_protected() const;
-
     void set_cache_disconnected(CacheDisconnectedMode mode);
     CacheDisconnectedMode get_cache_disconnected() const;
 
@@ -360,18 +244,35 @@ public:
     void set_cache_control(const vector<string> &cc);
     vector<string> get_cache_control();
 
+    void lock_cache_interface() {
+    	DBG(cerr << "Locking interface... ");
+    	LOCK(&d_cache_mutex);
+    	DBGN(cerr << "Done" << endl);
+    }    	
+    void unlock_cache_interface() {
+    	DBG(cerr << "Unlocking interface... " );
+    	UNLOCK(&d_cache_mutex);
+    	DBGN(cerr << "Done" << endl);
+    }
+    
+    // This must lock for writing
     bool cache_response(const string &url, time_t request_time,
                         const vector<string> &headers, const FILE *body);
-    vector<string> get_conditional_request_headers(const string &url);
     void update_response(const string &url, time_t request_time,
                          const vector<string> &headers);
 
-    bool is_url_in_cache(const string &url);
+    // This is separate from get_cached_response() because often an invalid
+    // cache entry just needs a header update. That is best left to the HTTP
+    // Connection code.
     bool is_url_valid(const string &url);
-    FILE *get_cached_response(const string &url, vector<string> &headers);
+    
+    // Lock these for reading
+    vector<string> get_conditional_request_headers(const string &url);
     FILE *get_cached_response(const string &url, vector<string> &headers,
-			      string &cacheName);
-    FILE *get_cached_response_body(const string &url);
+			      			  string &cacheName);
+    FILE *get_cached_response(const string &url, vector<string> &headers);
+    FILE *get_cached_response(const string &url);
+
     void release_cached_response(FILE *response);
 
     void purge_cache();
