@@ -27,7 +27,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    { "$Id: HTTPConnect.cc 18763 2008-05-20 19:22:36Z jimg $"
+    { "$Id: HTTPConnect.cc 19864 2008-11-14 17:01:35Z jimg $"
     };
 
 #ifdef HAVE_UNISTD_H
@@ -111,6 +111,63 @@ static char *http_server_errors[SERVER_ERR_MAX - SERVER_ERR_MIN +1] =
         "HTTP Version Not Supported."
     };
 
+/** This function returns the ObjectType value that matches the given string.
+    Modified to include tests for the descriptions that use hyphens in addition
+    to underscores. 8/1/08 jhrg
+
+    @deprecated Use get_description_type instead - there are two other get_type()
+    functions in libdap.*/
+ObjectType
+get_type(const string &value)
+{
+    if (value == "dods_das" | value == "dods-das")
+        return dods_das;
+    else if (value == "dods_dds" | value == "dods-dds")
+        return dods_dds;
+    else if (value == "dods_data" | value == "dods-data")
+        return dods_data;
+    else if (value == "dods_error" | value == "dods-error")
+        return dods_error;
+    else if (value == "web_error" | value == "web-error")
+        return web_error;
+    else if (value == "dap4_ddx" | value == "dap4-ddx")
+        return dap4_ddx;
+    else if (value == "dap4_datax" | value == "dap4-datax")
+        return dap4_datax;
+    else if (value == "dap4_errorx" | value == "dap4-errorx")
+        return dap4_errorx;
+    else
+        return unknown_type;
+}
+
+/** This function returns the ObjectType value that matches the given string.
+    Modified to include tests for the descriptions that use hyphens in addition
+    to underscores. 8/1/08 jhrg
+
+    @param value Value from teh HTTP response header */
+ObjectType
+get_description_type(const string &value)
+{
+    if (value == "dods_das" | value == "dods-das")
+        return dods_das;
+    else if (value == "dods_dds" | value == "dods-dds")
+        return dods_dds;
+    else if (value == "dods_data" | value == "dods-data")
+        return dods_data;
+    else if (value == "dods_error" | value == "dods-error")
+        return dods_error;
+    else if (value == "web_error" | value == "web-error")
+        return web_error;
+    else if (value == "dap4_ddx" | value == "dap4-ddx")
+        return dap4_ddx;
+    else if (value == "dap4_datax" | value == "dap4-datax")
+        return dap4_datax;
+    else if (value == "dap4_errorx" | value == "dap4-errorx")
+        return dap4_errorx;
+    else
+        return unknown_type;
+}
+
 /** This function translates the HTTP status codes into error messages. It
     works for those code greater than or equal to 400. */
 static string
@@ -151,7 +208,7 @@ public:
             line >> value;
             downcase(value);
             DBG2(cout << name << ": " << value << endl);
-            type = get_type(value);
+            type = get_description_type(value);
         }
         // The second test (== "dods/0.0") tests if xopendap-server has already
         // been seen. If so, use that header in preference to the old
@@ -185,7 +242,7 @@ public:
             server = value;
         }
        	else if (name == "location:") {
-       	    string value; 
+       	    string value;
        	    line >> value;
        	    DBG2(cout << name << ": " << value << endl);
        	    location = value;
@@ -352,6 +409,16 @@ HTTPConnect::www_lib_init()
         curl_easy_setopt(d_curl, CURLOPT_SSL_VERIFYHOST, 0);
     }
 
+    // Look to see if cookies are turned on in the .dodsrc file. If so,
+    // activate here. We honor 'session cookies' (cookies without an
+    // expiration date) here so that session-base SSO systems will work as
+    // expected.  
+    if (!d_cookie_jar.empty()) {
+	DBG(cerr << "Setting the cookie jar to: " << d_cookie_jar << endl);
+        curl_easy_setopt(d_curl, CURLOPT_COOKIEJAR, d_cookie_jar.c_str());
+        curl_easy_setopt(d_curl, CURLOPT_COOKIESESSION, 1);
+    }
+
     if (www_trace) {
         cerr << "Curl version: " << curl_version() << endl;
         curl_easy_setopt(d_curl, CURLOPT_VERBOSE, 1);
@@ -387,7 +454,7 @@ public:
     url into the file pointed to by \c stream.
 
     @param url The URL to dereference.
-    @param stream The distination for the data; the caller can assume that
+    @param stream The destination for the data; the caller can assume that
     the body of the response can be found by reading from this pointer. A
     value/result parameter
     @param resp_hdrs Value/result parameter for the HTTP Response Headers.
@@ -509,7 +576,11 @@ HTTPConnect::url_uses_no_proxy_for(const string &url) throw()
     @param rcr A pointer to the RCReader object which holds configuration
     file information to be used by this virtual connection. */
 
-HTTPConnect::HTTPConnect(RCReader *rcr) : d_username(""), d_password("")
+HTTPConnect::HTTPConnect(RCReader *rcr) : d_username(""), d_password(""),
+  					  d_cookie_jar(""),
+					  d_dap_client_protocol_major(2), 
+					  d_dap_client_protocol_minor(0)
+
 {
     d_accept_deflate = rcr->get_deflate();
     d_rcr = rcr;
@@ -544,6 +615,8 @@ HTTPConnect::HTTPConnect(RCReader *rcr) : d_username(""), d_password("")
         d_http_cache->set_always_validate(d_rcr->get_always_validate() != 0);
     }
 
+    d_cookie_jar = rcr->get_cookie_jar();
+
     www_lib_init();  // This may throw either Error or InternalErr
 }
 
@@ -632,11 +705,11 @@ static char *
 get_tempfile_template(char *file_template)
 {
     char *c;
-    
+
 #ifdef WIN32
     // whitelist for a WIN32 directory
     Regex directory("[-a-zA-Z0-9_\\]*");
-	
+
     c = getenv("TEMP");
     if (c && directory.match(c, strlen(c)) && (access(getenv("TEMP"), 6) == 0))
     	goto valid_temp_directory;
@@ -647,7 +720,7 @@ get_tempfile_template(char *file_template)
 #else
 	// whitelist for a directory
 	Regex directory("[-a-zA-Z0-9_/]*");
-	
+
 	c = getenv("TMPDIR");
 	if (c && directory.match(c, strlen(c)) && (access(c, W_OK | R_OK) == 0))
     	goto valid_temp_directory;
@@ -662,13 +735,13 @@ get_tempfile_template(char *file_template)
 #endif  // WIN32
 
     c = ".";
-    
+
 valid_temp_directory:
 	// Sanitize allocation
 	int size = strlen(c) + strlen(file_template) + 2;
 	if (!size_ok(1, size))
 		throw Error("Bad temporary file name.");
-		
+
     char *temp = new char[size];
     strncpy(temp, c, size-2);
     strcat(temp, "/");
@@ -750,187 +823,99 @@ close_temp(FILE *s, const string &name)
     @exception InternalErr Thrown if a temporary file to hold the response
     could not be opened. */
 
-HTTPResponse * HTTPConnect::caching_fetch_url(const string &url) {
-	DBG(cerr << "Is this URL (" << url << ") in the cache?... ");
+HTTPResponse *
+HTTPConnect::caching_fetch_url(const string &url)
+{
+    DBG(cerr << "Is this URL (" << url << ") in the cache?... ");
 
-	vector<string> *headers = new vector<string>;
-	FILE *s = d_http_cache->get_cached_response(url, *headers);
-	if (!s) {
-		// url not in cache; get it and cache it
-		DBGN(cerr << "no; getting response and caching." << endl);
-		time_t now = time(0);
-		HTTPResponse *rs = plain_fetch_url(url);
-		d_http_cache->cache_response(url, now, *(rs->get_headers()),
-				rs->get_stream());
+    vector<string> *headers = new vector<string> ;
+    FILE *s = d_http_cache->get_cached_response(url, *headers);
+    if (!s) {
+        // url not in cache; get it and cache it
+        DBGN(cerr << "no; getting response and caching." << endl);
+        time_t now = time(0);
+        HTTPResponse *rs = plain_fetch_url(url);
+        d_http_cache->cache_response(url, now, *(rs->get_headers()),
+                rs->get_stream());
 
-		return rs;
-	}
-	else { // url in cache
-		DBGN(cerr << "yes... ");
+        return rs;
+    }
+    else { // url in cache
+        DBGN(cerr << "yes... ");
 
-		if (d_http_cache->is_url_valid(url)) { // url in cache and valid
-			DBGN(cerr << "and it's valid; using cached response." << endl);
-			HTTPCacheResponse *crs = new HTTPCacheResponse(s, 200, headers, d_http_cache);
-			return crs;
-		} 
-		else { // url in cache but not valid; validate
-			DBGN(cerr << "but it's not valid; validating... ");
+        if (d_http_cache->is_url_valid(url)) { // url in cache and valid
+            DBGN(cerr << "and it's valid; using cached response." << endl);
+            HTTPCacheResponse *crs =
+                    new HTTPCacheResponse(s, 200, headers, d_http_cache);
+            return crs;
+        }
+        else { // url in cache but not valid; validate
+            DBGN(cerr << "but it's not valid; validating... ");
 
-			d_http_cache->release_cached_response(s);
+            d_http_cache->release_cached_response(s);
 
-			vector<string> *resp_hdrs = new vector<string>;
-			vector<string> cond_hdrs =
-					d_http_cache->get_conditional_request_headers(url);
-			FILE *body = 0;
-			string dods_temp = get_temp_file(body);
-			time_t now = time(0); // When was the request made (now).
-			long http_status;
+            vector<string> *resp_hdrs = new vector<string> ;
+            vector<string> cond_hdrs =
+                    d_http_cache->get_conditional_request_headers(url);
+            FILE *body = 0;
+            string dods_temp = get_temp_file(body);
+            time_t now = time(0); // When was the request made (now).
+            long http_status;
 
-			try {
-				http_status = read_url(url, body, resp_hdrs, &cond_hdrs);
-				rewind(body);
-			}
-			catch (Error &e) {
-				close_temp(body, dods_temp);
-				throw;
-			}
+            try {
+                http_status = read_url(url, body, resp_hdrs, &cond_hdrs);
+                rewind(body);
+            }
+            catch (Error &e) {
+                close_temp(body, dods_temp);
+                throw ;
+            }
 
-			switch (http_status) {
-			case 200: { // New headers and new body
-				DBGN(cerr << "read a new response; caching." << endl);
+            switch (http_status) {
+                case 200: { // New headers and new body
+                    DBGN(cerr << "read a new response; caching." << endl);
 
-				d_http_cache->cache_response(url, now, *resp_hdrs, body);
-				HTTPResponse *rs = new HTTPResponse(body, http_status, resp_hdrs,
-						dods_temp);
+                    d_http_cache->cache_response(url, now, *resp_hdrs, body);
+                    HTTPResponse *rs = new HTTPResponse(body, http_status, resp_hdrs,
+                            dods_temp);
 
-				return rs;
-			}
+                    return rs;
+                }
 
-			case 304: { // Just new headers, use cached body
-				DBGN(cerr << "cached response valid; updating." << endl);
+                case 304: { // Just new headers, use cached body
+                    DBGN(cerr << "cached response valid; updating." << endl);
 
-				close_temp(body, dods_temp);
-				d_http_cache->update_response(url, now, *resp_hdrs);
+                    close_temp(body, dods_temp);
+                    d_http_cache->update_response(url, now, *resp_hdrs);
 
-				vector<string> *headers = new vector<string>;
-				FILE *hs = d_http_cache->get_cached_response(url, *headers);
-				HTTPCacheResponse *crs = new HTTPCacheResponse(hs, 304, headers, d_http_cache);
-				return crs;
-			}
+                    vector<string> *headers = new vector<string>;
+                    FILE *hs = d_http_cache->get_cached_response(url, *headers);
+                    HTTPCacheResponse *crs = new HTTPCacheResponse(hs, 304, headers, d_http_cache);
+                    return crs;
+                }
 
-			default: { // Oops.
-				close_temp(body, dods_temp);
-				if (http_status >= 400) {
-					string msg = "Error while reading the URL: ";
-					msg += url;
-					msg
-							+= ".\nThe OPeNDAP server returned the following message:\n";
-					msg += http_status_to_string(http_status);
-					throw Error(msg);
-				} else {
-					throw InternalErr(__FILE__, __LINE__,
-							"Bad response from the HTTP server: " + long_to_string(http_status));
-				}
-			}
+                default: { // Oops.
+                    close_temp(body, dods_temp);
+                    if (http_status >= 400) {
+                        string msg = "Error while reading the URL: ";
+                        msg += url;
+                        msg
+                        += ".\nThe OPeNDAP server returned the following message:\n";
+                        msg += http_status_to_string(http_status);
+                        throw Error(msg);
+                    }
+                    else {
+                        throw InternalErr(__FILE__, __LINE__,
+                                "Bad response from the HTTP server: " + long_to_string(http_status));
+                    }
+                }
+            }
+        }
+    }
 
-			}
-		}
-	}
-	
-	throw InternalErr(__FILE__, __LINE__, "Should never get here");
+    throw InternalErr(__FILE__, __LINE__, "Should never get here");
 }
 
-#if 0
-HTTPResponse * HTTPConnect::caching_fetch_url(const string &url) {
-	DBG(cerr << "Is this URL (" << url << ") in the cache?... ");
-
-	if (d_http_cache->is_url_in_cache(url)) { // url in cache
-		DBGN(cerr << "yes... ");
-
-		if (d_http_cache->is_url_valid(url)) { // url in cache and valid
-			DBGN(cerr << "and it's valid; using cached response." << endl);
-
-			vector<string> *headers = new vector<string>;
-			FILE *s = d_http_cache->get_cached_response(url, *headers);
-			HTTPCacheResponse *crs = new HTTPCacheResponse(s, 200, headers, d_http_cache);
-
-			return crs;
-		} else { // url in cache but not valid; validate
-			DBGN(cerr << "but it's not valid; validating... ");
-
-			// *** auto_ptr??? resp_hdrs not deleted! 10/10/03 jhrg
-			vector<string> *resp_hdrs = new vector<string>;
-			vector<string> cond_hdrs =
-					d_http_cache->get_conditional_request_headers(url);
-			FILE *body = 0;
-			string dods_temp = get_temp_file(body);
-			time_t now = time(0); // When was the request made (now).
-			long http_status;
-
-			try {
-				http_status = read_url(url, body, resp_hdrs, &cond_hdrs);
-				rewind(body);
-			}
-			catch (Error &e) {
-				close_temp(body, dods_temp);
-				throw;
-			}
-
-			switch (http_status) {
-			case 200: { // New headers and new body
-				DBGN(cerr << "read a new response; caching." << endl);
-
-				d_http_cache->cache_response(url, now, *resp_hdrs, body);
-				HTTPResponse *rs = new HTTPResponse(body, http_status, resp_hdrs,
-						dods_temp);
-
-				return rs;
-			}
-				break;
-
-			case 304: { // Just new headers, use cached body
-				DBGN(cerr << "cached response valid; updating." << endl);
-
-				close_temp(body, dods_temp);
-				d_http_cache->update_response(url, now, *resp_hdrs);
-
-				vector<string> *headers = new vector<string>;
-				FILE *s = d_http_cache->get_cached_response(url, *headers);
-				HTTPCacheResponse *crs = new HTTPCacheResponse(s, 304, headers, d_http_cache);
-				return crs;
-			}
-				break;
-
-			default: { // Oops.
-				close_temp(body, dods_temp);
-				if (http_status >= 400) {
-					string msg = "Error while reading the URL: ";
-					msg += url;
-					msg += ".\nThe OPeNDAP server returned the following message:\n";
-					msg += http_status_to_string(http_status);
-					throw Error(msg);
-				} else {
-					throw InternalErr(__FILE__, __LINE__,
-							"Bad response from the HTTP server: " + long_to_string(http_status));
-				}
-			}
-				break;
-			}
-		}
-	} else { // url not in cache; get it and cache it
-		DBGN(cerr << "no; getting response and caching." << endl);
-		time_t now = time(0);
-		HTTPResponse *rs = plain_fetch_url(url);
-		d_http_cache->cache_response(url, now, *(rs->get_headers()),
-				rs->get_stream());
-
-		return rs;
-	}
-
-	throw InternalErr(__FILE__, __LINE__, "Unexpected cache response.");
-}
-#endif
-
 /** Dereference a URL and load its body into a temporary file. This
     method ignores the HTTP cache.
 
@@ -1004,6 +989,44 @@ HTTPConnect::set_accept_deflate(bool deflate)
     }
 }
 
+/** Look for a certain header */
+class HeaderMatch : public unary_function<const string &, bool> {
+    const string &d_header;
+    public:
+        HeaderMatch(const string &header) : d_header(header) {}
+        bool operator()(const string &arg) { return arg.find(d_header) == 0; }
+};
+
+/** Set the <em>xdap_accept</em> property/HTTP-header. This sets the value
+    of the DAP which the client advertises to servers that it understands.
+    The information (client protocol major and minor versions) are recorded
+    in the instance and the information is sent to servers using the
+    XDAP-Accept HTTP request header.
+
+    @param major The dap client major protocol version
+    @param minor The dap client minor protocol version */
+void
+HTTPConnect::set_xdap_protocol(int major, int minor)
+{
+    // Look for, and remove if one exists, an XDAP-Accept header
+    vector<string>::iterator i;
+    i = find_if(d_request_headers.begin(), d_request_headers.end(),
+                HeaderMatch("XDAP-Accept:"));
+    if (i != d_request_headers.end())
+        d_request_headers.erase(i);
+
+    // Record and add the new header value
+    d_dap_client_protocol_major = major;
+    d_dap_client_protocol_minor = minor;
+    ostringstream xdap_accept;
+    xdap_accept << "XDAP-Accept: " << major << "." << minor;
+
+    d_request_headers.push_back(xdap_accept.str());
+
+    DBG(copy(d_request_headers.begin(), d_request_headers.end(),
+             ostream_iterator<string>(cerr, "\n")));
+}
+
 /** Set the credentials for responding to challenges while dereferencing
     URLs. Alternatively, these can be embedded in the URL. This method
     provides a way for clients of HTTPConnect to get credentials from users
