@@ -86,8 +86,13 @@ private:
     string d_password;  // extracted from URL
     string d_upstring;  // used to pass info into curl
 
+    string d_cookie_jar;
+
     vector<string> d_request_headers; // Request headers
 
+    int d_dap_client_protocol_major;
+    int d_dap_client_protocol_minor;
+
     void www_lib_init();
     long read_url(const string &url, FILE *stream, vector<string> *resp_hdrs,
                   const vector<string> *headers = 0);
@@ -100,8 +105,6 @@ private:
 
     void extract_auth_info(string &url);
 
-    // bool cond_fetch_url(const string &url, const vector<string> &headers);
-
     friend size_t save_raw_http_header(void *ptr, size_t size, size_t nmemb,
                                        void *http_connect);
     friend class HTTPConnectTest;
@@ -131,11 +134,23 @@ public:
 
     void set_credentials(const string &u, const string &p);
     void set_accept_deflate(bool defalte);
+    void set_xdap_protocol(int major, int minor);
+
+    /** Set the cookie jar. THis function sets the name of a file used to store 
+    cookies returned by servers. This will help with things like single 
+    sign on systems.
+
+    @param cookie_jar The pathname to the file that stores cookies. If this
+    is the empty string saving cookies is disabled. */
+    void set_cookie_jar(const string &cookie_jar)
+    {
+	d_cookie_jar = cookie_jar;
+    }
 
     /** Set the state of the HTTP cache. By default, the HTTP cache is
     enabled of disabled using the value of the \c USE_CACHE property in
     the \c .dodsrc file. Use this method to set the state from within a
-    program. 
+    program.
     @param enabled True to use the cache, False to disable. */
     void set_cache_enabled(bool enabled)
     {
@@ -152,6 +167,9 @@ public:
     HTTPResponse *fetch_url(const string &url);
 };
 
+ObjectType get_type(const string &value); // deprecated
+ObjectType get_description_type(const string &value);
+
 } // namespace libdap
 
 #endif // _httpconnect_h
