@@ -37,7 +37,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: Int16.cc 18315 2008-03-03 20:14:44Z jimg $"
+    {"$Id: Int16.cc 20518 2009-03-05 23:39:46Z jimg $"
     };
 
 #include "Int16.h"
@@ -54,9 +54,23 @@ using std::endl;
 
 namespace libdap {
 
+/** The Int16 constructor accepts the name of the variable to be created.
+
+    @param n A string containing the name of the variable to be created.
+*/
 Int16::Int16(const string &n) : BaseType(n, dods_int16_c)
 {}
 
+/** The Int16 server-side constructor accepts the name of the variable and
+    the dataset name from which this instance is created.
+
+    @param n A string containing the name of the variable to be created.
+    @param d A string containing the name of the dataset from which this
+    variable is created
+*/
+Int16::Int16(const string &n, const string &d) : BaseType(n, d, dods_int16_c)
+{}
+
 Int16::Int16(const Int16 &copy_from) : BaseType(copy_from)
 {
     _buf = copy_from._buf;
@@ -88,16 +102,16 @@ Int16::width()
 }
 
 bool
-Int16::serialize(const string &dataset, ConstraintEvaluator &eval, DDS &dds,
+Int16::serialize(ConstraintEvaluator &eval, DDS &dds,
                  Marshaller &m, bool ce_eval)
 {
     dds.timeout_on();
 
     if (!read_p())
-        read(dataset);  // read() throws Error and InternalErr
+        read();  // read() throws Error and InternalErr
 
 #if EVAL
-    if (ce_eval && !eval.eval_selection(dds, dataset))
+    if (ce_eval && !eval.eval_selection(dds, dataset()))
         return true;
 #endif
 
@@ -162,7 +176,7 @@ Int16::set_value(dods_int16 i)
 
     return true;
 }
-
+//#if FILE_METHODS
 void
 Int16::print_val(FILE *out, string space, bool print_decl_p)
 {
@@ -173,7 +187,7 @@ Int16::print_val(FILE *out, string space, bool print_decl_p)
     else
         fprintf(out, "%d", _buf) ;
 }
-
+//#endif
 void
 Int16::print_val(ostream &out, string space, bool print_decl_p)
 {
@@ -186,24 +200,24 @@ Int16::print_val(ostream &out, string space, bool print_decl_p)
 }
 
 bool
-Int16::ops(BaseType *b, int op, const string &dataset)
+Int16::ops(BaseType *b, int op)
 {
 
     // Extract the Byte arg's value.
-    if (!read_p() && !read(dataset)) {
+    if (!read_p() && !read()) {
         // Jose Garcia
         // Since the read method is virtual and implemented outside
-        // libdap++ if we can not read the data that is the problem
+        // libdap++ if we cannot read the data that is the problem
         // of the user or of whoever wrote the surrogate library
         // implemeting read therefore it is an internal error.
         throw InternalErr(__FILE__, __LINE__, "This value not read!");
     }
 
     // Extract the second arg's value.
-    if (!b->read_p() && !b->read(dataset)) {
+    if (!b || !b->read_p() && !b->read()) {
         // Jose Garcia
         // Since the read method is virtual and implemented outside
-        // libdap++ if we can not read the data that is the problem
+        // libdap++ if we cannot read the data that is the problem
         // of the user or of whoever wrote the surrogate library
         // implemeting read therefore it is an internal error.
         throw InternalErr(__FILE__, __LINE__, "This value not read!");
