@@ -37,7 +37,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: Int32.cc 18315 2008-03-03 20:14:44Z jimg $"
+    {"$Id: Int32.cc 19948 2008-12-03 23:51:12Z jimg $"
     };
 
 #include "Int32.h"
@@ -66,6 +66,17 @@ Int32::Int32(const string &n)
         : BaseType(n, dods_int32_c)
 {}
 
+/** The Int32 server-side constructor accepts the name of the variable and
+    the dataset name from which this instance is created.
+
+    @param n A string containing the name of the variable to be created.
+    @param d A string containing the name of the dataset from which this
+    variable is created
+*/
+Int32::Int32(const string &n, const string &d)
+        : BaseType(n, d, dods_int32_c)
+{}
+
 Int32::Int32(const Int32 &copy_from) : BaseType(copy_from)
 {
     _buf = copy_from._buf;
@@ -102,16 +113,16 @@ Int32::width()
 }
 
 bool
-Int32::serialize(const string &dataset, ConstraintEvaluator &eval, DDS &dds,
+Int32::serialize(ConstraintEvaluator &eval, DDS &dds,
                  Marshaller &m, bool ce_eval)
 {
     dds.timeout_on();
 
     if (!read_p())
-        read(dataset);  // read() throws Error and InternalErr
+        read();  // read() throws Error and InternalErr
 
 #if EVAL
-    if (ce_eval && !eval.eval_selection(dds, dataset))
+    if (ce_eval && !eval.eval_selection(dds, dataset()))
         return true;
 #endif
 
@@ -176,7 +187,7 @@ Int32::set_value(dods_int32 i)
 
     return true;
 }
-
+//#if FILE_METHODS
 void
 Int32::print_val(FILE *out, string space, bool print_decl_p)
 {
@@ -187,7 +198,7 @@ Int32::print_val(FILE *out, string space, bool print_decl_p)
     else
         fprintf(out, "%d", (int)_buf) ;
 }
-
+//#endif
 void
 Int32::print_val(ostream &out, string space, bool print_decl_p)
 {
@@ -200,24 +211,24 @@ Int32::print_val(ostream &out, string space, bool print_decl_p)
 }
 
 bool
-Int32::ops(BaseType *b, int op, const string &dataset)
+Int32::ops(BaseType *b, int op)
 {
 
     // Extract the Byte arg's value.
-    if (!read_p() && !read(dataset)) {
+    if (!read_p() && !read()) {
         // Jose Garcia
         // Since the read method is virtual and implemented outside
-        // libdap++ if we can not read the data that is the problem
+        // libdap++ if we cannot read the data that is the problem
         // of the user or of whoever wrote the surrogate library
         // implemeting read therefore it is an internal error.
         throw InternalErr(__FILE__, __LINE__, "This value not read!");
     }
 
     // Extract the second arg's value.
-    if (!b->read_p() && !b->read(dataset)) {
+    if (!b->read_p() && !b->read()) {
         // Jose Garcia
         // Since the read method is virtual and implemented outside
-        // libdap++ if we can not read the data that is the problem
+        // libdap++ if we cannot read the data that is the problem
         // of the user or of whoever wrote the surrogate library
         // implemeting read therefore it is an internal error.
         throw InternalErr(__FILE__, __LINE__, "This value not read!");
