@@ -75,7 +75,8 @@ protected:
     dods_int32 _buf;
 
 public:
-    Int32(const string &n = "");
+    Int32(const string &n);
+    Int32(const string &n, const string &d);
 
     Int32(const Int32 &copy_from);
 
@@ -87,8 +88,8 @@ public:
 
     virtual unsigned int width();
 
-    virtual bool serialize(const string &dataset, ConstraintEvaluator &eval,
-                           DDS &dds, Marshaller &m, bool ce_eval = true);
+    virtual bool serialize(ConstraintEvaluator &eval, DDS &dds,
+			   Marshaller &m, bool ce_eval = true);
     virtual bool deserialize(UnMarshaller &um, DDS *dds, bool reuse = false);
 
     virtual unsigned int val2buf(void *val, bool reuse = false);
@@ -96,13 +97,14 @@ public:
 
     virtual bool set_value(dods_int32 i);
     virtual dods_int32 value() const;
-
+    //#if FILE_METHODS
     virtual void print_val(FILE *out, string space = "",
                            bool print_decl_p = true);
+    //#endif
     virtual void print_val(ostream &out, string space = "",
                            bool print_decl_p = true);
 
-    virtual bool ops(BaseType *b, int op, const string &dataset);
+    virtual bool ops(BaseType *b, int op);
 
     virtual void dump(ostream &strm) const ;
 };
