@@ -35,11 +35,9 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: InternalErr.cc 16759 2007-06-26 19:37:30Z jimg $"
+    {"$Id: InternalErr.cc 18315 2008-03-03 20:14:44Z jimg $"
     };
 
-#include <stdio.h>
-
 #include <string>
 #include <sstream>
 
@@ -49,6 +47,8 @@ static char rcsid[] not_used =
 using std::endl;
 using std::ostringstream;
 
+namespace libdap {
+
 InternalErr::InternalErr() : Error()
 {
     _error_code = internal_error;
@@ -104,3 +104,5 @@ InternalErr::OK()
 {
     return Error::OK();
 }
+
+} // namespace libdap
