@@ -37,14 +37,15 @@
 #define _internalerr_h 1
 
 
-#include <stdio.h>  // For FILE *
-
 #include <string>
 
 #ifndef _error_h
 #include "Error.h"
 #endif
 
+namespace libdap
+{
+
 
 /** The InternalErr class is used to signal that somewhere inside libdap a
     software fault was found. This class wraps the message text in some
@@ -91,4 +92,6 @@ public:
     bool OK();
 };
 
+} // namespace libdap
+
 #endif // _internalerr_h
