@@ -107,6 +107,8 @@ private:
     // jhrg
     string d_ais_database;
 
+    string d_cookie_jar;
+
     static RCReader* _instance;
 
     RCReader() throw(Error);
@@ -253,6 +255,11 @@ public:
         return d_ais_database;
     }
 
+    string get_cookie_jar() const throw()
+    {
+	return d_cookie_jar;
+    }
+
     // SET METHODS
     void set_use_cache(bool b) throw()
     {
