@@ -37,7 +37,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: RValue.cc 18315 2008-03-03 20:14:44Z jimg $"
+    {"$Id: RValue.cc 20518 2009-03-05 23:39:46Z jimg $"
     };
 
 #include <cassert>
@@ -90,36 +90,34 @@ append_rvalue_list(rvalue_list *rvals, rvalue *rv)
     @param dds Use this DDS when evaluating functions
     @param dataset Use this when evaluating functions. */
 BaseType **
-build_btp_args(rvalue_list *args, DDS &dds, const string &dataset)
+build_btp_args(rvalue_list *args, DDS &dds)
 {
     int argc = 0;
 
     if (args)
         argc = args->size();
-        
+
     // Sanitize allocation size
-    if (!size_ok(sizeof(BaseType*), argc+1))
-    	throw Error(malformed_expr, 
-                string("Malformed argument list (") 
-                + long_to_string(argc)  
-                + string(")."));
+    if (!size_ok(sizeof(BaseType*), argc + 1))
+        throw Error(malformed_expr, string("Malformed argument list (")
+                + long_to_string(argc) + string(")."));
 
     // Add space for a null terminator
     BaseType **argv = new BaseType*[argc + 1];
 
     int index = 0;
     if (argv && argc) {
-        for (rvalue::Args_iter i = args->begin(); i != args->end() && index < argc+1; ++i) {
-            argv[index++] = (*i)->bvalue(dataset, dds);
-        }
+        for (rvalue::Args_iter i = args->begin(); i != args->end() && index
+                < argc + 1; ++i)
+            argv[index++] = (*i)->bvalue(dds);
     }
 
-	if (index != argc) {
-		delete[] argv;
-		throw InternalErr(__FILE__, __LINE__, "index out of range.");
-	}
-		
-    argv[index] = 0;            // Add the null terminator.
+    if (index != argc) {
+        delete[] argv;
+        throw InternalErr(__FILE__, __LINE__, "index out of range.");
+    }
+
+    argv[index] = 0; // Add the null terminator.
 
     return argv;
 }
@@ -155,11 +153,11 @@ rvalue::value_name()
     return values in BaseType *s.
 
     @param dataset The dataset name to pass to a function (which may call
-    BaseType::read() using that arguemnt).
+    BaseType::read() using that argument).
     @param dds The dds to pass to a function.
 */
 BaseType *
-rvalue::bvalue(const string &dataset, DDS &dds)
+rvalue::bvalue(DDS &dds)
 {
     if (d_value) {        // i.e., if this RValue is a BaseType
         return d_value;
@@ -167,8 +165,12 @@ rvalue::bvalue(const string &dataset, DDS &dds)
     else if (d_func) {
         // If func is true, then args must be set. See the constructor.
         // 12/23/04 jhrg
-        BaseType **argv = build_btp_args(d_args, dds, dataset);
-        BaseType *ret_val = (*d_func)(d_args->size(), argv, dds, dataset);
+        BaseType **argv = build_btp_args(d_args, dds);
+#if 0
+        BaseType *ret_val = (*d_func)(d_args->size(), argv, dds);
+#endif
+        BaseType *ret_val;
+        (*d_func)(d_args->size(), argv, dds, &ret_val);
         delete[] argv;
         return ret_val;
     }
