@@ -152,6 +152,24 @@ Sequence::Sequence(const string &n) : Constructor(n, dods_sequence_c),
         d_leaf_sequence(false), d_top_most(false)
 {}
 
+/** The Sequence server-side constructor requires the name of the variable
+    to be created and the dataset name from which this variable is being
+    created.
+
+    @param n A string containing the name of the variable to be
+    created.
+    @param d A string containing the name of the dataset from which this
+    variable is being created.
+
+    @brief The Sequence server-side constructor. */
+Sequence::Sequence(const string &n, const string &d)
+    : Constructor(n, d, dods_sequence_c),
+      d_row_number(-1), d_starting_row_number(-1),
+      d_row_stride(1), d_ending_row_number(-1),
+      d_unsent_data(false), d_wrote_soi(false),
+      d_leaf_sequence(false), d_top_most(false)
+{}
+
 /** @brief The Sequence copy constructor. */
 Sequence::Sequence(const Sequence &rhs) : Constructor(rhs)
 {
@@ -552,7 +570,7 @@ Sequence::reset_row_number()
 
     @note The first row is row number zero. A Sequence with 100 rows will
     have row numbers 0 to 99.
-    
+
     @todo This code ignores the main reason for nesting the sequences, that
     if the outer Sequence's current instance fails the CE, there's no need to
     look at the values of the inner Sequence. But in the code that calls this
@@ -566,37 +584,38 @@ Sequence::reset_row_number()
     should be called again because there's more data to be read.
     FALSE indicates the end of the Sequence.
     @param row The row number to read.
-    @param dataset A string, often a file name, used to refer to t he
-    dataset.
     @param dds A reference to the DDS for this dataset.
     @param eval Use this as the constraint expression evaluator.
     @param ce_eval If True, evaluate any CE, otherwise do not.
 */
 bool
-Sequence::read_row(int row, const string &dataset, DDS &dds,
+Sequence::read_row(int row, DDS &dds,
                    ConstraintEvaluator &eval, bool ce_eval)
 {
     DBG2(cerr << "Entering Sequence::read_row for " << name() << endl);
     if (row < d_row_number)
         throw InternalErr("Trying to back up inside a sequence!");
 
-    DBG2(cerr << "read_row: row number " << row << ", current row " << d_row_number
-         << endl);
+    DBG2(cerr << "read_row: row number " << row
+              << ", current row " << d_row_number << endl);
     if (row == d_row_number)
+    {
+	DBG2(cerr << "Leaving Sequence::read_row for " << name() << endl);
         return true;
+    }
 
     dds.timeout_on();
 
     int eof = 0;  // Start out assuming EOF is false.
     while (!eof && d_row_number < row) {
         if (!read_p()) {
-            eof = (read(dataset) == false);
+            eof = (read() == false);
         }
 
         // Advance the row number if ce_eval is false (we're not supposed to
         // evaluate the selection) or both ce_eval and the selection are
         // true.
-        if (!eof && (!ce_eval || eval.eval_selection(dds, dataset)))
+        if (!eof && (!ce_eval || eval.eval_selection(dds, dataset())))
             d_row_number++;
 
         set_read_p(false); // ...so that the next instance will be read
@@ -611,6 +630,8 @@ Sequence::read_row(int row, const string &dataset, DDS &dds,
     dds.timeout_off();
 
     // Return true if we have valid data, false if we've read to the EOF.
+    DBG2(cerr << "Leaving Sequence::read_row for " << name()
+              << " with " << (eof == 0) << endl);
     return eof == 0;
 }
 
@@ -688,16 +709,16 @@ Sequence::is_end_of_rows(int i)
     </ol>
 */
 bool
-Sequence::serialize(const string &dataset, ConstraintEvaluator &eval, DDS &dds,
+Sequence::serialize(ConstraintEvaluator &eval, DDS &dds,
                     Marshaller &m, bool ce_eval)
 {
     DBG2(cerr << "Entering Sequence::serialize for " << name() << endl);
 
     // Special case leaf sequences!
     if (is_leaf_sequence())
-        return serialize_leaf(dataset, dds, eval, m, ce_eval);
+        return serialize_leaf(dds, eval, m, ce_eval);
     else
-        return serialize_parent_part_one(dataset, dds, eval, m);
+        return serialize_parent_part_one(dds, eval, m);
 }
 
 // We know this is not a leaf Sequence. That means that this Sequence holds
@@ -705,7 +726,7 @@ Sequence::serialize(const string &dataset, ConstraintEvaluator &eval, DDS &dds,
 // the actual transmission of values.
 
 bool
-Sequence::serialize_parent_part_one(const string &dataset, DDS &dds,
+Sequence::serialize_parent_part_one(DDS &dds,
                                     ConstraintEvaluator &eval, Marshaller &m)
 {
     DBG2(cerr << "Entering serialize_parent_part_one for " << name() << endl);
@@ -716,7 +737,7 @@ Sequence::serialize_parent_part_one(const string &dataset, DDS &dds,
     // found. 6/1/2001 jhrg
     // Since this is a parent sequence, read the row ignoring the CE (all of
     // the CE clauses will be evaluated by the leaf sequence).
-    bool status = read_row(i, dataset, dds, eval, false);
+    bool status = read_row(i, dds, eval, false);
     DBG2(cerr << "Sequence::serialize_parent_part_one::read_row() status: " << status << endl);
 
     while (status && !is_end_of_rows(i)) {
@@ -737,12 +758,12 @@ Sequence::serialize_parent_part_one(const string &dataset, DDS &dds,
             // sequence must be the lowest level sequence with values whose send_p
             // property is true.
             if ((*iter)->send_p() && (*iter)->type() == dods_sequence_c)
-                (*iter)->serialize(dataset, eval, dds, m);
+                (*iter)->serialize(eval, dds, m);
         }
 
         set_read_p(false); // ...so this will read the next instance
 
-        status = read_row(i, dataset, dds, eval, false);
+        status = read_row(i, dds, eval, false);
         DBG(cerr << "Sequence::serialize_parent_part_one::read_row() status: " << status << endl);
     }
     // Reset current row number for next nested sequence element.
@@ -771,15 +792,14 @@ Sequence::serialize_parent_part_one(const string &dataset, DDS &dds,
 // NB: This code only works if the child sequences appear after all other
 // variables.
 void
-Sequence::serialize_parent_part_two(const string &dataset, DDS &dds,
+Sequence::serialize_parent_part_two(DDS &dds,
                                     ConstraintEvaluator &eval, Marshaller &m)
 {
     DBG(cerr << "Entering serialize_parent_part_two for " << name() << endl);
 
     BaseType *btp = get_parent();
     if (btp && btp->type() == dods_sequence_c)
-        dynamic_cast<Sequence&>(*btp).serialize_parent_part_two(dataset, dds,
-                eval, m);
+        dynamic_cast<Sequence&>(*btp).serialize_parent_part_two(dds, eval, m);
 
     if (d_unsent_data) {
         DBG(cerr << "Writing Start of Instance marker" << endl);
@@ -793,7 +813,7 @@ Sequence::serialize_parent_part_two(const string &dataset, DDS &dds,
                 << (*iter)->name() << endl);
             if ((*iter)->send_p() && (*iter)->type() != dods_sequence_c) {
                 DBG(cerr << "Send P is true, sending " << (*iter)->name() << endl);
-                (*iter)->serialize(dataset, eval, dds, m, false);
+                (*iter)->serialize(eval, dds, m, false);
             }
         }
 
@@ -804,7 +824,7 @@ Sequence::serialize_parent_part_two(const string &dataset, DDS &dds,
 // This code is only run by a leaf sequence. Note that a one level sequence
 // is also a leaf sequence.
 bool
-Sequence::serialize_leaf(const string &dataset, DDS &dds,
+Sequence::serialize_leaf(DDS &dds,
                          ConstraintEvaluator &eval, Marshaller &m, bool ce_eval)
 {
     DBG(cerr << "Entering Sequence::serialize_leaf for " << name() << endl);
@@ -812,7 +832,7 @@ Sequence::serialize_leaf(const string &dataset, DDS &dds,
 
     // read_row returns true if valid data was read, false if the EOF was
     // found. 6/1/2001 jhrg
-    bool status = read_row(i, dataset, dds, eval, ce_eval);
+    bool status = read_row(i, dds, eval, ce_eval);
     DBG(cerr << "Sequence::serialize_leaf::read_row() status: " << status << endl);
 
     // Once the first valid (satisfies the CE) row of the leaf sequence has
@@ -830,8 +850,8 @@ Sequence::serialize_leaf(const string &dataset, DDS &dds,
     if (status && !is_end_of_rows(i)) {
         BaseType *btp = get_parent();
         if (btp && btp->type() == dods_sequence_c)
-            dynamic_cast<Sequence&>(*btp).serialize_parent_part_two(dataset,
-                    dds, eval, m);
+            dynamic_cast<Sequence&>(*btp).serialize_parent_part_two(dds,
+								    eval, m);
     }
 
     d_wrote_soi = false;
@@ -848,13 +868,13 @@ Sequence::serialize_leaf(const string &dataset, DDS &dds,
                 << (*iter)->name() << endl);
             if ((*iter)->send_p()) {
                 DBG(cerr << "Send P is true, sending " << (*iter)->name() << endl);
-                (*iter)->serialize(dataset, eval, dds, m, false);
+                (*iter)->serialize(eval, dds, m, false);
             }
         }
 
         set_read_p(false); // ...so this will read the next instance
 
-        status = read_row(i, dataset, dds, eval, ce_eval);
+        status = read_row(i, dds, eval, ce_eval);
         DBG(cerr << "Sequence::serialize_leaf::read_row() status: " << status << endl);
     }
 
@@ -888,49 +908,46 @@ Sequence::serialize_leaf(const string &dataset, DDS &dds,
     Sequences which have a parent (directly or indirectly) variable that is
     a Sequence.
 
-    @param dataset The name of the data set
     @param eval Use this contraint evaluator
     @param dds This DDS holds the variables for the data source */
 void
-Sequence::intern_data(const string &dataset, ConstraintEvaluator &eval, DDS &dds)
+Sequence::intern_data(ConstraintEvaluator &eval, DDS &dds)
 {
-    DBG(cerr << "Entering intern_data for " << name() << endl);
+    DBG(cerr << "Sequence::intern_data - for " << name() << endl);
     DBG2(cerr << "    intern_data, values: " << &d_values << endl);
 
     // Why use a stack instead of return values? We need the stack because
     // Sequences neted three of more levels deep will loose the middle
     // instances when the intern_data_parent_part_two() code is run.
     sequence_values_stack_t sequence_values_stack;
-    
-    DBG2(cerr << "    pushing d_values (" << &d_values
-         << ") on stack; size: " << sequence_values_stack.size() << endl);
+
+    DBG2(cerr << "    pushing d_values of " << name() << " (" << &d_values
+              << ") on stack; size: " << sequence_values_stack.size() << endl);
     sequence_values_stack.push(&d_values);
 
-    intern_data_private(dataset, eval, dds, sequence_values_stack);
+    intern_data_private(eval, dds, sequence_values_stack);
 }
 
 void
-Sequence::intern_data_private(const string &dataset,
-                                ConstraintEvaluator &eval,
-                                DDS &dds,
-                                sequence_values_stack_t &sequence_values_stack)
+Sequence::intern_data_private(ConstraintEvaluator &eval,
+                              DDS &dds,
+                              sequence_values_stack_t &sequence_values_stack)
 {
     DBG(cerr << "Entering intern_data_private for " << name() << endl);
 
     if (is_leaf_sequence())
-        intern_data_for_leaf(dataset, dds, eval, sequence_values_stack);
+        intern_data_for_leaf(dds, eval, sequence_values_stack);
     else
-        intern_data_parent_part_one(dataset, dds, eval, sequence_values_stack);
+        intern_data_parent_part_one(dds, eval, sequence_values_stack);
 }
 
 void
-Sequence::intern_data_parent_part_one(const string & dataset, DDS & dds,
-                                        ConstraintEvaluator & eval,
-                                        sequence_values_stack_t &
-                                        sequence_values_stack)
+Sequence::intern_data_parent_part_one(DDS & dds,
+                                      ConstraintEvaluator & eval,
+                                      sequence_values_stack_t &
+                                      sequence_values_stack)
 {
-    DBG(cerr << "Entering intern_data_parent_part_one for " << name() <<
-        endl);
+    DBG(cerr << "Entering intern_data_parent_part_one for " << name() << endl);
 
     int i = (get_starting_row_number() != -1) ? get_starting_row_number() : 0;
 
@@ -938,22 +955,31 @@ Sequence::intern_data_parent_part_one(const string & dataset, DDS & dds,
     // found. 6/1/2001 jhrg
     // Since this is a parent sequence, read the row ignoring the CE (all of
     // the CE clauses will be evaluated by the leaf sequence).
-    bool status = read_row(i, dataset, dds, eval, false);
+    bool status = read_row(i, dds, eval, false);
+
+    // Grab the current size of the value stack. We do this because it is
+    // possible that no nested sequences for this row happened to be
+    // selected because of a constract evaluation or the last row is not
+    // selected because of a constraint evaluation. In either case, no
+    // nested sequence d_values are pused onto the stack, so there is
+    // nothing to pop at the end of this function. pcw 07/14/08
+    SequenceValues::size_type orig_stack_size = sequence_values_stack.size() ;
 
     while (status
            && (get_ending_row_number() == -1
-               || i <= get_ending_row_number())) {
+               || i <= get_ending_row_number()))
+    {
         i += get_row_stride();
         for (Vars_iter iter = var_begin(); iter != var_end(); iter++) {
             if ((*iter)->send_p()) {
                 switch ((*iter)->type()) {
                 case dods_sequence_c:
-                    dynamic_cast<Sequence&>(**iter).intern_data_private(dataset,
+                    dynamic_cast<Sequence&>(**iter).intern_data_private(
                             eval, dds, sequence_values_stack);
                     break;
 
                 default:
-                    (*iter)->intern_data(dataset, eval, dds);
+                    (*iter)->intern_data(eval, dds);
                     break;
                 }
             }
@@ -961,32 +987,41 @@ Sequence::intern_data_parent_part_one(const string & dataset, DDS & dds,
 
         set_read_p(false);      // ...so this will read the next instance
 
-        status = read_row(i, dataset, dds, eval, false);
+        status = read_row(i, dds, eval, false);
     }
 
     // Reset current row number for next nested sequence element.
     reset_row_number();
-    DBG2(cerr << "    popping d_values (" << sequence_values_stack.top()
-         << ") off stack; size: " << sequence_values_stack.size() << endl);
-    sequence_values_stack.pop();
+
+    // if the size of the stack is larger than the original size (retrieved
+    // above) then pop the top set of d_values from the stack. If it's the
+    // same, then no nested sequences, or possible the last nested sequence,
+    // were pushed onto the stack, so there is nothing to pop.
+    if( sequence_values_stack.size() > orig_stack_size )
+    {
+	DBG2(cerr << "    popping d_values (" << sequence_values_stack.top()
+	     << ") off stack; size: " << sequence_values_stack.size() << endl);
+	sequence_values_stack.pop();
+    }
+    DBG(cerr << "Leaving intern_data_parent_part_one for " << name() << endl);
 }
 
 void
-Sequence::intern_data_parent_part_two(const string &dataset, DDS &dds,
-                                      ConstraintEvaluator &eval,
-                                      sequence_values_stack_t &sequence_values_stack)
+Sequence::intern_data_parent_part_two(DDS &dds,
+			      ConstraintEvaluator &eval,
+			      sequence_values_stack_t &sequence_values_stack)
 {
     DBG(cerr << "Entering intern_data_parent_part_two for " << name() << endl);
 
     BaseType *btp = get_parent();
     if (btp && btp->type() == dods_sequence_c) {
-        dynamic_cast<Sequence&>(*btp).intern_data_parent_part_two(dataset, 
+        dynamic_cast<Sequence&>(*btp).intern_data_parent_part_two(
                                       dds, eval, sequence_values_stack);
     }
 
     DBG2(cerr << "    stack size: " << sequence_values_stack.size() << endl);
     SequenceValues *values = sequence_values_stack.top();
-    DBG2(cerr << "    using values = " << values << endl);
+    DBG2(cerr << "    using values = " << (void *)values << endl);
 
     if (get_unsent_data()) {
         BaseTypeRow *row_data = new BaseTypeRow;
@@ -999,43 +1034,50 @@ Sequence::intern_data_parent_part_two(const string &dataset, DDS &dds,
             }
             else if ((*iter)->send_p()) { //Sequence; must be the last variable
                 Sequence *tmp = dynamic_cast<Sequence*>((*iter)->ptr_duplicate());
+                if (!tmp)
+                    throw InternalErr(__FILE__, __LINE__, "Expected a Sequence.");
                 row_data->push_back(tmp);
-                DBG2(cerr << "    pushing d_values (" << &(dynamic_cast<Sequence&>(*tmp).d_values)
-                     << ") on stack; size: " << sequence_values_stack.size() << endl);
-                // This pushes the d_values field of the newly created leaf 
+                DBG2(cerr << "    pushing d_values of " << tmp->name()
+		     << " (" << &(tmp->d_values)
+                     << ") on stack; size: " << sequence_values_stack.size()
+		     << endl);
+                // This pushes the d_values field of the newly created leaf
                 // Sequence onto the stack. The code then returns to intern
                 // _data_for_leaf() where this value will be used.
-                sequence_values_stack.push(&(dynamic_cast<Sequence&>(*tmp).d_values));
+                sequence_values_stack.push(&(tmp->d_values));
             }
         }
 
-        DBG2(cerr << "    pushing values for " << name() << " to " << values << endl);
+        DBG2(cerr << "    pushing values for " << name()
+	          << " to " << values << endl);
         values->push_back(row_data);
         set_unsent_data(false);
     }
+    DBG(cerr << "Leaving intern_data_parent_part_two for " << name() << endl);
 }
 
 void
-Sequence::intern_data_for_leaf(const string &dataset, DDS &dds,
+Sequence::intern_data_for_leaf(DDS &dds,
                                ConstraintEvaluator &eval,
                                sequence_values_stack_t &sequence_values_stack)
 {
     DBG(cerr << "Entering intern_data_for_leaf for " << name() << endl);
-    
+
     int i = (get_starting_row_number() != -1) ? get_starting_row_number() : 0;
 
     DBG2(cerr << "    reading row " << i << endl);
-    bool status = read_row(i, dataset, dds, eval, true);
+    bool status = read_row(i, dds, eval, true);
     DBG2(cerr << "    status: " << status << endl);
-    
+    DBG2(cerr << "    ending row number: " << get_ending_row_number() << endl);
+
     if (status && (get_ending_row_number() == -1 || i <= get_ending_row_number())) {
         BaseType *btp = get_parent();
         if (btp && btp->type() == dods_sequence_c) {
-            // This call will read the values for the parent sequences and 
+            // This call will read the values for the parent sequences and
             // then allocate a new instance for the leaf and push that onto
             // the stack.
-            dynamic_cast<Sequence&>(*btp).intern_data_parent_part_two(dataset,
-                dds, eval, sequence_values_stack);
+            dynamic_cast<Sequence&>(*btp).intern_data_parent_part_two(
+					    dds, eval, sequence_values_stack);
         }
 
         // intern_data_parent_part_two pushes the d_values field of the leaf
@@ -1044,7 +1086,7 @@ Sequence::intern_data_for_leaf(const string &dataset, DDS &dds,
         SequenceValues *values = sequence_values_stack.top();
         DBG2(cerr << "    using values = " << values << endl);
 
-        while (status && (get_ending_row_number() == -1 
+        while (status && (get_ending_row_number() == -1
                           || i <= get_ending_row_number())) {
             i += get_row_stride();
 
@@ -1056,19 +1098,21 @@ Sequence::intern_data_for_leaf(const string &dataset, DDS &dds,
                 }
             }
 
-            DBG2(cerr << "    pushing values for " << name() << " to " << values << endl);
+            DBG2(cerr << "    pushing values for " << name()
+	              << " to " << values << endl);
             // Save the row_data to values().
             values->push_back(row_data);
-            
+
             set_read_p(false);      // ...so this will read the next instance
             // Read the ith row into this object's fields
-            status = read_row(i, dataset, dds, eval, true);
+            status = read_row(i, dds, eval, true);
         }
 
         DBG2(cerr << "    popping d_values (" << sequence_values_stack.top()
              << ") off stack; size: " << sequence_values_stack.size() << endl);
         sequence_values_stack.pop();
     }
+    DBG(cerr << "Leaving intern_data_for_leaf for " << name() << endl);
 }
 
 /** @brief Deserialize (read from the network) the entire Sequence.
@@ -1081,14 +1125,14 @@ Sequence::intern_data_for_leaf(const string &dataset, DDS &dds,
 
     @param um An UnMarshaller that knows how to deserialize data
     @param dds A DataDDS from which to read.
-    @param reuse Passed to child objects when they are deserialized. Some 
+    @param reuse Passed to child objects when they are deserialized. Some
     implementations of derialize() use this to determine if new storage should
     be allocated or existing storage reused.
     @exception Error if a sequence stream marker cannot be read.
     @exception InternalErr if the <tt>dds</tt> param is not a DataDDS.
     @return A return value of false indicates that an EOS ("end of
     Sequence") marker was found, while a value of true indicates
-    that there are more rows to be read. This version always reads the 
+    that there are more rows to be read. This version always reads the
     entire sequence, so it always returns false.
 */
 bool
@@ -1104,7 +1148,7 @@ Sequence::deserialize(UnMarshaller &um, DDS *dds, bool reuse)
 
     // Check for old servers.
     if (dd->get_protocol_major() < 2) {
-        throw Error(string("The protocl version (") + dd->get_protocol() 
+        throw Error(string("The protocl version (") + dd->get_protocol()
 		    + ") indicates that this\nis an old server which may not correctly transmit Sequence variables.\nContact the server administrator.");
     }
 
@@ -1227,7 +1271,7 @@ Sequence::buf2val(void **)
     throw InternalErr(__FILE__, __LINE__, "Use Sequence::var_value() or Sequence::row_value() in place of Sequence::buf2val()");
     return sizeof(Sequence);
 }
-
+//#if FILE_METHODS
 void
 Sequence::print_one_row(FILE *out, int row, string space,
                         bool print_row_num)
@@ -1265,7 +1309,7 @@ Sequence::print_one_row(FILE *out, int row, string space,
 
     fprintf(out, " }") ;
 }
-
+//#endif
 void
 Sequence::print_one_row(ostream &out, int row, string space,
                         bool print_row_num)
@@ -1278,11 +1322,11 @@ Sequence::print_one_row(ostream &out, int row, string space,
     int elements = element_count();
     int j = 0;
     BaseType *bt_ptr = 0;
-    
-    // This version of print_one_row() works for both data read with 
+
+    // This version of print_one_row() works for both data read with
     // deserialize(), where each variable is assumed to have valid data, and
     // intern_data(), where some/many variables do not. Because of that, it's
-    // not correct to assume that all of the elements will be printed, which 
+    // not correct to assume that all of the elements will be printed, which
     // is what the old code did.
     // Print the first value
     while (j < elements && !bt_ptr) {
@@ -1308,7 +1352,7 @@ Sequence::print_one_row(ostream &out, int row, string space,
                 bt_ptr->print_val(out, space, false);
         }
     }
-    
+
 #if 0
     // old version
     int elements = element_count() - 1;
@@ -1341,6 +1385,7 @@ Sequence::print_one_row(ostream &out, int row, string space,
     out << " }" ;
 }
 
+//#if FILE_METHODS
 void
 Sequence::print_val_by_rows(FILE *out, string space, bool print_decl_p,
                             bool print_row_numbers)
@@ -1365,7 +1410,7 @@ Sequence::print_val_by_rows(FILE *out, string space, bool print_decl_p,
     if (print_decl_p)
         fprintf(out, ";\n") ;
 }
-
+//#endif
 void
 Sequence::print_val_by_rows(ostream &out, string space, bool print_decl_p,
                             bool print_row_numbers)
@@ -1390,13 +1435,13 @@ Sequence::print_val_by_rows(ostream &out, string space, bool print_decl_p,
     if (print_decl_p)
 	out << ";\n" ;
 }
-
+//#if FILE_METHODS
 void
 Sequence::print_val(FILE *out, string space, bool print_decl_p)
 {
     print_val_by_rows(out, space, print_decl_p, false);
 }
-
+//#endif
 void
 Sequence::print_val(ostream &out, string space, bool print_decl_p)
 {
