@@ -216,35 +216,35 @@ protected:
 
     typedef stack<SequenceValues*> sequence_values_stack_t;
 
-    virtual bool serialize_parent_part_one(const string &dataset, DDS &dds,
+    virtual bool serialize_parent_part_one(DDS &dds,
                                            ConstraintEvaluator &eval,
 					   Marshaller &m);
-    virtual void serialize_parent_part_two(const string &dataset, DDS &dds,
+    virtual void serialize_parent_part_two(DDS &dds,
                                            ConstraintEvaluator &eval,
 					   Marshaller &m);
-    virtual bool serialize_leaf(const string &dataset, DDS &dds,
+    virtual bool serialize_leaf(DDS &dds,
                                 ConstraintEvaluator &eval,
 				Marshaller &m, bool ce_eval);
 
-    virtual void intern_data_private(const string &dataset,
-                                       ConstraintEvaluator &eval,
-                                       DDS &dds,
-                                       sequence_values_stack_t &sequence_values_stack);
-    virtual void intern_data_for_leaf(const string &dataset, DDS &dds,
-                                        ConstraintEvaluator &eval,
-                                        sequence_values_stack_t &sequence_values_stack);
+    virtual void intern_data_private( ConstraintEvaluator &eval,
+                                      DDS &dds,
+                                      sequence_values_stack_t &sequence_values_stack);
+    virtual void intern_data_for_leaf(DDS &dds,
+                                      ConstraintEvaluator &eval,
+                                      sequence_values_stack_t &sequence_values_stack);
 
-    virtual void intern_data_parent_part_one(const string &dataset, DDS &dds,
+    virtual void intern_data_parent_part_one(DDS &dds,
             ConstraintEvaluator &eval,
             sequence_values_stack_t &sequence_values_stack);
 
-    virtual void intern_data_parent_part_two(const string &dataset, DDS &dds,
+    virtual void intern_data_parent_part_two(DDS &dds,
             ConstraintEvaluator &eval,
             sequence_values_stack_t &sequence_values_stack);
 
 public:
 
-    Sequence(const string &n = "");
+    Sequence(const string &n);
+    Sequence(const string &n, const string &d);
 
     Sequence(const Sequence &rhs);
 
@@ -270,13 +270,12 @@ public:
 
     virtual int number_of_rows();
 
-    virtual bool read_row(int row, const string &dataset, DDS &dds,
+    virtual bool read_row(int row, DDS &dds,
                           ConstraintEvaluator &eval, bool ce_eval = true);
 
-    virtual void intern_data(const string &dataset, ConstraintEvaluator &eval,
-                             DDS &dds);
-    virtual bool serialize(const string &dataset, ConstraintEvaluator &eval,
-                           DDS &dds, Marshaller &m, bool ce_eval = true);
+    virtual void intern_data(ConstraintEvaluator &eval, DDS &dds);
+    virtual bool serialize(ConstraintEvaluator &eval, DDS &dds,
+			   Marshaller &m, bool ce_eval = true);
     virtual bool deserialize(UnMarshaller &um, DDS *dds, bool reuse = false);
 
     /// Rest the row number counter
@@ -320,20 +319,23 @@ public:
     virtual BaseTypeRow *row_value(size_t row);
 
     virtual void add_var(BaseType *, Part part = nil);
-    virtual void print_one_row(FILE *out, int row, string space,
-                               bool print_row_num = false);
     virtual void print_one_row(ostream &out, int row, string space,
                                bool print_row_num = false);
+    virtual void print_val_by_rows(ostream &out, string space = "",
+                                   bool print_decl_p = true,
+                                   bool print_row_numbers = true);
+    virtual void print_val(ostream &out, string space = "",
+                           bool print_decl_p = true);
+
+    //#if FILE_METHODS
+    virtual void print_one_row(FILE *out, int row, string space,
+                               bool print_row_num = false);
     virtual void print_val_by_rows(FILE *out, string space = "",
                                    bool print_decl_p = true,
                                    bool print_row_numbers = true);
-    virtual void print_val_by_rows(ostream &out, string space = "",
-                                   bool print_decl_p = true,
-                                   bool print_row_numbers = true);
     virtual void print_val(FILE *out, string space = "",
                            bool print_decl_p = true);
-    virtual void print_val(ostream &out, string space = "",
-                           bool print_decl_p = true);
+    //#endif
 
     virtual bool check_semantics(string &msg, bool all = false);
 
