@@ -74,7 +74,8 @@ protected:
     dods_uint32 _buf;
 
 public:
-    UInt32(const string &n = "");
+    UInt32(const string &n);
+    UInt32(const string &n, const string &d);
     virtual ~UInt32()
     {}
 
@@ -86,8 +87,8 @@ public:
 
     virtual unsigned int width();
 
-    virtual bool serialize(const string &dataset, ConstraintEvaluator &eval,
-                           DDS &dds, Marshaller &m, bool ce_eval = true);
+    virtual bool serialize(ConstraintEvaluator &eval, DDS &dds,
+			   Marshaller &m, bool ce_eval = true);
     virtual bool deserialize(UnMarshaller &um, DDS *dds, bool reuse = false);
 
     virtual unsigned int val2buf(void *val, bool reuse = false);
@@ -95,13 +96,14 @@ public:
 
     virtual dods_uint32 value() const;
     virtual bool set_value(dods_uint32 val);
-
+    //#if FILE_METHODS
     virtual void print_val(FILE *out, string space = "",
                            bool print_decl_p = true);
+    //#endif
     virtual void print_val(ostream &out, string space = "",
                            bool print_decl_p = true);
 
-    virtual bool ops(BaseType *b, int op, const string &dataset);
+    virtual bool ops(BaseType *b, int op);
 
     virtual void dump(ostream &strm) const ;
 };
