@@ -39,7 +39,7 @@
 #include <cstring>
 
 static char rcsid[] not_used =
-    { "$Id: Vector.cc 18315 2008-03-03 20:14:44Z jimg $"
+    { "$Id: Vector.cc 19807 2008-11-06 22:46:39Z jimg $"
     };
 
 //#define DODS_DEBUG
@@ -71,7 +71,7 @@ void Vector::_duplicate(const Vector & v)
         _var = 0;
     }
 
-    // _vec and _buf (futher down) hold the values of the Vector. The field
+    // _vec and _buf (further down) hold the values of the Vector. The field
     // _vec is used when the Vector holds non-numeric data (including strings
     // although it used to be that was not the case jhrg 2/10/05) while _buf
     // holds numeric values.
@@ -127,6 +127,36 @@ Vector::Vector(const string & n, BaseType * v, const Type & t)
         _var->set_parent(this);
 }
 
+/** The Vector server-side constructor requires the name of the variable
+    to be created, the dataset name from which this Vector is created, and
+    a pointer to an object of the type the Vector is to hold.  The
+    name may be omitted, which will create a nameless variable.
+    The template object may not be omitted.
+
+    @param n A string containing the name of the variable to be
+    created.
+    @param d A string containing the dataset name from which the variable is
+    being created.
+    @param v A pointer to a variable of the type to be included
+    in the Vector.
+    @param t The type of the resulting Vector object, from the Type
+    enum list.  There is no DAP2 Vector object, so all uses of this
+    method will be from the List or Array classes.  This defaults to
+    <tt>dods_null_c</tt>.
+
+    @see Type
+    @brief The Vector constructor.  */
+Vector::Vector(const string & n, const string &d, BaseType * v, const Type & t)
+        : BaseType(n, d, t), _length(-1), _var(0), _buf(0), _vec(0)
+{
+    if (v)
+        add_var(v);
+
+    DBG2(cerr << "Entering Vector ctor for object: " << this << endl);
+    if (_var)
+        _var->set_parent(this);
+}
+
 /** The Vector copy constructor. */
 Vector::Vector(const Vector & rhs): BaseType(rhs)
 {
@@ -217,7 +247,7 @@ void Vector::set_read_p(bool state)
 
     Note that the parameter <i>exact_match</i> is not used by this mfunc.
 
-    @param n The name of the variabe to find.
+    @param n The name of the variable to find.
     @param exact Unused.
     @param s Pointer to a BaseType Pointer Stack. Use this stack to record
     the path to the variable. By default this pointer is null, in which case
@@ -228,17 +258,26 @@ void Vector::set_read_p(bool state)
 BaseType *Vector::var(const string & n, bool exact, btp_stack * s)
 {
     string name = www2id(n);
+    DBG(cerr << "Vector::var: Looking for " << n << endl);
 
     // Make sure to check for the case where name is the default (the empty
     // string). 9/1/98 jhrg
     if (_var->is_constructor_type()) {
-        if (name == "" || _var->name() == name)
+        if (name == "" || _var->name() == name) {
+            if (s)
+                s->push(this);
             return _var;
-        else
-            return _var->var(name, exact, s);
+        }
+        else {
+            BaseType * result = _var->var(name, exact, s);
+            if (result && s)
+                s->push(this);
+            return result;
+        }
+    }
+    else {
+        return _var; // I don't see why this isn't return 0 *** jhrg 10/9/08
     }
-    else
-        return _var;
 }
 
 /** This version of var(...) searches for <i>name</i> and returns a
@@ -264,19 +303,19 @@ BaseType *Vector::var(const string & n, btp_stack & s)
 }
 
 // Return a pointer the the BaseType object for element I. If the Vector is
-// of a cardinal type, store the Ith element's value in the BaseType
+// of a cardinal type, store the ith element's value in the BaseType
 // object. If it is a Vector of a non-cardinal type, then this mfunc returns
 // _vec[i].
 //
 // NB: I defaults to zero.
 //
-// Returns: A BaseType pointer to the Ith element of the Vector.
+// Returns: A BaseType pointer to the ith element of the Vector.
 
 /** Returns a pointer to the specified Vector element.  The return
     pointer will reference the element itself, so multiple calls to this
     method should save each value before making the next call.
 
-    @todo Is this method thread safe? If 'apartment threding' is used, I
+    @todo Is this method thread safe? If 'apartment threading' is used, I
     think so. But if the library is running in more than one thread, then
     this is not thread safe.
 
@@ -386,26 +425,26 @@ void Vector::vec_resize(int l)
 }
 
 /** @brief read data into a variable for later use
- 
+
     Most uses of a variable are to either serialize its data to a stream of
     some sort or to read values from some stream and intern those in the
     variable for later use. These operations are perform by serialize()
     and deserialize() which follow. This function performs essentially both
     of these operations without actually using a stream device. The data are
     read using the read() method(s) and loaded into the variables directly.
-    
+
     This method is intended to be used by objects which transform DAP objects
     like the DataDDS into an ASCII CSV representation.
-    
-    @param dataset A string passed to read() so data values can be read from
+
     the data source.
     @param eval A reference to a constraint evaluator
     @param dds The complete DDS to which this variable belongs */
 void
-Vector::intern_data(const string &dataset, ConstraintEvaluator &eval, DDS &dds)
+Vector::intern_data(ConstraintEvaluator &eval, DDS &dds)
 {
+    DBG(cerr << "Vector::intern_data: " << name() << endl);
     if (!read_p())
-        read(dataset);          // read() throws Error and InternalErr
+        read();          // read() throws Error and InternalErr
 
     // length() is not capacity; it must be set explicitly in read().
     int num = length();
@@ -421,30 +460,31 @@ Vector::intern_data(const string &dataset, ConstraintEvaluator &eval, DDS &dds)
         // For these cases, read() puts the data into _buf, which is what we
         // need to do 'stuff' with the data.
         break;
-        
+
     case dods_str_c:
     case dods_url_c:
-        // For these cases, read() will put the data into d_str[], which is 
+        // For these cases, read() will put the data into d_str[], which is
         // what the transformation classes need.
         break;
 
     case dods_array_c:
-        // I think this is an error since there can never be an Array of 
+        // I think this is an error since there can never be an Array of
         // Array.
         throw InternalErr(__FILE__, __LINE__, "Array of Array not supported.");
         break;
-        
+
     case dods_structure_c:
     case dods_sequence_c:
     case dods_grid_c:
-        // For these cases, we need to call read() for each of the 'num' 
+        DBG(cerr << "Vector::intern_data: found ctor" << endl);
+        // For these cases, we need to call read() for each of the 'num'
         // elements in the '_vec[]' array of BaseType object pointers.
         if (_vec.capacity() == 0)
             throw InternalErr(__FILE__, __LINE__,
                               "The capacity of *this* vector is 0.");
 
         for (int i = 0; i < num; ++i)
-            _vec[i]->intern_data(dataset, eval, dds);
+            _vec[i]->intern_data(eval, dds);
 
         break;
 
@@ -456,7 +496,7 @@ Vector::intern_data(const string &dataset, ConstraintEvaluator &eval, DDS &dds)
 
 /** @brief Serialize a Vector.
 
-    This uses the Marshaller class to encode each element of a cardinal
+    This uses the Marshaler class to encode each element of a cardinal
     array. For Arrays of Str and Url types, send the element count over
     as a prefix to the data so that deserialize will know how many elements
     to read.
@@ -466,18 +506,18 @@ Vector::intern_data(const string &dataset, ConstraintEvaluator &eval, DDS &dds)
 */
 
 
-bool Vector::serialize(const string & dataset, ConstraintEvaluator & eval,
-                       DDS & dds, Marshaller &m, bool ce_eval)
+bool Vector::serialize(ConstraintEvaluator & eval, DDS & dds,
+		       Marshaller &m, bool ce_eval)
 {
     int i = 0;
 
     dds.timeout_on();
 
     if (!read_p())
-        read(dataset);          // read() throws Error and InternalErr
+        read();          // read() throws Error and InternalErr
 
 #if EVAL
-    if (ce_eval && !eval.eval_selection(dds, dataset))
+    if (ce_eval && !eval.eval_selection(dds, dataset()))
         return true;
 #endif
 
@@ -525,7 +565,7 @@ bool Vector::serialize(const string & dataset, ConstraintEvaluator & eval,
 	m.put_int( num ) ;
 
         for (i = 0; i < num; ++i)
-            _vec[i]->serialize(dataset, eval, dds, m, false);
+            _vec[i]->serialize(eval, dds, m, false);
 
         break;
 
@@ -646,7 +686,7 @@ bool Vector::deserialize(UnMarshaller &um, DDS * dds, bool reuse)
         break;
 
     default:
-        throw InternalErr(__FILE__, __LINE__, "Unknow type!");
+        throw InternalErr(__FILE__, __LINE__, "Unknown type!");
         break;
     }
 
@@ -688,7 +728,7 @@ unsigned int Vector::val2buf(void *val, bool reuse)
     // is implemented in the surrogate library. Passing NULL as a pointer to
     // this method will be an error of the creator of the surrogate library.
     // Even though I recognize the fact that some methods inside libdap++ can
-    // call val2buf, I think by now no coding bugs such as missusing val2buf
+    // call val2buf, I think by now no coding bugs such as misusing val2buf
     // will be in libdap++, so it will be an internal error from the
     // surrogate library.
     if (!val)
@@ -744,7 +784,7 @@ unsigned int Vector::val2buf(void *val, bool reuse)
     Sequence or Grid.
 
     When reading data out of a variable that has been constrained, this method
-    assumes the N values/bytes of constrained data start at the begining
+    assumes the N values/bytes of constrained data start at the beginning
     of the object's internal buffer. For example, do not load an entire
     Vector's data using val2buf(), constrain and then use this method to
     get the data. Unless your constraint starts with the [0]th element, the
@@ -839,7 +879,7 @@ void Vector::set_vec(unsigned int i, BaseType * val)
     // Jose Garcia
     // This is a public method which allows users to set the elements
     // of *this* vector. Passing an invalid index, a NULL pointer or
-    // missmatching the vector type are internal errors.
+    // mismatching the vector type are internal errors.
     if (i >= static_cast < unsigned int >(_length))
         throw InternalErr(__FILE__, __LINE__,
                           "Invalid data: index too large.");
@@ -1130,11 +1170,11 @@ Vector::set_value(vector<string> &val, int sz)
 //@}
 
 //@{
-/** @brief Get a copy of the data held by this variable. 
-    Read data from this variable's internal storage and load it into the 
+/** @brief Get a copy of the data held by this variable.
+    Read data from this variable's internal storage and load it into the
     memory referenced by \c b. The argument \c b must point to enough memory
     to hold length() Bytes.
-    
+
     @param b A pointer to the memory to hold the data; must be at least
     length() * sizeof(dods_byte) in size.*/
 void Vector::value(dods_byte *b) const
@@ -1195,18 +1235,18 @@ void Vector::value(dods_float64 *b) const
 /** @brief Get a copy of the data held by this variable. */
 void Vector::value(vector<string> &b) const
 {
-    if (_var->type() == dods_byte_c)
+    if (_var->type() == dods_byte_c || _var->type() == dods_url_c)
         b = d_str;
 }
 
-/** Allocated memory and copy data into the new buffer. Return the new 
+/** Allocated memory and copy data into the new buffer. Return the new
     buffer's pointer. The caller must delete the storage. */
 void *Vector::value()
 {
     void *buffer = new char[width()];
 
     memcpy(buffer, _buf, width());
-    
+
     return buffer;
 }
 //@}
