@@ -110,10 +110,11 @@
 
 
 #define YYSTYPE char *
+#define ATTR_STRING_QUOTE_FIX
 
 #include "config.h"
 
-static char rcsid[] not_used = {"$Id: das.y 18315 2008-03-03 20:14:44Z jimg $"};
+static char rcsid[] not_used = {"$Id: das.y 20873 2009-05-08 23:28:18Z jimg $"};
 
 #include <string>
 
@@ -123,6 +124,7 @@ static char rcsid[] not_used = {"$Id: das.y 18315 2008-03-03 20:14:44Z jimg $"};
 #include "Error.h"
 #include "debug.h"
 #include "parser.h"
+#include "util.h"
 #include "das.tab.hh"
 
 #ifdef TRACE_NEW
@@ -218,7 +220,7 @@ typedef int YYSTYPE;
 
 
 /* Line 216 of yacc.c.  */
-#line 222 "das.tab.cc"
+#line 224 "das.tab.cc"
 
 #ifdef short
 # undef short
@@ -528,14 +530,14 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   180,   180,   180,   195,   196,   200,   201,   207,   208,
-     209,   212,   214,   215,   214,   218,   219,   218,   222,   223,
-     222,   226,   227,   226,   230,   231,   230,   234,   235,   234,
-     238,   239,   238,   242,   243,   242,   246,   247,   246,   251,
-     271,   250,   279,   278,   284,   288,   294,   298,   304,   308,
-     314,   318,   324,   328,   334,   338,   344,   348,   354,   358,
-     364,   368,   374,   377,   380,   383,   383,   383,   383,   383,
-     384,   384,   384,   384,   385,   385,   385,   389,   393,   388
+       0,   182,   182,   182,   199,   200,   204,   205,   211,   212,
+     213,   216,   218,   219,   218,   222,   223,   222,   226,   227,
+     226,   230,   231,   230,   234,   235,   234,   238,   239,   238,
+     242,   243,   242,   246,   247,   246,   250,   251,   250,   255,
+     275,   254,   283,   282,   288,   292,   298,   302,   308,   312,
+     318,   322,   328,   332,   338,   342,   348,   352,   358,   363,
+     370,   374,   380,   383,   386,   389,   389,   389,   389,   389,
+     390,   390,   390,   390,   391,   391,   391,   395,   399,   394
 };
 #endif
 
@@ -1520,17 +1522,19 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 180 "das.y"
+#line 182 "das.y"
     {
 		name = new string();
 		type = new string();
 		attr_tab_stack = new vector<AttrTable *>;
-		PUSH(DAS_OBJ(arg)); // push outermost AttrTable
+
+		// push outermost AttrTable
+		PUSH(DAS_OBJ(arg)->get_top_level_attributes());
 	;}
     break;
 
   case 3:
-#line 187 "das.y"
+#line 191 "das.y"
     {
 		POP;	// pop the DAS/AttrTable before stack's dtor
 		delete name;
@@ -1540,104 +1544,104 @@ yyreduce:
     break;
 
   case 7:
-#line 202 "das.y"
+#line 206 "das.y"
     {
 		    parse_error((parser_arg *)arg, NO_DAS_MSG, das_line_num);
 		;}
     break;
 
   case 12:
-#line 214 "das.y"
+#line 218 "das.y"
     { save_str(*type, "Byte", das_line_num); ;}
     break;
 
   case 13:
-#line 215 "das.y"
-    { save_str(*name, (yyvsp[(3) - (3)]), das_line_num); ;}
-    break;
-
-  case 15:
-#line 218 "das.y"
-    { save_str(*type, "Int16", das_line_num); ;}
-    break;
-
-  case 16:
 #line 219 "das.y"
     { save_str(*name, (yyvsp[(3) - (3)]), das_line_num); ;}
     break;
 
-  case 18:
+  case 15:
 #line 222 "das.y"
-    { save_str(*type, "UInt16", das_line_num); ;}
+    { save_str(*type, "Int16", das_line_num); ;}
     break;
 
-  case 19:
+  case 16:
 #line 223 "das.y"
     { save_str(*name, (yyvsp[(3) - (3)]), das_line_num); ;}
     break;
 
-  case 21:
+  case 18:
 #line 226 "das.y"
-    { save_str(*type, "Int32", das_line_num); ;}
+    { save_str(*type, "UInt16", das_line_num); ;}
     break;
 
-  case 22:
+  case 19:
 #line 227 "das.y"
     { save_str(*name, (yyvsp[(3) - (3)]), das_line_num); ;}
     break;
 
-  case 24:
+  case 21:
 #line 230 "das.y"
-    { save_str(*type, "UInt32", das_line_num); ;}
+    { save_str(*type, "Int32", das_line_num); ;}
     break;
 
-  case 25:
+  case 22:
 #line 231 "das.y"
     { save_str(*name, (yyvsp[(3) - (3)]), das_line_num); ;}
     break;
 
-  case 27:
+  case 24:
 #line 234 "das.y"
-    { save_str(*type, "Float32", das_line_num); ;}
+    { save_str(*type, "UInt32", das_line_num); ;}
     break;
 
-  case 28:
+  case 25:
 #line 235 "das.y"
     { save_str(*name, (yyvsp[(3) - (3)]), das_line_num); ;}
     break;
 
-  case 30:
+  case 27:
 #line 238 "das.y"
-    { save_str(*type, "Float64", das_line_num); ;}
+    { save_str(*type, "Float32", das_line_num); ;}
     break;
 
-  case 31:
+  case 28:
 #line 239 "das.y"
     { save_str(*name, (yyvsp[(3) - (3)]), das_line_num); ;}
     break;
 
-  case 33:
+  case 30:
 #line 242 "das.y"
+    { save_str(*type, "Float64", das_line_num); ;}
+    break;
+
+  case 31:
+#line 243 "das.y"
+    { save_str(*name, (yyvsp[(3) - (3)]), das_line_num); ;}
+    break;
+
+  case 33:
+#line 246 "das.y"
     { *type = "String"; ;}
     break;
 
   case 34:
-#line 243 "das.y"
-    { *name = (yyvsp[(3) - (3)]); ;}
-    break;
-
-  case 36:
-#line 246 "das.y"
-    { *type = "Url"; ;}
-    break;
-
-  case 37:
 #line 247 "das.y"
     { *name = (yyvsp[(3) - (3)]); ;}
     break;
 
-  case 39:
+  case 36:
+#line 250 "das.y"
+    { *type = "Url"; ;}
+    break;
+
+  case 37:
 #line 251 "das.y"
+    { *name = (yyvsp[(3) - (3)]); ;}
+    break;
+
+  case 39:
+#line 255 "das.y"
     {
 		    DBG(cerr << "Processing ID: " << (yyvsp[(1) - (1)]) << endl);
 		    
@@ -1660,7 +1664,7 @@ yyreduce:
     break;
 
   case 40:
-#line 271 "das.y"
+#line 275 "das.y"
     {
 		    /* pop top of stack; store in attr_tab */
 		    DBG(cerr << " Popped attr_tab: " << TOP_OF_STACK << endl);
@@ -1669,155 +1673,158 @@ yyreduce:
     break;
 
   case 42:
-#line 279 "das.y"
+#line 283 "das.y"
     { 
 		    parse_error(ATTR_TUPLE_MSG, das_line_num, (yyvsp[(1) - (1)]));
 		;}
     break;
 
   case 44:
-#line 285 "das.y"
+#line 289 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_byte);
 		;}
     break;
 
   case 45:
-#line 289 "das.y"
+#line 293 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_byte);
 		;}
     break;
 
   case 46:
-#line 295 "das.y"
+#line 299 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_int16);
 		;}
     break;
 
   case 47:
-#line 299 "das.y"
+#line 303 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_int16);
 		;}
     break;
 
   case 48:
-#line 305 "das.y"
+#line 309 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_uint16);
 		;}
     break;
 
   case 49:
-#line 309 "das.y"
+#line 313 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_uint16);
 		;}
     break;
 
   case 50:
-#line 315 "das.y"
+#line 319 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_int32);
 		;}
     break;
 
   case 51:
-#line 319 "das.y"
+#line 323 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_int32);
 		;}
     break;
 
   case 52:
-#line 325 "das.y"
+#line 329 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_uint32);
 		;}
     break;
 
   case 53:
-#line 329 "das.y"
+#line 333 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_uint32);
 		;}
     break;
 
   case 54:
-#line 335 "das.y"
+#line 339 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_float32);
 		;}
     break;
 
   case 55:
-#line 339 "das.y"
+#line 343 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_float32);
 		;}
     break;
 
   case 56:
-#line 345 "das.y"
+#line 349 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_float64);
 		;}
     break;
 
   case 57:
-#line 349 "das.y"
+#line 353 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_float64);
 		;}
     break;
 
   case 58:
-#line 355 "das.y"
+#line 359 "das.y"
     {
-		    add_attribute(*type, *name, (yyvsp[(1) - (1)]), 0);
+		    string attr = remove_quotes((yyvsp[(1) - (1)]));
+		    add_attribute(*type, *name, attr, 0);
 		;}
     break;
 
   case 59:
-#line 359 "das.y"
+#line 364 "das.y"
     {
-		    add_attribute(*type, *name, (yyvsp[(3) - (3)]), 0);
+		    string attr = remove_quotes((yyvsp[(3) - (3)]));
+		    add_attribute(*type, *name, attr, 0);
 		;}
     break;
 
   case 60:
-#line 365 "das.y"
+#line 371 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_url);
 		;}
     break;
 
   case 61:
-#line 369 "das.y"
+#line 375 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_url);
 		;}
     break;
 
   case 77:
-#line 389 "das.y"
+#line 395 "das.y"
     { 
 		    *name = (yyvsp[(2) - (2)]);
 		;}
     break;
 
   case 78:
-#line 393 "das.y"
+#line 399 "das.y"
     {
-		    add_alias(DAS_OBJ(arg), TOP_OF_STACK, *name, string((yyvsp[(4) - (4)])))
+		    add_alias( DAS_OBJ(arg)->get_top_level_attributes(),
+		               TOP_OF_STACK, *name, string((yyvsp[(4) - (4)])) ) ;
                 ;}
     break;
 
 
 /* Line 1267 of yacc.c.  */
-#line 1821 "das.tab.cc"
+#line 1828 "das.tab.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -2031,7 +2038,7 @@ yyreturn:
 }
 
 
-#line 399 "das.y"
+#line 406 "das.y"
 
 
 // This function is required for linking, but DODS uses its own error
@@ -2135,8 +2142,12 @@ add_bad_attribute(AttrTable *attr, const string &type, const string &name,
 	    error_cont = attr->append_container(error_cont_name);
 
 	error_cont->append_attr(name, type, value);
-	error_cont->append_attr(name + "_explanation", "String",
-				"\"" + msg + "\"");
+#ifndef ATTR_STRING_QUOTE_FIX
+    error_cont->append_attr(name + "_explanation", "String",
+                "\"" + msg + "\"");
+#else
+       error_cont->append_attr(name + "_explanation", "String", msg);
+#endif
     }
 }
 
