@@ -119,7 +119,7 @@
 
 #include "config_dap.h"
 
-static char rcsid[] not_used = {"$Id: dds.y 18315 2008-03-03 20:14:44Z jimg $"};
+static char rcsid[] not_used = {"$Id: dds.y 20091 2009-01-29 00:02:40Z jimg $"};
 
 #include <cstring>
 #include <cassert>
@@ -520,7 +520,7 @@ static const yytype_uint16 yyrline[] =
      285,   296,   302,   308,   314,   315,   316,   317,   318,   319,
      320,   321,   322,   325,   326,   329,   329,   329,   329,   329,
      330,   330,   330,   330,   331,   331,   331,   331,   332,   335,
-     357,   361,   356,   385,   396,   397,   398
+     359,   363,   358,   390,   401,   402,   403
 };
 #endif
 
@@ -1782,18 +1782,20 @@ yyreduce:
 			 if( current ) delete current ;
 			 current = a;
 		     }
+
+		     (yyval.boolean) = true;
 		 ;}
     break;
 
   case 50:
-#line 357 "dds.y"
+#line 359 "dds.y"
     {
 		     id = new string((yyvsp[(2) - (2)].word));
 		 ;}
     break;
 
   case 51:
-#line 361 "dds.y"
+#line 363 "dds.y"
     { 
 		     if (!check_int32((yyvsp[(5) - (5)].word))) {
 			 string msg = "In the dataset descriptor object:\n";
@@ -1818,8 +1820,15 @@ yyreduce:
 		 ;}
     break;
 
-  case 53:
+  case 52:
 #line 386 "dds.y"
+    {
+		     (yyval.boolean) = true;
+		 ;}
+    break;
+
+  case 53:
+#line 391 "dds.y"
     {
 		     ostringstream msg;
 		     msg << "In the dataset descriptor object:" << endl
@@ -1831,17 +1840,17 @@ yyreduce:
     break;
 
   case 54:
-#line 396 "dds.y"
+#line 401 "dds.y"
     { (*DDS_OBJ(arg)).set_dataset_name((yyvsp[(1) - (1)].word)); ;}
     break;
 
   case 55:
-#line 397 "dds.y"
+#line 402 "dds.y"
     { (*DDS_OBJ(arg)).set_dataset_name((yyvsp[(1) - (1)].word)); ;}
     break;
 
   case 56:
-#line 399 "dds.y"
+#line 404 "dds.y"
     {
 		  ostringstream msg;
 		  msg << "Error parsing the dataset name." << endl
@@ -1854,7 +1863,7 @@ yyreduce:
 
 
 /* Line 1267 of yacc.c.  */
-#line 1858 "dds.tab.cc"
+#line 1867 "dds.tab.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -2068,7 +2077,7 @@ yyreturn:
 }
 
 
-#line 409 "dds.y"
+#line 414 "dds.y"
 
 
 /* 
