@@ -38,6 +38,9 @@
 
 using std::string;
 
+namespace libdap
+{
+
 string hexstring(unsigned char val);
 string unhexstring(string s);
 string octstring(unsigned char val);
@@ -73,5 +76,7 @@ string unescattr(string s);
 
 string munge_error_message(string msg);
 
+} // namespace libdap
+
 #endif // _escaping_h
 
