@@ -58,8 +58,7 @@ typedef struct
         double f;
         string *s;
     } v;
-}
-value;
+} value;
 
 // Syntactic sugar for `pointer to function returning boolean' (bool_func)
 // and `pointer to function returning BaseType *' (btp_func). Both function
@@ -68,9 +67,10 @@ value;
 // evaluated (analogous to the ENVP in UNIX). ARGC is the length of ARGV.
 
 // Try to make a single `selection function' type.
-
-typedef bool(*bool_func)(int argc, BaseType *argv[], DDS &dds);
-typedef BaseType *(*btp_func)(int argc, BaseType *argv[], DDS &dds, const string &dataset);
+#if 1
+typedef void(*bool_func)(int argc, BaseType *argv[], DDS &dds, bool *result);
+#endif
+typedef void(*btp_func)(int argc, BaseType *argv[], DDS &dds, BaseType **btpp);
 typedef void(*proj_func)(int argc, BaseType *argv[], DDS &dds, ConstraintEvaluator &ce);
 
 // INT_LIST and INT_LIST_LIST are used by the parser to store the array
