@@ -36,7 +36,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    { "$Id: getdap.cc 18315 2008-03-03 20:14:44Z jimg $"
+    { "$Id: getdap.cc 19917 2008-11-25 23:47:56Z jimg $"
     };
 
 #ifdef WIN32
@@ -44,9 +44,11 @@ static char rcsid[] not_used =
 #include <fcntl.h>
 #endif
 
-#include <GetOpt.h>
 #include <cstring>
 #include <string>
+#include <sstream>
+
+#include "GetOpt.h"
 
 #include "AISConnect.h"
 #include "Response.h"
@@ -54,6 +56,7 @@ static char rcsid[] not_used =
 
 using std::cerr;
 using std::endl;
+using std::flush;
 
 using namespace libdap ;
 
@@ -67,7 +70,7 @@ void usage(string name)
     cerr <<
     " [idDaxAVvks] [-B <db>][-c <expr>][-m <num>] <url> [<url> ...]" <<
     endl;
-    cerr << " [Vvks] <file> [<file> ...]" << endl;
+    cerr << " [VvksM] <file> [<file> ...]" << endl;
     cerr << endl;
     cerr << "In the first form of the command, dereference the URL and"
     << endl;
@@ -104,14 +107,15 @@ void usage(string name)
     cerr << "        B: <AIS xml dataBase>. Overrides .dodsrc." << endl;
     cerr << "        v: Verbose." << endl;
     cerr << "        V: Version." << endl;
-    cerr << "        c: <expr> is a contraint expression. Used with -D." <<
+    cerr << "        c: <expr> is a constraint expression. Used with -D." <<
     endl;
     cerr << "           NB: You can use a `?' for the CE also." << endl;
-    cerr << "        k: Keep temporary files created by libdap core\n" <<
-    endl;
+    cerr << "        k: Keep temporary files created by libdap core" << endl;
     cerr << "        m: Request the same URL <num> times." << endl;
     cerr << "        z: Ask the server to compress data." << endl;
     cerr << "        s: Print Sequences using numbered rows." << endl;
+    cerr << "        M: Assume data read from a file has no MIME headers" << endl;
+    cerr << "           (the default is to assume the headers are present)." << endl;
 }
 
 bool read_data(FILE * fp)
@@ -132,23 +136,22 @@ bool read_data(FILE * fp)
 
 static void print_data(DDS & dds, bool print_rows = false)
 {
-    fprintf(stdout, "The data:\n");
+    cout << "The data:" << endl;
 
     for (DDS::Vars_iter i = dds.var_begin(); i != dds.var_end(); i++) {
         BaseType *v = *i;
         if (print_rows && (*i)->type() == dods_sequence_c)
-            dynamic_cast < Sequence * >(*i)->print_val_by_rows(stdout);
+            dynamic_cast < Sequence * >(*i)->print_val_by_rows(cout);
         else
-            v->print_val(stdout);
+            v->print_val(cout);
     }
 
-    fprintf(stdout, "\n");
-    fflush(stdout);
+    cout << endl << flush;
 }
 
 int main(int argc, char *argv[])
 {
-    GetOpt getopt(argc, argv, "idaDxXAVvkB:c:m:zsh?H");
+    GetOpt getopt(argc, argv, "idaDxXAVvkB:c:m:zshM?Hp:");
     int option_char;
 
     bool get_das = false;
@@ -163,7 +166,10 @@ int main(int argc, char *argv[])
     bool accept_deflate = false;
     bool print_rows = false;
     bool use_ais = false;
+    bool mime_headers = true;
     int times = 1;
+    int dap_client_major = 2;
+    int dap_client_minor = 0;
     string expr = "";
     string ais_db = "";
 
@@ -221,6 +227,17 @@ int main(int argc, char *argv[])
         case 's':
             print_rows = true;
             break;
+        case 'M':
+            mime_headers = false;
+            break;
+        case 'p': {
+            istringstream iss(getopt.optarg);
+            char dot;
+            iss >> dap_client_major;
+            iss >> dot;
+            iss >> dap_client_minor;
+            break;
+        }
         case 'h':
         case '?':
         default:
@@ -252,6 +269,9 @@ int main(int argc, char *argv[])
             if (accept_deflate)
                 url->set_accept_deflate(accept_deflate);
 
+            if (dap_client_major > 2)
+                url->set_xdap_protocol(dap_client_major, dap_client_minor);
+
             if (url->is_local()) {
                 if (verbose) {
                     fprintf(stderr,
@@ -269,7 +289,10 @@ int main(int argc, char *argv[])
                         if (!r->get_stream())
                             throw Error("Could not open standard input.");
 
-                        url->read_data(dds, r);
+                        if (mime_headers)
+                            url->read_data(dds, r); // The default case
+                        else
+                            url->read_data_no_mime(dds, r);
                     }
                     else {
                         r = new Response(fopen(argv[i], "r"), 0);
@@ -353,7 +376,7 @@ int main(int argc, char *argv[])
                         fprintf(stderr, "DDS:\n");
                     }
 
-                    dds.print(stdout);
+                    dds.print(cout);
                 }
             }
 
@@ -377,7 +400,7 @@ int main(int argc, char *argv[])
                         fprintf(stderr, "DDX:\n");
                     }
 
-                    dds.print_xml(stdout, false, "getdap; no blob yet");
+                    dds.print_xml(cout, false, "getdap; no blob yet");
                 }
             }
 
@@ -386,7 +409,7 @@ int main(int argc, char *argv[])
                     BaseTypeFactory factory;
                     DDS dds(&factory);
                     try {
-                        url->request_dds(dds);
+                        url->request_dds(dds, expr);
                         DAS das;
                         url->request_das(das);
                         dds.transfer_attributes(&das);
@@ -404,15 +427,11 @@ int main(int argc, char *argv[])
                         fprintf(stderr, "Client-built DDX:\n");
                     }
 
-                    dds.print_xml(stdout, false, "getdap; no blob yet");
+                    dds.print_xml(cout, false, "getdap; no blob yet");
                 }
             }
 
             else if (get_data) {
-#if 0
-                if (expr.empty() && name.find('?') == string::npos)
-                    expr = "";
-#endif
                 for (int j = 0; j < times; ++j) {
                     BaseTypeFactory factory;
                     DataDDS dds(&factory);
@@ -449,6 +468,9 @@ int main(int argc, char *argv[])
                 if (accept_deflate)
                     http.set_accept_deflate(accept_deflate);
 
+                if (dap_client_major > 2)
+                    url->set_xdap_protocol(dap_client_major, dap_client_minor);
+
                 string url_string = argv[i];
                 for (int j = 0; j < times; ++j) {
                     try {
