@@ -53,29 +53,29 @@ extern "C" {
    regoff_t be at least as wide as ptrdiff_t and ssize_t; see XBD ERN
    60 (2005-08-25).  We don't know of any hosts where ssize_t or
    ptrdiff_t is wider than ssize_t, so ssize_t is safe.  */
-    typedef ssize_t regoff_t;
+typedef ssize_t regoff_t;
 
 /* The type of nonnegative object indexes.  Traditionally, GNU regex
    uses 'int' for these.  Code that uses __re_idx_t should work
    regardless of whether the type is signed.  */
-    typedef size_t __re_idx_t;
+typedef size_t __re_idx_t;
 
 /* The type of object sizes.  */
-    typedef size_t __re_size_t;
+typedef size_t __re_size_t;
 
 /* The type of object sizes, in places where the traditional code
    uses unsigned long int.  */
-    typedef size_t __re_long_size_t;
+typedef size_t __re_long_size_t;
 
 #else
 
 /* Use types that are binary-compatible with the traditional GNU regex
    implementation, which mishandles strings longer than INT_MAX.  */
 
-    typedef int regoff_t;
-    typedef int __re_idx_t;
-    typedef unsigned int __re_size_t;
-    typedef unsigned long int __re_long_size_t;
+typedef int regoff_t;
+typedef int __re_idx_t;
+typedef unsigned int __re_size_t;
+typedef unsigned long int __re_long_size_t;
 
 #endif
 
@@ -83,15 +83,15 @@ extern "C" {
    wide enough to hold a value of a pointer.  For most ANSI compilers
    ptrdiff_t and size_t should be likely OK.  Still size of these two
    types is 2 for Microsoft C.  Ugh... */
-    typedef long int s_reg_t;
-    typedef unsigned long int active_reg_t;
+typedef long int s_reg_t;
+typedef unsigned long int active_reg_t;
 
 /* The following bits are used to determine the regexp syntax we
    recognize.  The set/not-set meanings are chosen so that Emacs syntax
    remains the value 0.  The bits are given in alphabetical order, and
    the definitions shifted by one from the previous bit; thus, when we
    add or remove a bit, only one other definition need change.  */
-    typedef unsigned long int reg_syntax_t;
+typedef unsigned long int reg_syntax_t;
 
 #ifdef __USE_GNU_REGEX
 
@@ -226,13 +226,13 @@ extern "C" {
    re_compile_pattern.  */
 # define RE_NO_SUB (RE_CONTEXT_INVALID_DUP << 1)
 
-#endif                          /* defined __USE_GNU_REGEX */
+#endif /* defined __USE_GNU_REGEX */
 
 /* This global variable defines the particular regexp syntax to use (for
    some interfaces).  When a regexp is compiled, the syntax used is
    stored in the pattern buffer, so changing this does not affect
    already-compiled regexps.  */
-    extern reg_syntax_t re_syntax_options;
+extern reg_syntax_t re_syntax_options;
 
 #ifdef __USE_GNU_REGEX
 /* Define combinations of the above bits for the standard possibilities.
@@ -306,7 +306,7 @@ extern "C" {
    | RE_NO_BK_VBAR	    | RE_UNMATCHED_RIGHT_PAREN_ORD)
 /* [[[end syntaxes]]] */
 
-#endif                          /* defined __USE_GNU_REGEX */
+#endif /* defined __USE_GNU_REGEX */
 
 #ifdef __USE_GNU_REGEX
 
@@ -326,7 +326,7 @@ extern "C" {
    its historical value.  */
 # define RE_DUP_MAX (0x7fff)
 
-#endif                          /* defined __USE_GNU_REGEX */
+#endif /* defined __USE_GNU_REGEX */
 
 
 /* POSIX `cflags' bits (i.e., information for `regcomp').  */
@@ -369,31 +369,32 @@ extern "C" {
 /* If any error codes are removed, changed, or added, update the
    `__re_error_msgid' table in regcomp.c.  */
 
-    typedef enum {
-        _REG_ENOSYS = -1,       /* This will never happen for this implementation.  */
-        _REG_NOERROR = 0,       /* Success.  */
-        _REG_NOMATCH,           /* Didn't find a match (for regexec).  */
+typedef enum
+{
+  _REG_ENOSYS = -1,	/* This will never happen for this implementation.  */
+  _REG_NOERROR = 0,	/* Success.  */
+  _REG_NOMATCH,		/* Didn't find a match (for regexec).  */
 
-        /* POSIX regcomp return error codes.  (In the order listed in the
-           standard.)  */
-        _REG_BADPAT,            /* Invalid pattern.  */
-        _REG_ECOLLATE,          /* Invalid collating element.  */
-        _REG_ECTYPE,            /* Invalid character class name.  */
-        _REG_EESCAPE,           /* Trailing backslash.  */
-        _REG_ESUBREG,           /* Invalid back reference.  */
-        _REG_EBRACK,            /* Unmatched left bracket.  */
-        _REG_EPAREN,            /* Parenthesis imbalance.  */
-        _REG_EBRACE,            /* Unmatched \{.  */
-        _REG_BADBR,             /* Invalid contents of \{\}.  */
-        _REG_ERANGE,            /* Invalid range end.  */
-        _REG_ESPACE,            /* Ran out of memory.  */
-        _REG_BADRPT,            /* No preceding re for repetition op.  */
+  /* POSIX regcomp return error codes.  (In the order listed in the
+     standard.)  */
+  _REG_BADPAT,		/* Invalid pattern.  */
+  _REG_ECOLLATE,	/* Invalid collating element.  */
+  _REG_ECTYPE,		/* Invalid character class name.  */
+  _REG_EESCAPE,		/* Trailing backslash.  */
+  _REG_ESUBREG,		/* Invalid back reference.  */
+  _REG_EBRACK,		/* Unmatched left bracket.  */
+  _REG_EPAREN,		/* Parenthesis imbalance.  */
+  _REG_EBRACE,		/* Unmatched \{.  */
+  _REG_BADBR,		/* Invalid contents of \{\}.  */
+  _REG_ERANGE,		/* Invalid range end.  */
+  _REG_ESPACE,		/* Ran out of memory.  */
+  _REG_BADRPT,		/* No preceding re for repetition op.  */
 
-        /* Error codes we've added.  */
-        _REG_EEND,              /* Premature end.  */
-        _REG_ESIZE,             /* Compiled pattern bigger than 2^16 bytes.  */
-        _REG_ERPAREN            /* Unmatched ) or \); not returned from regcomp.  */
-    } reg_errcode_t;
+  /* Error codes we've added.  */
+  _REG_EEND,		/* Premature end.  */
+  _REG_ESIZE,		/* Compiled pattern bigger than 2^16 bytes.  */
+  _REG_ERPAREN		/* Unmatched ) or \); not returned from regcomp.  */
+} reg_errcode_t;
 
 #ifdef _XOPEN_SOURCE
 # define REG_ENOSYS	_REG_ENOSYS
@@ -446,82 +447,84 @@ extern "C" {
    compiled, the `re_nsub' field is available.  All other fields are
    private to the regex routines.  */
 
-    struct re_pattern_buffer {
-        /* Space that holds the compiled pattern.  It is declared as
-           `unsigned char *' because its elements are sometimes used as
-           array indexes.  */
-        unsigned char *_REG_RE_NAME(buffer);
+struct re_pattern_buffer
+{
+  /* Space that holds the compiled pattern.  It is declared as
+     `unsigned char *' because its elements are sometimes used as
+     array indexes.  */
+  unsigned char *_REG_RE_NAME (buffer);
 
-        /* Number of bytes to which `buffer' points.  */
-        __re_long_size_t _REG_RE_NAME(allocated);
+  /* Number of bytes to which `buffer' points.  */
+  __re_long_size_t _REG_RE_NAME (allocated);
 
-        /* Number of bytes actually used in `buffer'.  */
-        __re_long_size_t _REG_RE_NAME(used);
+  /* Number of bytes actually used in `buffer'.  */
+  __re_long_size_t _REG_RE_NAME (used);
 
-        /* Syntax setting with which the pattern was compiled.  */
-        reg_syntax_t _REG_RE_NAME(syntax);
+  /* Syntax setting with which the pattern was compiled.  */
+  reg_syntax_t _REG_RE_NAME (syntax);
 
-        /* Pointer to a fastmap, if any, otherwise zero.  re_search uses the
-           fastmap, if there is one, to skip over impossible starting points
-           for matches.  */
-        char *_REG_RE_NAME(fastmap);
+  /* Pointer to a fastmap, if any, otherwise zero.  re_search uses the
+     fastmap, if there is one, to skip over impossible starting points
+     for matches.  */
+  char *_REG_RE_NAME (fastmap);
 
-        /* Either a translate table to apply to all characters before
-           comparing them, or zero for no translation.  The translation is
-           applied to a pattern when it is compiled and to a string when it
-           is matched.  */
-        REG_TRANSLATE_TYPE _REG_RE_NAME(translate);
+  /* Either a translate table to apply to all characters before
+     comparing them, or zero for no translation.  The translation is
+     applied to a pattern when it is compiled and to a string when it
+     is matched.  */
+  REG_TRANSLATE_TYPE _REG_RE_NAME (translate);
 
-        /* Number of subexpressions found by the compiler.  */
-        size_t re_nsub;
+  /* Number of subexpressions found by the compiler.  */
+  size_t re_nsub;
 
-        /* Zero if this pattern cannot match the empty string, one else.
-           Well, in truth it's used only in `re_search_2', to see whether or
-           not we should use the fastmap, so we don't set this absolutely
-           perfectly; see `re_compile_fastmap' (the `duplicate' case).  */
-        unsigned int _REG_RE_NAME(can_be_null):1;
+  /* Zero if this pattern cannot match the empty string, one else.
+     Well, in truth it's used only in `re_search_2', to see whether or
+     not we should use the fastmap, so we don't set this absolutely
+     perfectly; see `re_compile_fastmap' (the `duplicate' case).  */
+  unsigned int _REG_RE_NAME (can_be_null) : 1;
 
-        /* If REGS_UNALLOCATED, allocate space in the `regs' structure
-           for `max (RE_NREGS, re_nsub + 1)' groups.
-           If REGS_REALLOCATE, reallocate space if necessary.
-           If REGS_FIXED, use what's there.  */
+  /* If REGS_UNALLOCATED, allocate space in the `regs' structure
+     for `max (RE_NREGS, re_nsub + 1)' groups.
+     If REGS_REALLOCATE, reallocate space if necessary.
+     If REGS_FIXED, use what's there.  */
 #ifdef __USE_GNU_REGEX
 # define REGS_UNALLOCATED 0
 # define REGS_REALLOCATE 1
 # define REGS_FIXED 2
 #endif
-        unsigned int _REG_RE_NAME(regs_allocated):2;
+  unsigned int _REG_RE_NAME (regs_allocated) : 2;
 
-        /* Set to zero when `regex_compile' compiles a pattern; set to one
-           by `re_compile_fastmap' if it updates the fastmap.  */
-        unsigned int _REG_RE_NAME(fastmap_accurate):1;
+  /* Set to zero when `regex_compile' compiles a pattern; set to one
+     by `re_compile_fastmap' if it updates the fastmap.  */
+  unsigned int _REG_RE_NAME (fastmap_accurate) : 1;
 
-        /* If set, `re_match_2' does not return information about
-           subexpressions.  */
-        unsigned int _REG_RE_NAME(no_sub):1;
+  /* If set, `re_match_2' does not return information about
+     subexpressions.  */
+  unsigned int _REG_RE_NAME (no_sub) : 1;
 
-        /* If set, a beginning-of-line anchor doesn't match at the beginning
-           of the string.  */
-        unsigned int _REG_RE_NAME(not_bol):1;
+  /* If set, a beginning-of-line anchor doesn't match at the beginning
+     of the string.  */
+  unsigned int _REG_RE_NAME (not_bol) : 1;
 
-        /* Similarly for an end-of-line anchor.  */
-        unsigned int _REG_RE_NAME(not_eol):1;
+  /* Similarly for an end-of-line anchor.  */
+  unsigned int _REG_RE_NAME (not_eol) : 1;
 
-        /* If true, an anchor at a newline matches.  */
-        unsigned int _REG_RE_NAME(newline_anchor):1;
+  /* If true, an anchor at a newline matches.  */
+  unsigned int _REG_RE_NAME (newline_anchor) : 1;
 
 /* [[[end pattern_buffer]]] */
-    };
+};
 
-    typedef struct re_pattern_buffer regex_t;
+typedef struct re_pattern_buffer regex_t;
 
 /* This is the structure we store register match data in.  See
    regex.texinfo for a full description of what registers match.  */
-    struct re_registers {
-        __re_size_t _REG_RM_NAME(num_regs);
-        regoff_t *_REG_RM_NAME(start);
-        regoff_t *_REG_RM_NAME(end);
-    };
+struct re_registers
+{
+  __re_size_t _REG_RM_NAME (num_regs);
+  regoff_t *_REG_RM_NAME (start);
+  regoff_t *_REG_RM_NAME (end);
+};
 
 
 /* If `regs_allocated' is REGS_UNALLOCATED in the pattern buffer,
@@ -535,30 +538,29 @@ extern "C" {
 /* POSIX specification for registers.  Aside from the different names than
    `re_registers', POSIX uses an array of structures, instead of a
    structure of arrays.  */
-    typedef struct {
-        regoff_t rm_so;         /* Byte offset from string's start to substring's start.  */
-        regoff_t rm_eo;         /* Byte offset from string's start to substring's end.  */
-    } regmatch_t;
+typedef struct
+{
+  regoff_t rm_so;  /* Byte offset from string's start to substring's start.  */
+  regoff_t rm_eo;  /* Byte offset from string's start to substring's end.  */
+} regmatch_t;
 
 /* Declarations for routines.  */
 
 /* Sets the current default syntax to SYNTAX, and return the old syntax.
    You can also simply assign to the `re_syntax_options' variable.  */
-    extern reg_syntax_t re_set_syntax(reg_syntax_t __syntax);
+extern reg_syntax_t re_set_syntax (reg_syntax_t __syntax);
 
 /* Compile the regular expression PATTERN, with length LENGTH
    and syntax given by the global `re_syntax_options', into the buffer
    BUFFER.  Return NULL if successful, and an error string if not.  */
-    extern const char *re_compile_pattern(const char *__pattern,
-                                          size_t __length,
-                                          struct re_pattern_buffer
-                                          *__buffer);
+extern const char *re_compile_pattern (const char *__pattern, size_t __length,
+				       struct re_pattern_buffer *__buffer);
 
 
 /* Compile a fastmap for the compiled pattern in BUFFER; used to
    accelerate searches.  Return 0 if successful and -2 if was an
    internal error.  */
-    extern int re_compile_fastmap(struct re_pattern_buffer *__buffer);
+extern int re_compile_fastmap (struct re_pattern_buffer *__buffer);
 
 
 /* Search in the string STRING (with length LENGTH) for the pattern
@@ -566,39 +568,35 @@ extern "C" {
    characters.  Return the starting position of the match, -1 for no
    match, or -2 for an internal error.  Also return register
    information in REGS (if REGS and BUFFER->no_sub are nonzero).  */
-    extern regoff_t re_search(struct re_pattern_buffer *__buffer,
-                              const char *__string, __re_idx_t __length,
-                              __re_idx_t __start, regoff_t __range,
-                              struct re_registers *__regs);
+extern regoff_t re_search (struct re_pattern_buffer *__buffer,
+			   const char *__string, __re_idx_t __length,
+			   __re_idx_t __start, regoff_t __range,
+			   struct re_registers *__regs);
 
 
 /* Like `re_search', but search in the concatenation of STRING1 and
    STRING2.  Also, stop searching at index START + STOP.  */
-    extern regoff_t re_search_2(struct re_pattern_buffer *__buffer,
-                                const char *__string1,
-                                __re_idx_t __length1,
-                                const char *__string2,
-                                __re_idx_t __length2, __re_idx_t __start,
-                                regoff_t __range,
-                                struct re_registers *__regs,
-                                __re_idx_t __stop);
+extern regoff_t re_search_2 (struct re_pattern_buffer *__buffer,
+			     const char *__string1, __re_idx_t __length1,
+			     const char *__string2, __re_idx_t __length2,
+			     __re_idx_t __start, regoff_t __range,
+			     struct re_registers *__regs,
+			     __re_idx_t __stop);
 
 
 /* Like `re_search', but return how many characters in STRING the regexp
    in BUFFER matched, starting at position START.  */
-    extern regoff_t re_match(struct re_pattern_buffer *__buffer,
-                             const char *__string, __re_idx_t __length,
-                             __re_idx_t __start,
-                             struct re_registers *__regs);
+extern regoff_t re_match (struct re_pattern_buffer *__buffer,
+			  const char *__string, __re_idx_t __length,
+			  __re_idx_t __start, struct re_registers *__regs);
 
 
 /* Relates to `re_match' as `re_search_2' relates to `re_search'.  */
-    extern regoff_t re_match_2(struct re_pattern_buffer *__buffer,
-                               const char *__string1, __re_idx_t __length1,
-                               const char *__string2, __re_idx_t __length2,
-                               __re_idx_t __start,
-                               struct re_registers *__regs,
-                               __re_idx_t __stop);
+extern regoff_t re_match_2 (struct re_pattern_buffer *__buffer,
+			    const char *__string1, __re_idx_t __length1,
+			    const char *__string2, __re_idx_t __length2,
+			    __re_idx_t __start, struct re_registers *__regs,
+			    __re_idx_t __stop);
 
 
 /* Set REGS to hold NUM_REGS registers, storing them in STARTS and
@@ -613,16 +611,16 @@ extern "C" {
    Unless this function is called, the first search or match using
    PATTERN_BUFFER will allocate its own register data, without
    freeing the old data.  */
-    extern void re_set_registers(struct re_pattern_buffer *__buffer,
-                                 struct re_registers *__regs,
-                                 __re_size_t __num_regs,
-                                 regoff_t * __starts, regoff_t * __ends);
+extern void re_set_registers (struct re_pattern_buffer *__buffer,
+			      struct re_registers *__regs,
+			      __re_size_t __num_regs,
+			      regoff_t *__starts, regoff_t *__ends);
 
 #if defined _REGEX_RE_COMP || defined _LIBC
 # ifndef _CRAY
 /* 4.2 bsd compatibility.  */
-    extern char *re_comp(const char *);
-    extern int re_exec(const char *);
+extern char *re_comp (const char *);
+extern int re_exec (const char *);
 # endif
 #endif
 
@@ -655,22 +653,23 @@ extern "C" {
 #endif
 
 /* POSIX compatibility.  */
-    extern int regcomp(regex_t * _Restrict_ __preg,
-                       const char *_Restrict_ __pattern, int __cflags);
+extern int regcomp (regex_t *_Restrict_ __preg,
+		    const char *_Restrict_ __pattern,
+		    int __cflags);
 
-    extern int regexec(const regex_t * _Restrict_ __preg,
-                       const char *_Restrict_ __string, size_t __nmatch,
-                       regmatch_t __pmatch[_Restrict_arr_], int __eflags);
+extern int regexec (const regex_t *_Restrict_ __preg,
+		    const char *_Restrict_ __string, size_t __nmatch,
+		    regmatch_t __pmatch[_Restrict_arr_],
+		    int __eflags);
 
-    extern size_t regerror(int __errcode,
-                           const regex_t * _Restrict_ __preg,
-                           char *_Restrict_ __errbuf,
-                           size_t __errbuf_size);
+extern size_t regerror (int __errcode, const regex_t *_Restrict_ __preg,
+			char *_Restrict_ __errbuf, size_t __errbuf_size);
 
-    extern void regfree(regex_t * __preg);
+extern void regfree (regex_t *__preg);
 
 
 #ifdef __cplusplus
 }
-#endif                          /* C++ */
-#endif                          /* regex.h */
+#endif	/* C++ */
+
+#endif /* regex.h */
