@@ -37,6 +37,9 @@
 #define FALSE 0
 #endif
 
+namespace libdap
+{
+
 /** Argument to the GSE parser. Assumes all errors will be signaled by
     throws; Error objects are not returned. */
 struct gse_arg
@@ -77,3 +80,5 @@ struct gse_arg
         return _status;
     }
 };
+
+} // namespace libdap
