@@ -38,17 +38,19 @@
 
 #include "config.h"
 
-static char rcsid[] not_used = {"$Id: das-test.cc 13269 2006-02-24 18:54:20Z jimg $"};
+static char rcsid[] not_used = {"$Id: das-test.cc 18315 2008-03-03 20:14:44Z jimg $"};
 
+#include <cstdlib>
 #include <string>
 #include <GetOpt.h>
 
 #define YYSTYPE char *
 
 #include "DAS.h"
-#include "das.tab.h"
+#include "das.tab.hh"
 #include "Error.h"
 
+using namespace libdap ;
 
 void plain_driver(DAS &das, bool deref_alias);
 void load_attr_table(AttrTable at);
