@@ -26,6 +26,11 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
+#include "config.h"
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
 #include <cstring>
 #include <string>
 #include <iostream>
@@ -35,7 +40,7 @@
 #include <cppunit/extensions/TestFactoryRegistry.h>
 #include <cppunit/extensions/HelperMacros.h>
 
-#define DODS_DEBUG
+//#define DODS_DEBUG
 #include "RCReader.h"
 #include "debug.h"
 #include <test_config.h>
