@@ -28,7 +28,7 @@ using namespace std;
 using namespace libdap;
 
 int test_variable_sleep_interval = 0; // Used in Test* classes for testing
-				      // timeouts. 
+				      // timeouts.
 string cprint = "\
 Dataset {\n\
     Int16 var1;\n\
@@ -55,24 +55,45 @@ Dataset {\n\
 } Test%20Data%20Set;\n\
 " ;
 
+string containerprint = "\
+Dataset {\n\
+    Structure {\n\
+        Int16 c1var1;\n\
+        Int16 c1var3;\n\
+    } c1;\n\
+    Structure {\n\
+        String c2var2;\n\
+        Structure {\n\
+            Structure {\n\
+                Int16 c2var3var1var1;\n\
+                Int16 c2var3var1var2;\n\
+            } c2var3var1;\n\
+        } c2var3;\n\
+    } c2;\n\
+    Byte var1;\n\
+    Float64 var2;\n\
+} TestDDS;\n\
+" ;
+
 
 class ddsT : public CppUnit::TestFixture {
 
 CPPUNIT_TEST_SUITE( ddsT ) ;
 CPPUNIT_TEST( ddsT_test ) ;
+CPPUNIT_TEST( ddsT_containers ) ;
 CPPUNIT_TEST_SUITE_END( ) ;
 
 private:
     /* TEST PRIVATE DATA */
     TestTypeFactory *factory;
-    
+
 public:
     void setUp()
     {
         factory = new TestTypeFactory;
     }
 
-    void tearDown() 
+    void tearDown()
     {
         delete factory; factory = 0;
     }
@@ -184,7 +205,6 @@ public:
 	    }
 	}
 
-#if 1
         dvsc = dds.var_begin() ;
         vsc = vs.begin() ;
         for( ; dvsc != dds.var_end() && vsc != vs.end(); dvsc++, vsc++ )
@@ -196,18 +216,7 @@ public:
             }
             CPPUNIT_ASSERT( (*dvsc)->name() == *vsc ) ;
         }
-#else
-	p = dds.first_var() ;
-	vsc = vs.begin() ;
-	for( ; p && vsc != vs.end(); dds.next_var( p ), vsc++ )
-	{
-	    if( dds.var(p)->name() == "var2" )
-	    {
-		dds.del_var( "var2" ) ;
-	    }
-	    CPPUNIT_ASSERT( dds.var(p)->name() == *vsc ) ;
-	}
-#endif
+
 	nv = dds.num_var() ;
 	CPPUNIT_ASSERT( nv == 7 ) ;
 	if( nv != 7 )
@@ -353,42 +362,239 @@ public:
 	    }
 	}
 
-#if 0
-	dds.add_function( "test_grid_select", func_grid_select ) ;
-	proj_func projf ;
-	bool found_func = dds.find_function( "test_grid_select", &projf ) ;
-	CPPUNIT_ASSERT( found_func == true ) ;
-	CPPUNIT_ASSERT( projf ) ;
-#endif
 	{
-            string sof;
-            FILE2string(sof, of, dds.print( of ));
-            CPPUNIT_ASSERT(sof.find(cprint) != string::npos);
+            ostringstream sof;
+            dds.print( sof );
+            CPPUNIT_ASSERT(sof.str().find(cprint) != string::npos);
 	}
 
 	{
-            string sof;
-            FILE2string(sof, of, dds.print_constrained( of ));
-            CPPUNIT_ASSERT(sof.find(nprint) != string::npos);
+            ostringstream sof;
+            dds.print_constrained( sof );
+            CPPUNIT_ASSERT(sof.str().find(nprint) != string::npos);
 	}
 
 	dds.mark_all( true ) ;
 
 	{
-            string sof;
-            FILE2string(sof, of, dds.print_constrained( of ));
-            CPPUNIT_ASSERT(sof.find(cprint) != string::npos);
+            ostringstream sof;
+            dds.print_constrained( sof );
+            CPPUNIT_ASSERT(sof.str().find(cprint) != string::npos);
 	}
 
 	bool mark_ret = dds.mark( "var8", false ) ;
 	CPPUNIT_ASSERT( mark_ret == true ) ;
 
 	{
-            string sof;
-            FILE2string(sof, of, dds.print_constrained( of ));
-            CPPUNIT_ASSERT(sof.find(pprint) != string::npos);
+            ostringstream sof;
+            dds.print_constrained( sof );
+            CPPUNIT_ASSERT(sof.str().find(pprint) != string::npos);
 	}
     }
+
+    void ddsT_containers()
+    {
+	DDS dds( factory, "TestDDS" ) ;
+
+	// set the container to c1 and make sure the container is created
+	dds.container_name( "c1" ) ;
+	CPPUNIT_ASSERT( dds.container_name() == "c1" ) ;
+
+	Structure *c1 = dds.container() ;
+	CPPUNIT_ASSERT( c1 ) ;
+	CPPUNIT_ASSERT( c1->name() == "c1" ) ;
+
+	CPPUNIT_ASSERT( dds.num_var() == 1 ) ;
+
+	// set the container to c2 and make sure the container is created
+	dds.container_name( "c2" ) ;
+	CPPUNIT_ASSERT( dds.container_name() == "c2" ) ;
+
+	Structure *c2 = dds.container() ;
+	CPPUNIT_ASSERT( c2 ) ;
+	CPPUNIT_ASSERT( c2->name() == "c2" ) ;
+
+	CPPUNIT_ASSERT( dds.num_var() == 2 ) ;
+
+	// set back to c1, make sure new one not created
+	dds.container_name( "c1" ) ;
+	CPPUNIT_ASSERT( dds.container_name() == "c1" ) ;
+
+	c1 = dds.container() ;
+	CPPUNIT_ASSERT( c1 ) ;
+	CPPUNIT_ASSERT( c1->name() == "c1" ) ;
+
+	CPPUNIT_ASSERT( dds.num_var() == 2 ) ;
+
+	// start adding variables and make sure not added directly to dds.
+	// Make sure can find those variables without referencing the
+	// container.
+	try
+	{
+	    BaseType *bt = factory->NewInt16( "c1var1" ) ;
+	    dds.add_var( bt ) ;
+	    delete bt ;
+	    bt = factory->NewStr( "c1var2" ) ;
+	    dds.add_var( bt ) ;
+	    delete bt ;
+	    bt = factory->NewArray( "c1var3", factory->NewInt16( "" ) ) ;
+	    dds.add_var( bt ) ;
+	    delete bt ;
+	}
+	catch( InternalErr &e )
+	{
+	    CPPUNIT_FAIL( "failed to add a var" ) ;
+	}
+	CPPUNIT_ASSERT( dds.num_var() == 2 ) ;
+	CPPUNIT_ASSERT( c1->element_count() == 3 ) ;
+
+	BaseType *bt = dds.var( "c1var1" ) ;
+	CPPUNIT_ASSERT( bt ) ;
+	CPPUNIT_ASSERT( bt->name() == "c1var1" ) ;
+	Int16 *ibt = dynamic_cast<Int16 *>(bt) ;
+	CPPUNIT_ASSERT( ibt ) ;
+
+	bt = dds.var( "c1var2" ) ;
+	CPPUNIT_ASSERT( bt ) ;
+	CPPUNIT_ASSERT( bt->name() == "c1var2" ) ;
+	Str *strbt = dynamic_cast<Str *>(bt) ;
+	CPPUNIT_ASSERT( strbt ) ;
+
+	dds.del_var( "c1var2" ) ;
+	bt = dds.var( "c1var2" ) ;
+	CPPUNIT_ASSERT( bt == 0 ) ;
+	CPPUNIT_ASSERT( dds.num_var() == 2 ) ;
+	CPPUNIT_ASSERT( c1->element_count() == 2 ) ;
+
+	// set container to "", add vars, make sure added directly to dds.
+	// Make sure can find those variables
+	dds.container_name( "" ) ;
+	CPPUNIT_ASSERT( dds.container_name() == "" ) ;
+	CPPUNIT_ASSERT( dds.container() == 0 ) ;
+	try
+	{
+	    BaseType *bt = factory->NewByte( "var1" ) ;
+	    dds.add_var( bt ) ;
+	    delete bt ;
+	    bt = factory->NewFloat64( "var2" ) ;
+	    dds.add_var( bt ) ;
+	    delete bt ;
+	    bt = factory->NewUInt32( "var3" ) ;
+	    dds.add_var( bt ) ;
+	    delete bt ;
+	}
+	catch( InternalErr &e )
+	{
+	    CPPUNIT_FAIL( "failed to add a var" ) ;
+	}
+	CPPUNIT_ASSERT( dds.num_var() == 5 ) ;
+	CPPUNIT_ASSERT( c1->element_count() == 2 ) ;
+
+	BaseType::btp_stack btps ;
+	bt = dds.var( "c1var1", btps ) ;
+	CPPUNIT_ASSERT( bt && bt->name() == "c1var1" ) ;
+	CPPUNIT_ASSERT( btps.size() == 1 ) ;
+	BaseType *btp = btps.top() ;
+	CPPUNIT_ASSERT( btp && btp->name() == "c1" ) ;
+	btps.pop() ;
+
+	bt = dds.var( "var1" ) ;
+	CPPUNIT_ASSERT( bt ) ;
+	CPPUNIT_ASSERT( bt->name() == "var1" ) ;
+	Byte *bbt = dynamic_cast<Byte *>(bt) ;
+	CPPUNIT_ASSERT( bbt ) ;
+
+	bt = c1->var( "var1" ) ;
+	CPPUNIT_ASSERT( bt == 0 ) ;
+
+	dds.del_var( "var3" ) ;
+	bt = dds.var( "var3" ) ;
+	CPPUNIT_ASSERT( bt == 0 ) ;
+	CPPUNIT_ASSERT( dds.num_var() == 4 ) ;
+	CPPUNIT_ASSERT( c1->element_count() == 2 ) ;
+
+	// set to c2, add variables and make sure not added directly to dds.
+	// Make sure can find those variables without referencing the
+	// container.
+	dds.container_name( "c2" ) ;
+	CPPUNIT_ASSERT( dds.container_name() == "c2" ) ;
+	c2 = dds.container() ;
+	CPPUNIT_ASSERT( c2 && c2->name() == "c2" ) ;
+
+	try
+	{
+	    BaseType *bt = factory->NewInt32( "c2var1" ) ;
+	    dds.add_var( bt ) ;
+	    delete bt ;
+	    bt = factory->NewStr( "c2var2" ) ;
+	    dds.add_var( bt ) ;
+	    delete bt ;
+	    Structure *s = factory->NewStructure( "c2var3" ) ;
+	    Structure *s1 = factory->NewStructure( "c2var3var1" ) ;
+	    bt = factory->NewInt16( "c2var3var1var1" ) ;
+	    s1->add_var( bt ) ;
+	    delete bt ; bt = 0 ;
+	    bt = factory->NewInt16( "c2var3var1var2" ) ;
+	    s1->add_var( bt ) ;
+	    delete bt ; bt = 0 ;
+	    s->add_var( s1 ) ;
+	    delete s1 ; s1 = 0 ;
+	    dds.add_var( s ) ;
+	    delete s ; s = 0 ;
+	}
+	catch( InternalErr &e )
+	{
+	    CPPUNIT_FAIL( "failed to add a var" ) ;
+	}
+	CPPUNIT_ASSERT( dds.num_var() == 4 ) ;
+	CPPUNIT_ASSERT( c2->element_count() == 3 ) ;
+
+	bt = dds.var( "c2var1" ) ;
+	CPPUNIT_ASSERT( bt && bt->name() == "c2var1" ) ;
+	Int32 *i32bt = dynamic_cast<Int32 *>( bt ) ;
+	CPPUNIT_ASSERT( i32bt ) ;
+
+	bt = dds.var( "c2var2" ) ;
+	CPPUNIT_ASSERT( bt && bt->name() == "c2var2" ) ;
+	strbt = dynamic_cast<Str *>( bt ) ;
+	CPPUNIT_ASSERT( strbt ) ;
+
+	bt = dds.var( "c2var3" ) ;
+	CPPUNIT_ASSERT( bt && bt->name() == "c2var3" ) ;
+	Structure *sbt = dynamic_cast<Structure *>( bt ) ;
+	CPPUNIT_ASSERT( sbt ) ;
+
+	bt = dds.var( "var1" ) ;
+	CPPUNIT_ASSERT( bt == 0 ) ;
+
+	bt = dds.var( "var2" ) ;
+	CPPUNIT_ASSERT( bt == 0 ) ;
+
+	bt = dds.var( "c2var3var1var2", btps ) ;
+	CPPUNIT_ASSERT( bt && bt->name() == "c2var3var1var2" ) ;
+	CPPUNIT_ASSERT( btps.size() == 3 ) ;
+	btp = btps.top() ;
+	CPPUNIT_ASSERT( btp && btp->name() == "c2" ) ;
+	btps.pop() ;
+	btp = btps.top() ;
+	CPPUNIT_ASSERT( btp && btp->name() == "c2var3" ) ;
+	btps.pop() ;
+	btp = btps.top() ;
+	CPPUNIT_ASSERT( btp && btp->name() == "c2var3var1" ) ;
+	btps.pop() ;
+
+	dds.del_var( "c2var1" ) ;
+	bt = dds.var( "c2var1" ) ;
+	CPPUNIT_ASSERT( bt == 0 ) ;
+	CPPUNIT_ASSERT( dds.num_var() == 4 ) ;
+	CPPUNIT_ASSERT( c2->element_count() == 2 ) ;
+
+	// print the dds and make sure it looks good.
+	ostringstream sstrm ;
+	dds.print( sstrm ) ;
+	cout << sstrm.str() << endl ;
+	CPPUNIT_ASSERT( sstrm.str() == containerprint ) ;
+    }
 };
 
 CPPUNIT_TEST_SUITE_REGISTRATION( ddsT ) ;
@@ -401,7 +607,7 @@ int main( int, char ** )
     CppUnit::TestFactoryRegistry &registry =
 	CppUnit::TestFactoryRegistry::getRegistry() ;
     runner.addTest( registry.makeTest() ) ;
-    runner.setOutputter( CppUnit::CompilerOutputter::defaultOutputter( 
+    runner.setOutputter( CppUnit::CompilerOutputter::defaultOutputter(
                                                         &runner.result(),
                                                         std::cerr ) );
     bool wasSuccessful = runner.run( "", false ) ;
